@@ -10,6 +10,10 @@
 #include <sys/resource.h>
 #endif
 
+#ifdef _WIN32
+# include <evil_private.h> /* fcntl */
+#endif
+
 #include <Eina.h>
 #include <Eet.h>
 #include <Ecore.h>
