@@ -1,6 +1,11 @@
 #ifdef HAVE_CONFIG_H
 # include "elementary_config.h"
 #endif
+
+#ifdef _WIN32
+# include <evil_private.h> /* strcasestr */
+#endif
+
 #include <Elementary.h>
 
 enum _slide_style
@@ -375,6 +380,28 @@ test_label_ellipsis(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *
    evas_object_show(win);
 }
 
+/*** Label colors **************************************************************/
+void
+test_label_colors(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win, *lb;
+
+   win = elm_win_util_standard_add("label-colors", "Label colors");
+   elm_win_autodel_set(win, EINA_TRUE);
+
+   lb = elm_label_add(win);
+   elm_object_text_set(lb,
+                       "<color=red>this is red color line(color = red)<color><br>"
+                       "<color=#0000FF>this is blue color line (color = #0000FF)<color><br>"
+                       "<color=rgb(0,255,0)>this is green color line (color = rgb(0,255,0))<color><br>"
+                       "<color=rgba(0,255,0,255)>this is blue color line (color = rgba(0,255,0,255))<color><br>"
+                       );
+   evas_object_size_hint_weight_set(lb, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, lb);
+   evas_object_show(lb);
+
+   evas_object_show(win);
+}
 
 /*** Label Emoji *************************************************************/
 static char *
