@@ -3,8 +3,8 @@
 #endif
 #include <Efl_Ui.h>
 #include <Elementary.h>
-
-#define MAX_NUM_OF_CONTENT 18
+#include "elm_priv.h" //FIXME remove this once efl.ui.text doesn't need elm_general.h
+#define MAX_NUM_OF_CONTENT 17
 
 const Efl_Class *content_class[MAX_NUM_OF_CONTENT];
 
@@ -12,10 +12,10 @@ const Efl_Class *content_class[MAX_NUM_OF_CONTENT];
 static void
 _reset_cb(void *data, const Efl_Event *ev EINA_UNUSED)
 {
-   Evas_Object *radio = data;
+   Efl_Ui_Radio_Group *radio = data;
    Evas_Object *target;
 
-   radio = efl_ui_radio_selected_object_get(radio);
+   radio = efl_ui_selectable_last_selected_get(radio);
    target = evas_object_data_get(radio, "data");
 
    efl_gfx_color_set(efl_part(target, "background"), 0, 0, 0, 0);
@@ -25,11 +25,11 @@ _reset_cb(void *data, const Efl_Event *ev EINA_UNUSED)
 static void
 _color_cb(void *data, const Efl_Event *ev EINA_UNUSED)
 {
-   Evas_Object *radio = data;
+   Efl_Ui_Radio_Group *radio = data;
    Evas_Object *target;
    static Eina_Bool i;
 
-   radio = efl_ui_radio_selected_object_get(radio);
+   radio = efl_ui_selectable_last_selected_get(radio);
    target = evas_object_data_get(radio, "data");
    i ^= EINA_TRUE;
    efl_gfx_color_set(efl_part(target, "background"), (i) ? 255 : 0, (i) ? 0 : 255, 0, 255);
@@ -38,39 +38,43 @@ _color_cb(void *data, const Efl_Event *ev EINA_UNUSED)
 static void
 _scale_type_cb(void *data, const Efl_Event *ev EINA_UNUSED)
 {
-   Evas_Object *radio = data;
+   Efl_Ui_Radio_Group *radio = data;
    Evas_Object *target;
-   Efl_Gfx_Image_Scale_Type type;
+   Efl_Gfx_Image_Scale_Method type;
    char buf[PATH_MAX];
 
-   radio = efl_ui_radio_selected_object_get(radio);
+   radio = efl_ui_selectable_last_selected_get(radio);
    target = evas_object_data_get(radio, "data");
 
    snprintf(buf, sizeof(buf), "%s/images/plant_01.jpg", elm_app_data_dir_get());
    efl_file_simple_load(efl_part(target, "background"), buf, NULL);
-   type = efl_gfx_image_scale_type_get(efl_part(target, "background"));
-   type = (type + 1) % 5;
-   efl_gfx_image_scale_type_set(efl_part(target, "background"), type);
+   type = efl_gfx_image_scale_method_get(efl_part(target, "background"));
+   type = (type + 1) % 6;
+   efl_gfx_image_scale_method_set(efl_part(target, "background"), type);
 }
 
-static Evas_Object *
+static Efl_Ui_Radio_Group *
 _create_box_contents(Evas_Object *box)
 {
    Evas_Object *hbox;
-   Evas_Object *radio_group, *radio;
+   Evas_Object *radio;
    Evas_Object *content;
+   Efl_Ui_Radio_Group *radio_group;
    char buf[PATH_MAX];
    unsigned int i;
 
+   radio_group = efl_new(EFL_UI_RADIO_GROUP_IMPL_CLASS, NULL);
+
    hbox = efl_add(EFL_UI_BOX_CLASS, box,
-                  efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
+                  efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL),
                   efl_gfx_hint_weight_set(efl_added, 1, 1),
                   efl_pack_end(box, efl_added));
 
-   radio_group = radio = efl_add(EFL_UI_RADIO_CLASS, hbox,
-                                 efl_pack_end(hbox, efl_added),
-                                 efl_gfx_hint_weight_set(efl_added, 0, 0),
-                                 efl_ui_radio_state_value_set(efl_added, 0));
+   radio = efl_add(EFL_UI_RADIO_CLASS, hbox);
+   efl_gfx_hint_weight_set(radio, 0, 0);
+   efl_ui_radio_state_value_set(radio, 0);
+   efl_ui_radio_group_register(radio_group, radio);
+   efl_pack_end(hbox, radio);
 
    content = efl_add(EFL_UI_BOX_CLASS, hbox,
                      efl_pack_end(hbox, efl_added));
@@ -86,14 +90,14 @@ _create_box_contents(Evas_Object *box)
         if (!content_class[i]) continue;
 
         hbox = efl_add(EFL_UI_BOX_CLASS, box,
-                       efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
+                       efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL),
                        efl_pack_end(box, efl_added));
 
-        radio = efl_add(EFL_UI_RADIO_CLASS, hbox,
-                        efl_ui_radio_group_add(efl_added, radio_group),
-                        efl_pack_end(hbox, efl_added),
-                        efl_ui_radio_state_value_set(efl_added, i + 1),
-                        efl_gfx_hint_weight_set(efl_added, 0, 0));
+        radio = efl_add(EFL_UI_RADIO_CLASS, hbox);
+        efl_ui_radio_state_value_set(radio, i + 1);
+        efl_gfx_hint_weight_set(radio, 0, 0);
+        efl_ui_radio_group_register(radio_group, radio);
+        efl_pack_end(hbox, radio);
 
         content = efl_add(content_class[i], hbox,
                           efl_pack_end(hbox, efl_added));
@@ -110,7 +114,7 @@ _create_box_contents(Evas_Object *box)
         evas_object_data_set(radio, "data", content);
      }
 
-   efl_ui_nstate_value_set(radio_group, 0);
+   efl_ui_radio_group_selected_value_set(radio_group, 0);
 
    return radio_group;
 }
@@ -121,7 +125,7 @@ test_part_background(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
    Evas_Object *win;
    Evas_Object *scr;
    Evas_Object *vbox, *hbox;
-   Evas_Object *radio_group;
+   Efl_Ui_Radio_Group *radio_group;
    Evas_Object *reset_btn, *color_btn, *scale_btn;
 
    content_class[0] = EFL_UI_CALENDAR_CLASS;
@@ -139,9 +143,8 @@ test_part_background(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
    content_class[12] = EFL_UI_BG_CLASS;
    content_class[13] = EFL_UI_IMAGE_CLASS;
    content_class[14] = EFL_UI_IMAGE_ZOOMABLE_CLASS;
-   content_class[15] = EFL_UI_NSTATE_CLASS;
-   content_class[16] = EFL_UI_SPIN_CLASS;
-   content_class[17] = EFL_UI_SPIN_BUTTON_CLASS;
+   content_class[15] = EFL_UI_SPIN_CLASS;
+   content_class[16] = EFL_UI_SPIN_BUTTON_CLASS;
 
    win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
                  efl_text_set(efl_added, "Widget Part Background"),
@@ -152,7 +155,7 @@ test_part_background(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
                   efl_content_set(win, efl_added));
 
    hbox = efl_add(EFL_UI_BOX_CLASS, vbox,
-                  efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
+                  efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL),
                   efl_gfx_hint_weight_set(efl_added, 1.0, 0.0),
                   efl_pack_end(vbox, efl_added));
 
@@ -178,9 +181,9 @@ test_part_background(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
 
    radio_group = _create_box_contents(vbox);
 
-   efl_event_callback_add(reset_btn, EFL_UI_EVENT_CLICKED, _reset_cb, radio_group);
-   efl_event_callback_add(color_btn, EFL_UI_EVENT_CLICKED, _color_cb, radio_group);
-   efl_event_callback_add(scale_btn, EFL_UI_EVENT_CLICKED, _scale_type_cb, radio_group);
+   efl_event_callback_add(reset_btn, EFL_INPUT_EVENT_CLICKED, _reset_cb, radio_group);
+   efl_event_callback_add(color_btn, EFL_INPUT_EVENT_CLICKED, _color_cb, radio_group);
+   efl_event_callback_add(scale_btn, EFL_INPUT_EVENT_CLICKED, _scale_type_cb, radio_group);
 
    efl_gfx_entity_size_set(win, EINA_SIZE2D(300, 200));
 }
