@@ -20,9 +20,9 @@ typedef enum {
 } Weight_Mode;
 
 static void
-weights_cb(void *data, const Efl_Event *event)
+weights_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   Weight_Mode mode = elm_radio_state_value_get(event->object);
+   Weight_Mode mode = elm_radio_state_value_get(obj);
 
    switch (mode)
      {
@@ -76,7 +76,7 @@ padding_slider_cb(void *data, const Efl_Event *event)
    Eo *win = data, *box;
 
    box = efl_key_wref_get(win, "box");
-   efl_pack_padding_set(box, val, val, EINA_TRUE);
+   efl_gfx_arrangement_content_padding_set(box, val, val, EINA_TRUE);
 }
 
 static void
@@ -97,8 +97,8 @@ alignh_slider_cb(void *data, const Efl_Event *event)
 
    box = efl_key_wref_get(win, "box");
    val = elm_slider_value_get(event->object);
-   efl_pack_align_get(box, NULL, &av);
-   efl_pack_align_set(box, val, av);
+   efl_gfx_arrangement_content_align_get(box, NULL, &av);
+   efl_gfx_arrangement_content_align_set(box, val, av);
 }
 
 static void
@@ -109,8 +109,8 @@ alignv_slider_cb(void *data, const Efl_Event *event)
 
    box = efl_key_wref_get(win, "box");
    val = elm_slider_value_get(event->object);
-   efl_pack_align_get(box, &ah, NULL);
-   efl_pack_align_set(box, ah, val);
+   efl_gfx_arrangement_content_align_get(box, &ah, NULL);
+   efl_gfx_arrangement_content_align_set(box, ah, val);
 }
 
 static void
@@ -138,9 +138,9 @@ alignv_btn_slider_cb(void *data, const Efl_Event *event)
 }
 
 static void
-flow_check_cb(void *data, const Efl_Event *event)
+flow_check_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   Eina_Bool chk = elm_check_selected_get(event->object);
+   Eina_Bool chk = elm_check_selected_get(obj);
    Eina_List *list = NULL;
    Eina_Iterator *it;
    Eo *box, *win, *sobj, *parent;
@@ -158,7 +158,7 @@ flow_check_cb(void *data, const Efl_Event *event)
    efl_del(box);
 
    box = efl_add(chk ? EFL_UI_BOX_FLOW_CLASS : EFL_UI_BOX_CLASS, win,
-                 efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL));
+                 efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL));
    efl_content_set(parent, box);
    efl_key_wref_set(win, "box", box);
 
@@ -167,17 +167,17 @@ flow_check_cb(void *data, const Efl_Event *event)
 }
 
 static void
-horiz_check_cb(void *data, const Efl_Event *event)
+horiz_check_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   Eina_Bool chk = elm_check_selected_get(event->object);
+   Eina_Bool chk = elm_check_selected_get(obj);
    Eo *box = efl_key_wref_get(data, "box");
-   efl_ui_direction_set(box, chk ? EFL_UI_DIR_HORIZONTAL : EFL_UI_DIR_VERTICAL);
+   efl_ui_layout_orientation_set(box, chk ? EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL : EFL_UI_LAYOUT_ORIENTATION_VERTICAL);
 }
 
 static void
-homo_check_cb(void *data, const Efl_Event *event)
+homo_check_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   Eina_Bool chk = elm_check_selected_get(event->object);
+   Eina_Bool chk = elm_check_selected_get(obj);
    Eo *box = efl_key_wref_get(data, "box");
    efl_ui_box_homogeneous_set(box, chk);
 }
@@ -210,12 +210,12 @@ _custom_layout_update(Eo *pack, const void *data EINA_UNUSED)
 }
 
 static void
-custom_check_cb(void *data, const Efl_Event *event)
+custom_check_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    EFL_OPS_DEFINE(custom_layout_ops,
                   EFL_OBJECT_OP_FUNC(efl_pack_layout_update, _custom_layout_update));
 
-   Eina_Bool chk = elm_check_selected_get(event->object);
+   Eina_Bool chk = elm_check_selected_get(obj);
    Eo *box, *win = data;
 
    box = efl_key_wref_get(win, "box");
@@ -239,8 +239,8 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    efl_gfx_entity_size_set(win, EINA_SIZE2D(600,  400));
 
    vbox = efl_add(EFL_UI_BOX_CLASS, win,
-                  efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
-   efl_pack_padding_set(vbox, 10, 10, EINA_TRUE);
+                  efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
+   efl_gfx_arrangement_content_padding_set(vbox, 10, 10, EINA_TRUE);
    efl_gfx_hint_margin_set(vbox, 5, 5, 5, 5);
    elm_win_resize_object_add(win, vbox);
 
@@ -254,21 +254,21 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    efl_gfx_entity_visible_set(f, 1);
 
    hbox = efl_add(EFL_UI_BOX_CLASS, win,
-                  efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL));
+                  efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL));
    efl_content_set(f, hbox);
-   efl_pack_padding_set(hbox, 10, 0, EINA_TRUE);
+   efl_gfx_arrangement_content_padding_set(hbox, 10, 0, EINA_TRUE);
 
 
    /* weights radio group */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_pack(hbox, bx);
 
    chk = o = elm_radio_add(win);
    elm_object_text_set(o, "No weight");
-   efl_event_callback_add(o, EFL_UI_RADIO_EVENT_CHANGED, weights_cb, win);
+   evas_object_smart_callback_add(o, "changed", weights_cb, win);
    efl_gfx_hint_align_set(o, 0, 0.5);
    elm_radio_state_value_set(o, NONE);
    efl_pack(bx, o);
@@ -276,7 +276,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    o = elm_radio_add(win);
    elm_object_text_set(o, "No weight + box fill");
-   efl_event_callback_add(o, EFL_UI_RADIO_EVENT_CHANGED, weights_cb, win);
+   evas_object_smart_callback_add(o, "changed", weights_cb, win);
    efl_gfx_hint_align_set(o, 0, 0.5);
    elm_radio_state_value_set(o, NONE_BUT_FILL);
    elm_radio_group_add(o, chk);
@@ -285,7 +285,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    o = elm_radio_add(win);
    elm_object_text_set(o, "Equal weights");
-   efl_event_callback_add(o, EFL_UI_RADIO_EVENT_CHANGED, weights_cb, win);
+   evas_object_smart_callback_add(o, "changed", weights_cb, win);
    efl_gfx_hint_align_set(o, 0, 0.5);
    elm_radio_state_value_set(o, EQUAL);
    elm_radio_group_add(o, chk);
@@ -294,7 +294,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    o = elm_radio_add(win);
    elm_object_text_set(o, "One weight only");
-   efl_event_callback_add(o, EFL_UI_RADIO_EVENT_CHANGED, weights_cb, win);
+   evas_object_smart_callback_add(o, "changed", weights_cb, win);
    efl_gfx_hint_align_set(o, 0, 0.5);
    elm_radio_state_value_set(o, ONE);
    elm_radio_group_add(o, chk);
@@ -303,7 +303,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    o = elm_radio_add(win);
    elm_object_text_set(o, "Two weights");
-   efl_event_callback_add(o, EFL_UI_RADIO_EVENT_CHANGED, weights_cb, win);
+   evas_object_smart_callback_add(o, "changed", weights_cb, win);
    efl_gfx_hint_align_set(o, 0, 0.5);
    elm_radio_state_value_set(o, TWO);
    elm_radio_group_add(o, chk);
@@ -315,7 +315,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    /* misc */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_gfx_hint_weight_set(bx, 0, 1);
@@ -329,7 +329,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    o = elm_check_add(win);
    elm_check_selected_set(o, 0);
    elm_object_text_set(o, "Flow");
-   efl_event_callback_add(o, EFL_UI_CHECK_EVENT_CHANGED, flow_check_cb, win);
+   evas_object_smart_callback_add(o, "changed", flow_check_cb, win);
    efl_gfx_hint_align_set(o, 0, 0);
    efl_pack(bx, o);
    efl_gfx_entity_visible_set(o, 1);
@@ -337,7 +337,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    o = elm_check_add(win);
    elm_check_selected_set(o, 1);
    elm_object_text_set(o, "Horizontal");
-   efl_event_callback_add(o, EFL_UI_CHECK_EVENT_CHANGED, horiz_check_cb, win);
+   evas_object_smart_callback_add(o, "changed", horiz_check_cb, win);
    efl_gfx_hint_align_set(o, 0, 0);
    efl_pack(bx, o);
    efl_gfx_entity_visible_set(o, 1);
@@ -345,7 +345,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    o = elm_check_add(win);
    elm_check_selected_set(o, 0);
    elm_object_text_set(o, "Homogenous");
-   efl_event_callback_add(o, EFL_UI_CHECK_EVENT_CHANGED, homo_check_cb, win);
+   evas_object_smart_callback_add(o, "changed", homo_check_cb, win);
    efl_gfx_hint_align_set(o, 0, 0);
    efl_pack(bx, o);
    efl_gfx_entity_visible_set(o, 1);
@@ -353,7 +353,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    o = elm_check_add(win);
    elm_check_selected_set(o, 0);
    elm_object_text_set(o, "Custom layout");
-   efl_event_callback_add(o, EFL_UI_CHECK_EVENT_CHANGED, custom_check_cb, win);
+   evas_object_smart_callback_add(o, "changed", custom_check_cb, win);
    efl_gfx_hint_align_set(o, 0, 0);
    efl_gfx_hint_weight_set(o, 0, 1);
    efl_pack(bx, o);
@@ -362,7 +362,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    /* user min size setter */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_gfx_hint_weight_set(bx, 0, 1);
@@ -379,7 +379,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    elm_slider_horizontal_set(o, 0);
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 1);
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, user_min_slider_cb, NULL);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, user_min_slider_cb, NULL);
    elm_slider_min_max_set(o, 0, 250);
    elm_slider_inverted_set(o, 1);
    elm_slider_value_set(o, 0);
@@ -389,7 +389,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    /* inner box padding */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_gfx_hint_weight_set(bx, 0, 1);
@@ -406,7 +406,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    elm_slider_horizontal_set(o, 0);
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 1);
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, padding_slider_cb, win);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, padding_slider_cb, win);
    elm_slider_min_max_set(o, 0, 40);
    elm_slider_inverted_set(o, 1);
    elm_slider_value_set(o, 10);
@@ -416,7 +416,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    /* outer margin */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_gfx_hint_weight_set(bx, 0, 1);
@@ -433,7 +433,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    elm_slider_horizontal_set(o, 0);
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 1);
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, margin_slider_cb, win);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, margin_slider_cb, win);
    elm_slider_min_max_set(o, 0, 40);
    elm_slider_inverted_set(o, 1);
    elm_slider_value_set(o, 10);
@@ -443,7 +443,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    /* Box align */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_gfx_hint_weight_set(bx, 1, 1);
@@ -460,7 +460,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    elm_slider_horizontal_set(o, 0);
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 1);
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, alignv_slider_cb, win);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, alignv_slider_cb, win);
    elm_slider_min_max_set(o, -0.1, 1.0);
    elm_slider_step_set(o, 0.1);
    elm_slider_value_set(o, 0.5);
@@ -474,7 +474,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 0);
    efl_gfx_hint_size_min_set(o, EINA_SIZE2D(100, 0));
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, alignh_slider_cb, win);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, alignh_slider_cb, win);
    elm_slider_min_max_set(o, -0.1, 1.0);
    elm_slider_step_set(o, 0.1);
    elm_slider_value_set(o, 0.5);
@@ -483,7 +483,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
 
    /* Button align */
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
    efl_gfx_hint_align_set(bx, 0, 0.5);
    efl_gfx_hint_fill_set(bx, EINA_FALSE, EINA_TRUE);
    efl_gfx_hint_weight_set(bx, 1, 1);
@@ -500,7 +500,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    elm_slider_horizontal_set(o, 0);
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 1);
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, alignv_btn_slider_cb, win);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, alignv_btn_slider_cb, win);
    elm_slider_min_max_set(o, 0.0, 1.0);
    elm_slider_step_set(o, 0.1);
    elm_slider_value_set(o, 0.5);
@@ -514,7 +514,7 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    efl_gfx_hint_align_set(o, 0.5, -1);
    efl_gfx_hint_weight_set(o, 1, 0);
    efl_gfx_hint_size_min_set(o, EINA_SIZE2D(100, 0));
-   efl_event_callback_add(o, EFL_UI_SLIDER_EVENT_CHANGED, alignh_btn_slider_cb, win);
+   efl_event_callback_add(o, EFL_UI_RANGE_EVENT_CHANGED, alignh_btn_slider_cb, win);
    elm_slider_min_max_set(o, -0.1, 1.0);
    elm_slider_step_set(o, 0.1);
    elm_slider_value_set(o, 0.5);
@@ -531,9 +531,9 @@ test_ui_box(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    efl_gfx_entity_visible_set(f, 1);
 
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL));
    efl_key_wref_set(win, "box", bx);
-   efl_pack_padding_set(bx, 10, 10, EINA_TRUE);
+   efl_gfx_arrangement_content_padding_set(bx, 10, 10, EINA_TRUE);
    efl_gfx_hint_align_set(bx, 0.5, 0.5);
    efl_gfx_hint_weight_set(bx, 1, 1);
    efl_content_set(f, bx);
