@@ -36,7 +36,8 @@ typedef enum _Pack_Type {
    PACK_BEFORE,
    PACK_AFTER,
    PACK_AT,
-   UNPACK_AT
+   UNPACK_AT,
+   CLEAR
 } Pack_Type;
 
 typedef struct _Params {
@@ -240,7 +241,7 @@ static void pack_btn_cb(void *data, const Efl_Event *ev EINA_UNUSED)
    Eo *page = NULL, *curr_page;
    int index, cnt;
 
-   if (param->type != UNPACK_AT) {
+   if ((param->type != UNPACK_AT) && (param->type != CLEAR)) {
       index  = efl_content_count(pager);
 
       switch (index % 3) {
@@ -282,10 +283,12 @@ static void pack_btn_cb(void *data, const Efl_Event *ev EINA_UNUSED)
          break;
       case UNPACK_AT:
          index = efl_ui_range_value_get(param->unpack_sp);
-         page = efl_pack_content_get(pager, index);
-         efl_pack_unpack(pager, page);
+         page = efl_pack_unpack_at(pager, index);
          efl_del(page);
          break;
+      case CLEAR:
+         efl_pack_clear(pager);
+         break;
    }
 
    cnt = efl_content_count(pager);
@@ -293,7 +296,7 @@ static void pack_btn_cb(void *data, const Efl_Event *ev EINA_UNUSED)
    index = efl_ui_range_value_get(param->pack_sp);
    if (index > cnt)
      efl_ui_range_value_set(param->pack_sp, cnt);
-   efl_ui_range_min_max_set(param->pack_sp, 0, cnt);
+   efl_ui_range_limits_set(param->pack_sp, 0, cnt);
 
    if (cnt > 0)
      {
@@ -304,7 +307,7 @@ static void pack_btn_cb(void *data, const Efl_Event *ev EINA_UNUSED)
         index = efl_ui_range_value_get(param->unpack_sp);
         if (index > cnt)
           efl_ui_range_value_set(param->unpack_sp, cnt);
-        efl_ui_range_min_max_set(param->unpack_sp, 0, cnt);
+        efl_ui_range_limits_set(param->unpack_sp, 0, cnt);
      }
    else
      {
@@ -336,7 +339,7 @@ static void prev_block_check_cb(void *data, const Efl_Event *ev)
    Eo *pager = data;
    Eina_Bool prev, next;
 
-   prev = efl_ui_nstate_value_get(ev->object);
+   prev = efl_ui_selectable_selected_get(ev->object);
 
    efl_ui_pager_scroll_block_get(pager, NULL, &next);
    efl_ui_pager_scroll_block_set(pager, prev, next);
@@ -347,19 +350,17 @@ static void next_block_check_cb(void *data, const Efl_Event *ev)
    Eo *pager = data;
    Eina_Bool prev, next;
 
-   next = efl_ui_nstate_value_get(ev->object);
+   next = efl_ui_selectable_selected_get(ev->object);
 
    efl_ui_pager_scroll_block_get(pager, &prev, NULL);
    efl_ui_pager_scroll_block_set(pager, prev, next);
 }
 
-static void loop_check_cb(void *data, const Efl_Event *ev)
+static void loop_radio_cb(void *data, const Efl_Event *ev)
 {
    Eo *pager = data;
-   int state = efl_ui_nstate_value_get(ev->object);
+   int state = efl_ui_radio_group_selected_value_get(efl_ui_widget_parent_get(ev->object));
 
-   //FIXME use other widget (i.e. radio) than check
-   //      since loop might not be enabled according to the number of items
    efl_ui_pager_loop_mode_set(pager, state);
 }
 
@@ -390,7 +391,7 @@ static void page_size_cb(void *data,
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
@@ -408,16 +409,16 @@ static void page_size_cb(void *data,
    inbox = efl_add(EFL_UI_BOX_CLASS, fr,
                   efl_content_set(fr, efl_added));
 
-   ck = elm_check_add(inbox);
-   elm_object_text_set(ck, "Fill");
+   ck = efl_add(EFL_UI_CHECK_CLASS, inbox);
+   efl_text_set(ck, "Fill");
    efl_pack_end(inbox, ck);
    efl_gfx_entity_visible_set(ck, 1);
 
    sl = efl_add(EFL_UI_SLIDER_CLASS, inbox,
-                efl_ui_range_min_max_set(efl_added, 100, 200),
+                efl_ui_range_limits_set(efl_added, 100, 200),
                 efl_ui_range_value_set(efl_added, params->w),
                 efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(100, 0)),
-                efl_event_callback_add(efl_added, EFL_UI_SLIDER_EVENT_CHANGED,
+                efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_CHANGED,
                                        width_slider_cb, params),
                 efl_pack_end(inbox, efl_added));
 
@@ -428,7 +429,7 @@ static void page_size_cb(void *data,
    size_params->pager = params->pager;
    size_params->params = params;
 
-   efl_event_callback_add(ck, EFL_UI_CHECK_EVENT_CHANGED, width_check_cb,
+   efl_event_callback_add(ck, EFL_UI_EVENT_SELECTED_CHANGED, width_check_cb,
                           size_params);
    efl_event_callback_add(ck, EFL_EVENT_DEL, check_del_cb, size_params);
 
@@ -449,16 +450,16 @@ static void page_size_cb(void *data,
    inbox = efl_add(EFL_UI_BOX_CLASS, fr,
                   efl_content_set(fr, efl_added));
 
-   ck = elm_check_add(inbox);
-   elm_object_text_set(ck, "Fill");
+   ck = efl_add(EFL_UI_CHECK_CLASS, inbox);
+   efl_text_set(ck, "Fill");
    efl_pack_end(inbox, ck);
    efl_gfx_entity_visible_set(ck, 1);
 
    sl = efl_add(EFL_UI_SLIDER_CLASS, inbox,
-                efl_ui_range_min_max_set(efl_added, 100, 300),
+                efl_ui_range_limits_set(efl_added, 100, 300),
                 efl_ui_range_value_set(efl_added, params->h),
                 efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(100, 0)),
-                efl_event_callback_add(efl_added, EFL_UI_SLIDER_EVENT_CHANGED,
+                efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_CHANGED,
                                        height_slider_cb, params),
                 efl_pack_end(inbox, efl_added));
 
@@ -469,7 +470,7 @@ static void page_size_cb(void *data,
    size_params->pager = params->pager;
    size_params->params = params;
 
-   efl_event_callback_add(ck, EFL_UI_CHECK_EVENT_CHANGED, height_check_cb,
+   efl_event_callback_add(ck, EFL_UI_EVENT_SELECTED_CHANGED, height_check_cb,
                           size_params);
    efl_event_callback_add(ck, EFL_EVENT_DEL, check_del_cb, size_params);
 
@@ -490,19 +491,19 @@ static void padding_cb(void *data,
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
                  elm_naviframe_item_push(navi, "Padding Size", btn, NULL,
                                          efl_added, NULL));
 
    efl_add(EFL_UI_SLIDER_CLASS, box,
-           efl_ui_range_min_max_set(efl_added, 0, 50),
+           efl_ui_range_limits_set(efl_added, 0, 50),
            efl_ui_range_value_set(efl_added, params->padding),
            efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(100, 0)),
-           efl_event_callback_add(efl_added, EFL_UI_SLIDER_EVENT_CHANGED,
+           efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_CHANGED,
                                   padding_slider_cb, params),
            efl_pack_end(box, efl_added));
 }
@@ -517,23 +518,23 @@ static void side_page_num_cb(void *data,
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
 		 elm_naviframe_item_push(navi, "Side Page Num", btn, NULL,
                                          efl_added, NULL));
 
    efl_add(EFL_UI_SLIDER_CLASS, box,
            efl_text_set(efl_added, "side page num"),
            efl_ui_format_string_set(efl_part(efl_added, "indicator"), "%1.0f"),
-           efl_ui_range_min_max_set(efl_added, 0, 3),
+           efl_ui_range_limits_set(efl_added, 0, 3),
            efl_ui_range_value_set(efl_added, params->side_page_num),
-           efl_ui_direction_set(efl_added, EFL_UI_DIR_VERTICAL),
+           efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL),
            efl_gfx_hint_weight_set(efl_added, 1, 1),
            efl_gfx_hint_align_set(efl_added, -1, -1),
-           efl_event_callback_add(efl_added, EFL_UI_SLIDER_EVENT_CHANGED,
+           efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_CHANGED,
                                   side_page_num_slider_cb, params),
            efl_pack_end(box, efl_added));
 }
@@ -550,27 +551,27 @@ static void pack_cb(void *data,
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
                  elm_naviframe_item_push(navi, "Pack", btn, NULL,
                                          efl_added, NULL));
 
    in_box1 = efl_add(EFL_UI_BOX_CLASS, box,
-                     efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
-                     efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL));
+                     efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
+                     efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL));
 
    sp1 = efl_add(EFL_UI_SPIN_BUTTON_CLASS, in_box1,
-                 efl_ui_range_min_max_set(efl_added, 0,
+                 efl_ui_range_limits_set(efl_added, 0,
                                           efl_content_count(pager)),
                  efl_ui_range_value_set(efl_added,
                                         efl_ui_pager_current_page_get(pager)));
 
    in_box2 = efl_add(EFL_UI_BOX_CLASS, box,
-                     efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
-                     efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL));
+                     efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
+                     efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL));
 
    sp2 = efl_add(EFL_UI_SPIN_BUTTON_CLASS, in_box2);
 
@@ -589,7 +590,7 @@ static void pack_cb(void *data,
 
    efl_add(EFL_UI_BUTTON_CLASS, box,
            efl_text_set(efl_added, "Pack Begin"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   pack_btn_cb, pack_param),
            efl_event_callback_add(efl_added, EFL_EVENT_DEL,
                                   pack_btn_del_cb, pack_param),
@@ -607,7 +608,7 @@ static void pack_cb(void *data,
 
    efl_add(EFL_UI_BUTTON_CLASS, box,
            efl_text_set(efl_added, "Pack End"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   pack_btn_cb, pack_param),
            efl_event_callback_add(efl_added, EFL_EVENT_DEL,
                                   pack_btn_del_cb, pack_param),
@@ -625,7 +626,7 @@ static void pack_cb(void *data,
 
    efl_add(EFL_UI_BUTTON_CLASS, box,
            efl_text_set(efl_added, "Pack Before Current Page"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   pack_btn_cb, pack_param),
            efl_event_callback_add(efl_added, EFL_EVENT_DEL,
                                   pack_btn_del_cb, pack_param),
@@ -643,7 +644,7 @@ static void pack_cb(void *data,
 
    efl_add(EFL_UI_BUTTON_CLASS, box,
            efl_text_set(efl_added, "Pack After Current Page"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   pack_btn_cb, pack_param),
            efl_event_callback_add(efl_added, EFL_EVENT_DEL,
                                   pack_btn_del_cb, pack_param),
@@ -661,7 +662,7 @@ static void pack_cb(void *data,
 
    efl_add(EFL_UI_BUTTON_CLASS, in_box1,
            efl_text_set(efl_added, "Pack At"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   pack_btn_cb, pack_param),
            efl_event_callback_add(efl_added, EFL_EVENT_DEL,
                                   pack_btn_del_cb, pack_param),
@@ -680,14 +681,14 @@ static void pack_cb(void *data,
    pack_param->unpack_btn = btn;
    pack_param->type = UNPACK_AT;
 
-   efl_event_callback_add(btn, EFL_UI_EVENT_CLICKED,
+   efl_event_callback_add(btn, EFL_INPUT_EVENT_CLICKED,
                           pack_btn_cb, pack_param);
    efl_event_callback_add(btn, EFL_EVENT_DEL,
                           pack_btn_del_cb, pack_param);
 
    if (efl_content_count(pager) > 0)
      {
-        efl_ui_range_min_max_set(sp2, 0,
+        efl_ui_range_limits_set(sp2, 0,
                                  (efl_content_count(pager) - 1));
         efl_ui_range_value_set(sp2,
                                efl_ui_pager_current_page_get(pager));
@@ -701,6 +702,24 @@ static void pack_cb(void *data,
    efl_pack_end(box, in_box2);
    efl_pack_end(in_box2, btn);
    efl_pack_end(in_box2, sp2);
+
+   // Clear
+   pack_param = calloc(1, sizeof(Pack_Params));
+   if (!pack_param) return;
+
+   pack_param->pager = pager;
+   pack_param->pack_sp = sp1;
+   pack_param->unpack_sp = sp2;
+   pack_param->unpack_btn = btn;
+   pack_param->type = CLEAR;
+
+   efl_add(EFL_UI_BUTTON_CLASS, box,
+           efl_text_set(efl_added, "Clear"),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
+                                  pack_btn_cb, pack_param),
+           efl_event_callback_add(efl_added, EFL_EVENT_DEL,
+                                  pack_btn_del_cb, pack_param),
+           efl_pack_end(box, efl_added));
 }
 
 static void current_page_cb(void *data,
@@ -716,11 +735,11 @@ static void current_page_cb(void *data,
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
 		 elm_naviframe_item_push(navi, "Current Page", btn, NULL,
                                          efl_added, NULL));
 
@@ -734,7 +753,7 @@ static void current_page_cb(void *data,
 
    if (efl_content_count(pager) > 0)
      {
-        efl_ui_range_min_max_set(sp, 0,
+        efl_ui_range_limits_set(sp, 0,
                                  (efl_content_count(pager) - 1));
         efl_ui_range_value_set(sp,
                                efl_ui_pager_current_page_get(pager));
@@ -748,7 +767,7 @@ static void current_page_cb(void *data,
    psp->pager = pager;
    psp->spinner = sp;
 
-   efl_event_callback_add(btn, EFL_UI_EVENT_CLICKED, page_set_btn_cb, psp);
+   efl_event_callback_add(btn, EFL_INPUT_EVENT_CLICKED, page_set_btn_cb, psp);
    efl_event_callback_add(btn, EFL_EVENT_DEL, page_set_btn_del_cb, psp);
 }
 
@@ -759,36 +778,36 @@ static void scroll_block_cb(void *data,
    Params *params = (Params *)data;
    Evas_Object *navi = params->navi;
    Eo *pager = params->pager;
-   Eo *btn, *box;
+   Eo *btn, *box, *c;
    Eina_Bool prev, next;
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
 		 elm_naviframe_item_push(navi, "Scroll Block", btn, NULL,
                                          efl_added, NULL));
 
    efl_ui_pager_scroll_block_get(pager, &prev, &next);
 
-   efl_add(EFL_UI_CHECK_CLASS, box,
-           efl_ui_widget_style_set(efl_added, "toggle"),
-           efl_text_set(efl_added, "Prev Block"),
-           efl_ui_nstate_value_set(efl_added, prev),
-           efl_event_callback_add(efl_added, EFL_UI_CHECK_EVENT_CHANGED,
-                                  prev_block_check_cb, pager),
-           efl_pack_end(box, efl_added));
+   c = efl_add(EFL_UI_CHECK_CLASS, box);
+   efl_ui_widget_style_set(c, "toggle");
+   efl_text_set(c, "Prev Block");
+   efl_ui_selectable_selected_set(c, prev);
+   efl_event_callback_add(c, EFL_UI_EVENT_SELECTED_CHANGED,
+                          prev_block_check_cb, pager);
+   efl_pack_end(box, c);
 
-   efl_add(EFL_UI_CHECK_CLASS, box,
-           efl_ui_widget_style_set(efl_added, "toggle"),
-           efl_text_set(efl_added, "Next Block"),
-           efl_ui_nstate_value_set(efl_added, next),
-           efl_event_callback_add(efl_added, EFL_UI_CHECK_EVENT_CHANGED,
-                                  next_block_check_cb, pager),
-           efl_pack_end(box, efl_added));
+   c = efl_add(EFL_UI_CHECK_CLASS, box);
+   efl_ui_widget_style_set(c, "toggle");
+   efl_text_set(c, "Next Block");
+   efl_ui_selectable_selected_set(c, next);
+   efl_event_callback_add(c, EFL_UI_EVENT_SELECTED_CHANGED,
+                          next_block_check_cb, pager);
+   efl_pack_end(box, c);
 }
 
 static void loop_cb(void *data EINA_UNUSED,
@@ -798,25 +817,47 @@ static void loop_cb(void *data EINA_UNUSED,
    Params *params = (Params *)data;
    Evas_Object *navi = params->navi;
    Eo *pager = params->pager;
-   Eo *btn, *box;
+   Eo *btn, *box, *rd;
+   Efl_Ui_Pager_Loop loop;
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
-   box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+   box = efl_add(EFL_UI_RADIO_BOX_CLASS, navi,
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
 		 elm_naviframe_item_push(navi, "Loop", btn, NULL,
                                          efl_added, NULL));
 
-   efl_add(EFL_UI_CHECK_CLASS, box,
-           efl_ui_widget_style_set(efl_added, "toggle"),
-           efl_text_set(efl_added, "Loop"),
-           efl_ui_nstate_value_set(efl_added, efl_ui_pager_loop_mode_get(pager)),
-           efl_event_callback_add(efl_added, EFL_UI_CHECK_EVENT_CHANGED,
-                                  loop_check_cb, pager),
-           efl_pack_end(box, efl_added));
+   rd = efl_add(EFL_UI_RADIO_CLASS, box);
+   efl_ui_radio_state_value_set(rd, EFL_UI_PAGER_LOOP_DISABLED);
+   efl_text_set(rd, "Disabled");
+   efl_gfx_hint_weight_set(rd, 1, 0);
+   efl_event_callback_add(rd, EFL_UI_EVENT_SELECTED_CHANGED,
+                          loop_radio_cb, pager);
+   efl_pack(box, rd);
+
+   rd = efl_add(EFL_UI_RADIO_CLASS, box);
+   efl_ui_radio_state_value_set(rd, EFL_UI_PAGER_LOOP_ENABLED);
+   efl_text_set(rd, "Enabled");
+   efl_gfx_hint_weight_set(rd, 1, 0);
+   efl_event_callback_add(rd, EFL_UI_EVENT_SELECTED_CHANGED,
+                          loop_radio_cb, pager);
+   efl_pack(box, rd);
+
+   loop = efl_ui_pager_loop_mode_get(pager);
+
+   efl_ui_radio_group_selected_value_set(efl_ui_radio_box_group_get(box), loop);
+
+   if (loop == EFL_UI_PAGER_LOOP_DISABLED)
+     {
+        Eina_Bool ret = efl_ui_pager_loop_mode_set(pager, EFL_UI_PAGER_LOOP_ENABLED);
+        if (!ret)
+          elm_object_disabled_set(rd, EINA_TRUE);
+        else
+          efl_ui_pager_loop_mode_set(pager, EFL_UI_PAGER_LOOP_DISABLED);
+     }
 }
 
 static void indicator_cb(void *data EINA_UNUSED,
@@ -829,23 +870,23 @@ static void indicator_cb(void *data EINA_UNUSED,
 
    btn = efl_add(EFL_UI_BUTTON_CLASS, navi,
                  efl_text_set(efl_added, "Back"),
-                 efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                 efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                         back_btn_cb, navi));
 
    box = efl_add(EFL_UI_BOX_CLASS, navi,
-                 efl_pack_padding_set(efl_added, 10, 10, EINA_TRUE),
+                 efl_gfx_arrangement_content_padding_set(efl_added, 10, 10, EINA_TRUE),
                  elm_naviframe_item_push(navi, "Indicator", btn, NULL,
                                          efl_added, NULL));
 
    efl_add(EFL_UI_BUTTON_CLASS, box,
            efl_text_set(efl_added, "Icon Type"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   indicator_icon_btn_cb, params),
            efl_pack_end(box, efl_added));
 
    efl_add(EFL_UI_BUTTON_CLASS, box,
            efl_text_set(efl_added, "None"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                   indicator_none_btn_cb, params),
            efl_pack_end(box, efl_added));
 }
@@ -860,8 +901,7 @@ void test_ui_pager_scroll(void *data EINA_UNUSED,
    int i;
 
    win = efl_add(EFL_UI_WIN_CLASS, efl_main_loop_get(),
-                 efl_ui_win_type_set(efl_added, EFL_UI_WIN_TYPE_BASIC),
-                 efl_text_set(efl_added, "Pager"),
+                                  efl_text_set(efl_added, "Pager"),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
 
    panes = efl_add(EFL_UI_PANES_CLASS, win,
@@ -895,13 +935,13 @@ void test_ui_pager_scroll(void *data EINA_UNUSED,
    efl_add(EFL_UI_BUTTON_CLASS, layout,
            efl_text_set(efl_added, "Prev"),
            efl_event_callback_add(efl_added,
-                                  EFL_UI_EVENT_CLICKED, prev_btn_cb, pager),
+                                  EFL_INPUT_EVENT_CLICKED, prev_btn_cb, pager),
            efl_content_set(efl_part(layout, "prev_btn"), efl_added));
 
    efl_add(EFL_UI_BUTTON_CLASS, layout,
            efl_text_set(efl_added, "Next"),
            efl_event_callback_add(efl_added,
-                                  EFL_UI_EVENT_CLICKED, next_btn_cb, pager),
+                                  EFL_INPUT_EVENT_CLICKED, next_btn_cb, pager),
            efl_content_set(efl_part(layout, "next_btn"), efl_added));
 
    tran = efl_add(EFL_PAGE_TRANSITION_SCROLL_CLASS, pager,
