@@ -9,6 +9,10 @@ typedef struct _pbdata
    Eo *win;
    Eo *pb1;
    Eo *pb2;
+   Eo *pb3;
+   Eo *pb4;
+   Eo *pb5;
+   Eo *check;
    Eo *btn_start;
    Eo *btn_stop;
    Eo *btn_reset;
@@ -45,6 +49,9 @@ _pb_timer_cb(void *d)
      {
         progress_val += 1;
         efl_ui_range_value_set(pd->pb2, progress_val);
+        efl_ui_range_value_set(pd->pb3, progress_val);
+        efl_ui_range_value_set(pd->pb4, progress_val);
+        efl_ui_range_value_set(pd->pb5, progress_val);
      }
 
    if (!_set_progress_val(pd->pb1, 0.5))
@@ -97,6 +104,9 @@ _reset_btn_clicked_cb(void *d, const Efl_Event *ev EINA_UNUSED)
 
    efl_ui_range_value_set(pd->pb1, 0.0);
    efl_ui_range_value_set(pd->pb2, 0.0);
+   efl_ui_range_value_set(pd->pb3, 0.0);
+   efl_ui_range_value_set(pd->pb4, 0.0);
+   efl_ui_range_value_set(pd->pb5, 0.0);
 }
 
 static void
@@ -109,6 +119,29 @@ _win_delete_req_cb(void *d, const Efl_Event *ev EINA_UNUSED)
    free(pd);
 }
 
+static Eina_Bool
+_custom_format_cb(void *data EINA_UNUSED, Eina_Strbuf *str, const Eina_Value value)
+{
+   double v;
+   eina_value_get(&value, &v);
+   if (v < 25.f) eina_strbuf_append_printf(str, "Starting up...");
+   else if (v < 50.f) eina_strbuf_append_printf(str, "Working...");
+   else if (v < 75.f) eina_strbuf_append_printf(str, "Getting there...");
+   else if (v < 100.f) eina_strbuf_append_printf(str, "Almost done...");
+   else eina_strbuf_append_printf(str, "Done!");
+   return EINA_TRUE;
+}
+
+static void
+_toggle_progress_label(void *data, const Efl_Event *ev)
+{
+   Efl_Ui_Check *check = ev->object;
+   Efl_Ui_Progressbar *pb3 = data;
+   Eina_Bool state = efl_ui_selectable_selected_get(check);
+
+   efl_ui_progressbar_show_progress_label_set(pb3, state);
+}
+
 void
 test_ui_progressbar(void *data EINA_UNUSED, Eo *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
@@ -119,8 +152,7 @@ test_ui_progressbar(void *data EINA_UNUSED, Eo *obj EINA_UNUSED, void *event_inf
    pd = (pbdata *)calloc(1, sizeof(pbdata));
 
    pd->win = win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
-                           efl_ui_win_type_set(efl_added, EFL_UI_WIN_TYPE_BASIC),
-                           efl_text_set(efl_added, "Efl.Ui.Progressbar"),
+                                                      efl_text_set(efl_added, "Efl.Ui.Progressbar"),
                            efl_ui_win_autodel_set(efl_added, EINA_TRUE),
                            efl_event_callback_add(efl_added, EFL_UI_WIN_EVENT_DELETE_REQUEST,
                                                   _win_delete_req_cb, pd)
@@ -133,7 +165,7 @@ test_ui_progressbar(void *data EINA_UNUSED, Eo *obj EINA_UNUSED, void *event_inf
    pd->pb1 = efl_add(EFL_UI_PROGRESSBAR_CLASS, bx,
                      efl_pack(bx, efl_added),
                      efl_text_set(efl_added, "percent"),
-                     efl_ui_range_min_max_set(efl_added, 0, 100),
+                     efl_ui_range_limits_set(efl_added, 0, 100),
                      efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(250, 20))
                     );
 
@@ -149,31 +181,62 @@ test_ui_progressbar(void *data EINA_UNUSED, Eo *obj EINA_UNUSED, void *event_inf
                      efl_text_set(efl_added, "10-100"),
                      efl_ui_progressbar_pulse_set(efl_added, EINA_TRUE),
                      efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(250, 20)),
-                     efl_ui_range_min_max_set(efl_added, 10, 100),
+                     efl_ui_range_limits_set(efl_added, 10, 100),
                      efl_ui_range_value_set(efl_added, 10)
                     );
 
+   pd->pb3 = efl_add(EFL_UI_PROGRESSBAR_CLASS, bx,
+                     efl_pack(bx, efl_added),
+                     efl_text_set(efl_added, "Toggle progress label"),
+                     efl_ui_range_limits_set(efl_added, 0, 100),
+                     efl_ui_progressbar_show_progress_label_set(efl_added, EINA_FALSE),
+                     efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(250, 20))
+                    );
+   pd->check = efl_add(EFL_UI_CHECK_CLASS, bx,
+                       efl_pack(bx, efl_added),
+                       efl_event_callback_add(efl_added, EFL_UI_EVENT_SELECTED_CHANGED,
+                                              _toggle_progress_label, pd->pb3),
+                       efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(250, 20))
+                      );
+   efl_text_set(pd->check, "Show progress label of above progressbar"),
+
+   pd->pb4 = efl_add(EFL_UI_PROGRESSBAR_CLASS, bx,
+                     efl_pack(bx, efl_added),
+                     efl_text_set(efl_added, "Custom string"),
+                     efl_ui_range_limits_set(efl_added, 0, 100),
+                     efl_ui_format_string_set(efl_added, "%d rabbits", EFL_UI_FORMAT_STRING_TYPE_SIMPLE),
+                     efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(250, 20))
+                    );
+
+   pd->pb5 = efl_add(EFL_UI_PROGRESSBAR_CLASS, bx,
+                     efl_pack(bx, efl_added),
+                     efl_text_set(efl_added, "Custom func"),
+                     efl_ui_range_limits_set(efl_added, 0, 100),
+                     efl_ui_format_func_set(efl_added, NULL, _custom_format_cb, NULL),
+                     efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(250, 20))
+                    );
+
    btbx = efl_add(EFL_UI_BOX_CLASS, bx,
                   efl_pack(bx, efl_added),
-                  efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL)
+                  efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL)
                  );
 
    pd->btn_start = efl_add(EFL_UI_BUTTON_CLASS, btbx,
                            efl_text_set(efl_added, "start"),
-                           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                                   _start_btn_clicked_cb, pd),
                            efl_pack(btbx, efl_added)
                           );
 
    pd->btn_stop = efl_add(EFL_UI_BUTTON_CLASS, btbx,
                           efl_text_set(efl_added, "stop"),
-                          efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                          efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                                  _stop_btn_clicked_cb, pd),
                           efl_pack(btbx, efl_added)
                          );
    pd->btn_reset = efl_add(EFL_UI_BUTTON_CLASS, btbx,
                            efl_text_set(efl_added, "reset"),
-                           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED,
+                           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED,
                                                   _reset_btn_clicked_cb, pd),
                            efl_pack(btbx, efl_added)
                           );
