@@ -3,7 +3,7 @@
 #endif
 #include <Efl_Ui.h>
 #include <Elementary.h>
-
+#include "elm_priv.h" //FIXME remove this once efl.ui.text doesn't need elm_general.h
 static double
 _step_size_calculate(double min, double max)
 {
@@ -34,8 +34,7 @@ test_slider_interval(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
    double step;
 
    win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
-                 efl_ui_win_type_set(efl_added, EFL_UI_WIN_TYPE_BASIC),
-                 efl_text_set(efl_added, "Efl.Ui.Slider_Interval"),
+                                  efl_text_set(efl_added, "Efl.Ui.Slider_Interval"),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
 
    bx = efl_add(EFL_UI_BOX_CLASS, win,
@@ -70,7 +69,7 @@ test_slider_interval(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
 
    efl_add(EFL_UI_SLIDER_INTERVAL_CLASS, bx,
            efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(120, 0)),
-           efl_ui_range_min_max_set(efl_added, 10, 145),
+           efl_ui_range_limits_set(efl_added, 10, 145),
            efl_ui_slider_interval_value_set(efl_added, 50, 100),
            efl_ui_range_step_set(efl_added, step),
            elm_object_disabled_set(efl_added, EINA_TRUE),
@@ -82,23 +81,23 @@ test_slider_interval(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
            efl_pack(bx, efl_added));
 
    hbx = efl_add(EFL_UI_BOX_CLASS, bx,
-                 efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
+                 efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL),
                  efl_pack(bx, efl_added));
 
    efl_add(EFL_UI_SLIDER_INTERVAL_CLASS, hbx,
            efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(0, 160)),
-           efl_ui_range_min_max_set(efl_added, 10, 145),
+           efl_ui_range_limits_set(efl_added, 10, 145),
            efl_ui_slider_interval_value_set(efl_added, 50, 100),
            efl_ui_range_step_set(efl_added, step),
-           efl_ui_direction_set(efl_added, EFL_UI_DIR_VERTICAL),
+           efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL),
            efl_pack(hbx, efl_added));
 
    efl_add(EFL_UI_SLIDER_INTERVAL_CLASS, hbx,
            efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(0, 160)),
-           efl_ui_range_min_max_set(efl_added, 10, 145),
+           efl_ui_range_limits_set(efl_added, 10, 145),
            efl_ui_slider_interval_value_set(efl_added, 50, 100),
            efl_ui_range_step_set(efl_added, step),
-           efl_ui_direction_set(efl_added, EFL_UI_DIR_VERTICAL),
+           efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL),
            elm_object_disabled_set(efl_added, EINA_TRUE),
            efl_pack(hbx, efl_added));
 
@@ -109,9 +108,9 @@ test_slider_interval(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void
 
    efl_add(EFL_UI_SLIDER_INTERVAL_CLASS, bx,
            efl_gfx_hint_size_min_set(efl_added, EINA_SIZE2D(260, 0)),
-           efl_ui_range_min_max_set(efl_added, 0, 600),
+           efl_ui_range_limits_set(efl_added, 0, 600),
            efl_ui_slider_interval_value_set(efl_added, 100, 500),
            efl_ui_range_step_set(efl_added, step),
-           efl_event_callback_add(efl_added, EFL_UI_SLIDER_EVENT_CHANGED, _intv_slider_changed_cb, NULL),
+           efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_CHANGED, _intv_slider_changed_cb, NULL),
            efl_pack(bx, efl_added));
 }
