@@ -4,6 +4,8 @@
 #include <Efl_Ui.h>
 #include <Elementary.h>
 
+#define STEP_SIZE 2
+
 static void
 _spin_changed_cb(void *data EINA_UNUSED, const Efl_Event *ev)
 {
@@ -23,13 +25,13 @@ _spin_max_reached_cb(void *data EINA_UNUSED, const Efl_Event *ev)
 static void
 _inc_clicked(void *data, const Efl_Event *ev EINA_UNUSED)
 {
-   efl_ui_range_value_set(data, (efl_ui_range_value_get(data) + efl_ui_range_step_get(data)));
+   efl_ui_range_value_set(data, (efl_ui_range_value_get(data) + STEP_SIZE));
 }
 
 static void
 _dec_clicked(void *data, const Efl_Event *ev EINA_UNUSED)
 {
-   efl_ui_range_value_set(data, (efl_ui_range_value_get(data) - efl_ui_range_step_get(data)));
+   efl_ui_range_value_set(data, (efl_ui_range_value_get(data) - STEP_SIZE));
 }
 
 void
@@ -38,32 +40,30 @@ test_ui_spin(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_i
    Eo *win, *bx, *sp;
 
    win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
-                 efl_ui_win_type_set(efl_added, EFL_UI_WIN_TYPE_BASIC),
-                 efl_text_set(efl_added, "Efl.Ui.Spin"),
+                                  efl_text_set(efl_added, "Efl.Ui.Spin"),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
 
    bx = efl_add(EFL_UI_BOX_CLASS, win,
                 efl_content_set(win, efl_added),
-                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN));
+                efl_ui_layout_orientation_set(efl_added, EFL_UI_LAYOUT_ORIENTATION_VERTICAL));
 
    sp = efl_add(EFL_UI_SPIN_CLASS, bx,
-                efl_ui_range_min_max_set(efl_added, 0, 10),
+                efl_ui_range_limits_set(efl_added, 0, 10),
                 efl_ui_range_value_set(efl_added, 6),
-                efl_ui_range_step_set(efl_added, 2),
-                efl_ui_format_string_set(efl_added, "test %d"),
-                efl_event_callback_add(efl_added, EFL_UI_SPIN_EVENT_CHANGED,_spin_changed_cb, NULL),
-                efl_event_callback_add(efl_added, EFL_UI_SPIN_EVENT_MIN_REACHED,_spin_min_reached_cb, NULL),
-                efl_event_callback_add(efl_added, EFL_UI_SPIN_EVENT_MAX_REACHED,_spin_max_reached_cb, NULL),
+                efl_ui_format_string_set(efl_added, "test %d", EFL_UI_FORMAT_STRING_TYPE_SIMPLE),
+                efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_CHANGED,_spin_changed_cb, NULL),
+                efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_MIN_REACHED,_spin_min_reached_cb, NULL),
+                efl_event_callback_add(efl_added, EFL_UI_RANGE_EVENT_MAX_REACHED,_spin_max_reached_cb, NULL),
                 efl_pack(bx, efl_added));
 
    efl_add(EFL_UI_BUTTON_CLASS, bx,
            efl_text_set(efl_added, "Increse Spinner value"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _inc_clicked, sp),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED, _inc_clicked, sp),
            efl_pack(bx, efl_added));
 
    efl_add(EFL_UI_BUTTON_CLASS, bx,
            efl_text_set(efl_added, "Decrease Spinner value"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _dec_clicked, sp),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED, _dec_clicked, sp),
            efl_pack(bx, efl_added));
 
    efl_gfx_entity_size_set(win, EINA_SIZE2D(100, 120));
