@@ -93,8 +93,7 @@ test_win_indicator(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *e
 
    // FIXME: Resizing window should no cause sizing issues!
    win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
-                 efl_ui_win_type_set(efl_added, EFL_UI_WIN_TYPE_BASIC),
-                 efl_text_set(efl_added, "Efl.Win.Indicator"),
+                                  efl_text_set(efl_added, "Efl.Win.Indicator"),
                  efl_gfx_hint_size_max_set(efl_added, EINA_SIZE2D(300, -1)),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
    efl_event_callback_add(win, EFL_EVENT_DEL, _win_del, indicator);
@@ -106,18 +105,18 @@ test_win_indicator(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *e
 
    efl_add(EFL_UI_BUTTON_CLASS, win,
            efl_text_set(efl_added, "Indicator Off"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _off_clicked, win),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED, _off_clicked, win),
            efl_pack(bx, efl_added));
    efl_add(EFL_UI_BUTTON_CLASS, win,
            efl_text_set(efl_added, "Bg Opaque"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _opaque_clicked, win),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED, _opaque_clicked, win),
            efl_pack(bx, efl_added));
    efl_add(EFL_UI_BUTTON_CLASS, win,
            efl_text_set(efl_added, "Bg Transparent"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _transparent_clicked, win),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED, _transparent_clicked, win),
            efl_pack(bx, efl_added));
    efl_add(EFL_UI_BUTTON_CLASS, win,
            efl_text_set(efl_added, "Hidden"),
-           efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _hidden_clicked, win),
+           efl_event_callback_add(efl_added, EFL_INPUT_EVENT_CLICKED, _hidden_clicked, win),
            efl_pack(bx, efl_added));
 }
