@@ -9,11 +9,11 @@ static Eina_Hash *_funcs_params_init_get = NULL;
 static Eina_Hash *_funcs_params_init_set = NULL;
 
 static const char *
-_get_add_star(Eolian_Function_Type ftype, Eolian_Parameter_Dir pdir)
+_get_add_star(Eolian_Function_Type ftype, Eolian_Parameter_Direction pdir)
 {
    if (ftype == EOLIAN_PROP_GET)
      return "*";
-   if ((pdir == EOLIAN_OUT_PARAM) || (pdir == EOLIAN_INOUT_PARAM))
+   if ((pdir == EOLIAN_PARAMETER_OUT) || (pdir == EOLIAN_PARAMETER_INOUT))
      return "*";
    return "";
 }
@@ -103,11 +103,11 @@ _gen_func_pointer_param(const char *name, Eina_Stringshare *c_type,
 }
 
 static void
-_append_defval(Eina_Strbuf *buf, const Eolian_Expression *exp, const Eolian_Type *tp)
+_append_defval(Eina_Strbuf *buf, const Eolian_Expression *exp, const Eolian_Type *tp, const char *ctp)
 {
    if (exp)
      {
-        Eolian_Value val = eolian_expression_eval_type(exp, tp);
+        Eolian_Value val = eolian_expression_eval(exp, EOLIAN_MASK_ALL);
         Eina_Stringshare *lit = eolian_expression_value_to_literal(&val);
         if (lit)
           {
@@ -123,7 +123,7 @@ _append_defval(Eina_Strbuf *buf, const Eolian_Expression *exp, const Eolian_Type
      }
    /* default value or fallback */
    const Eolian_Type *btp = eolian_type_aliased_base_get(tp);
-   if (eolian_type_is_ptr(btp))
+   if (eolian_type_is_ptr(btp) || strchr(ctp, '*'))
      {
         eina_strbuf_append(buf, "NULL");
         return;
@@ -139,21 +139,58 @@ _append_defval(Eina_Strbuf *buf, const Eolian_Expression *exp, const Eolian_Type
         free(sn);
         return;
      }
-   Eina_Stringshare *ctp = eolian_type_c_type_get(btp, EOLIAN_C_TYPE_DEFAULT);
-   if (strchr(ctp, '*'))
-     {
-        eina_strbuf_append(buf, "NULL");
-        return;
-     }
-   eina_stringshare_del(ctp);
    /* enums and remaining regulars... 0 should do */
    eina_strbuf_append(buf, "0");
 }
 
+static const char *
+_free_func_get(const Eolian_Type *type)
+{
+   const Eolian_Type *ab = eolian_type_aliased_base_get(type);
+   switch (eolian_type_builtin_type_get(ab))
+     {
+      /* simple types */
+      case EOLIAN_TYPE_BUILTIN_MSTRING:
+        return "free";
+      case EOLIAN_TYPE_BUILTIN_STRINGSHARE:
+        return "eina_stringshare_del";
+      case EOLIAN_TYPE_BUILTIN_ANY_VALUE:
+        return "eina_value_flush";
+      case EOLIAN_TYPE_BUILTIN_ANY_VALUE_REF:
+        return "eina_value_free";
+      case EOLIAN_TYPE_BUILTIN_STRBUF:
+        return "eina_strbuf_free";
+      case EOLIAN_TYPE_BUILTIN_BINBUF:
+        return "eina_binbuf_free";
+      /* complex types */
+      case EOLIAN_TYPE_BUILTIN_ACCESSOR:
+        return "eina_accessor_free";
+      case EOLIAN_TYPE_BUILTIN_ARRAY:
+        return "eina_array_free";
+      case EOLIAN_TYPE_BUILTIN_FUTURE:
+        return "(void)";
+      case EOLIAN_TYPE_BUILTIN_ITERATOR:
+        return "eina_iterator_free";
+      case EOLIAN_TYPE_BUILTIN_HASH:
+        return "eina_hash_free";
+      case EOLIAN_TYPE_BUILTIN_LIST:
+        return "eina_list_free";
+      /* class and user types */
+      case EOLIAN_TYPE_BUILTIN_INVALID:
+        if (eolian_type_type_get(ab) == EOLIAN_TYPE_CLASS)
+          return "efl_del";
+        else
+          return eolian_typedecl_free_func_get(eolian_type_typedecl_get(ab));
+      /* no free func */
+      default:
+        return NULL;
+     }
+}
+
 static void
 _generate_normal_free(Eina_Strbuf **buf, const Eolian_Type *type, const Eina_Strbuf *parameter, const char *additional_intention)
 {
-   const char *free_func = eolian_type_free_func_get(type);
+   const char *free_func = _free_func_get(type);
    if (!free_func)
      {
         printf("No free type %s\n", eolian_type_short_name_get(type));
@@ -193,7 +230,7 @@ _generate_iterative_free(Eina_Strbuf **buf, const Eolian_Type *type, const Eolia
    eina_strbuf_append_printf(iter_param, "%s_iter", eolian_parameter_name_get(parameter));
 
    //generate the field definition
-   eina_strbuf_append_printf(*buf, "   %s", eolian_type_c_type_get(inner_type, EOLIAN_C_TYPE_DEFAULT));
+   eina_strbuf_append_printf(*buf, "   %s", eolian_type_c_type_get(inner_type));
    eina_strbuf_append_buffer(*buf, iter_param);
    eina_strbuf_append(*buf, ";\n");
 
@@ -230,7 +267,7 @@ _generate_iterative_free(Eina_Strbuf **buf, const Eolian_Type *type, const Eolia
      {
         eina_strbuf_append_printf(*buf,"   eina_hash_free_cb_set(");
         eina_strbuf_append_buffer(*buf, param);
-        eina_strbuf_append_printf(*buf, ",%s);\n",eolian_type_free_func_get(inner_type));
+        eina_strbuf_append_printf(*buf, ",%s);\n",_free_func_get(inner_type));
         eina_strbuf_append_printf(*buf,"   eina_hash_free(");
         eina_strbuf_append_buffer(*buf, param);
         eina_strbuf_append(*buf, ");\n");
@@ -270,7 +307,7 @@ _gen_function_param_fallback(Eina_Iterator *itr, Eina_Strbuf *fallback_free_owne
         inner_type = eolian_type_base_type_get(type);
 
         //check if they should be freed or just ignored
-        if (!eolian_type_is_owned(type) || eolian_parameter_direction_get(pr) == EOLIAN_OUT_PARAM)
+        if (!eolian_parameter_is_move(pr) || eolian_parameter_direction_get(pr) == EOLIAN_PARAMETER_OUT)
           {
              eina_strbuf_append_printf(fallback_free_ownership, "   (void)%s;\n", eolian_parameter_name_get(pr));
              continue;
@@ -280,16 +317,16 @@ _gen_function_param_fallback(Eina_Iterator *itr, Eina_Strbuf *fallback_free_owne
 
         eina_strbuf_reset(param_call);
 
-        if (eolian_parameter_direction_get(pr) == EOLIAN_INOUT_PARAM)
+        if (eolian_parameter_direction_get(pr) == EOLIAN_PARAMETER_INOUT)
           eina_strbuf_append_char(param_call, '*');
         eina_strbuf_append(param_call, eolian_parameter_name_get(pr));
 
         //check if we might want to free or handle the children
-        if (!inner_type || !eolian_type_is_owned(inner_type))
+        if (!inner_type || !eolian_type_is_move(inner_type))
           {
              _generate_normal_free(&fallback_free_ownership, type, param_call, "");
           }
-        else if (inner_type && eolian_type_is_owned(inner_type))
+        else if (inner_type && eolian_type_is_move(inner_type))
           {
              _generate_iterative_free(&fallback_free_ownership, type, inner_type, pr, param_call);
           }
@@ -333,9 +370,11 @@ _get_reflect_initf(const Eolian_Type *abtp)
 }
 
 static void
-_gen_reflect_get(Eina_Strbuf *buf, const char *cnamel, const Eolian_Type *valt,
+_gen_reflect_get(Eina_Strbuf *buf, const char *cnamel,
+                 const Eolian_Function_Parameter *pr,
                  const Eolian_Function *fid, Eina_Hash *refh)
 {
+   const Eolian_Type *valt = eolian_parameter_type_get(pr);
    if (eolian_type_is_ptr(valt))
      return;
 
@@ -355,7 +394,7 @@ _gen_reflect_get(Eina_Strbuf *buf, const char *cnamel, const Eolian_Type *valt,
      cnamel, eolian_function_name_get(fid));
    eina_strbuf_append(buf, "{\n");
 
-   Eina_Stringshare *ct = eolian_type_c_type_get(valt, EOLIAN_C_TYPE_RETURN);
+   Eina_Stringshare *ct = eolian_parameter_c_type_get(pr, EINA_TRUE);
    const char *starsp = (ct[strlen(ct) - 1] != '*') ? " " : "";
 
    Eina_Stringshare *fcn = eolian_function_full_c_name_get(fid, EOLIAN_PROP_GET);
@@ -368,9 +407,11 @@ _gen_reflect_get(Eina_Strbuf *buf, const char *cnamel, const Eolian_Type *valt,
 }
 
 static void
-_gen_reflect_set(Eina_Strbuf *buf, const char *cnamel, const Eolian_Type *valt,
+_gen_reflect_set(Eina_Strbuf *buf, const char *cnamel,
+                 const Eolian_Function_Parameter *pr,
                  const Eolian_Function *fid, Eina_Hash *refh)
 {
+   const Eolian_Type *valt = eolian_parameter_type_get(pr);
    if (eolian_type_is_ptr(valt))
      return;
 
@@ -391,7 +432,7 @@ _gen_reflect_set(Eina_Strbuf *buf, const char *cnamel, const Eolian_Type *valt,
    eina_strbuf_append(buf, "{\n");
    eina_strbuf_append(buf, "   Eina_Error r = 0;");
 
-   Eina_Stringshare *ct = eolian_type_c_type_get(valt, EOLIAN_C_TYPE_PARAM);
+   Eina_Stringshare *ct = eolian_parameter_c_type_get(pr, EINA_FALSE);
    const char *starsp = (ct[strlen(ct) - 1] != '*') ? " " : "";
    eina_strbuf_append_printf(buf, "   %s%scval;\n", ct, starsp);
    eina_stringshare_del(ct);
@@ -414,14 +455,11 @@ _gen_reflect_set(Eina_Strbuf *buf, const char *cnamel, const Eolian_Type *valt,
 }
 
 static void
-_emit_class_function(Eina_Strbuf *buf, const Eolian_Function *fid, const Eolian_Type *rtp, Eina_Strbuf *params_full,
+_emit_class_function(Eina_Strbuf *buf, const Eolian_Function *fid, const char *rtpn, Eina_Strbuf *params_full,
                      const char *ocnamel, const char *func_suffix, Eina_Strbuf *params, const char *function_name)
 {
    eina_strbuf_append(buf, "EOAPI ");
-   if (rtp)
-     eina_strbuf_append(buf, eolian_type_c_type_get(rtp, EOLIAN_C_TYPE_RETURN));
-   else
-     eina_strbuf_append(buf, "void");
+   eina_strbuf_append(buf, rtpn);
    eina_strbuf_append(buf, " ");
    eina_strbuf_append(buf, function_name);
    eina_strbuf_append(buf, "(");
@@ -432,7 +470,7 @@ _emit_class_function(Eina_Strbuf *buf, const Eolian_Function *fid, const Eolian_
    eina_strbuf_append(buf, ")\n");
    eina_strbuf_append(buf, "{\n");
    eina_strbuf_append_printf(buf, "   %s();\n", eolian_class_c_get_function_name_get(eolian_function_class_get(fid)));
-   if (rtp)
+   if (strcmp(rtpn, "void"))
      eina_strbuf_append(buf, "   return ");
    else
      eina_strbuf_append(buf, "   ");
@@ -460,14 +498,16 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
    Eina_Bool is_prop = (ftype == EOLIAN_PROP_GET || ftype == EOLIAN_PROP_SET);
    Eina_Bool var_as_ret = EINA_FALSE;
    /* assume we're not generating reflection api by default */
-   const Eolian_Type *reflect_type = NULL;
+   const Eolian_Function_Parameter *reflect_param = NULL;
 
    const Eolian_Expression *def_ret = NULL;
    const Eolian_Type *rtp = eolian_function_return_type_get(fid, ftype);
+   Eina_Stringshare *rtpn = NULL;
    if (rtp)
      {
         is_auto = EINA_FALSE; /* can't do auto if func returns */
         def_ret = eolian_function_return_default_value_get(fid, ftype);
+        rtpn = eolian_function_return_c_type_get(fid, ftype);
      }
 
    const char *func_suffix = "";
@@ -483,9 +523,11 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
                   Eolian_Function_Parameter *pr = d1;
                   rtp = eolian_parameter_type_get(pr);
                   /* reflect only when returning 1 val */
-                  reflect_type = rtp;
+                  if (!eolian_parameter_is_by_ref(pr))
+                    reflect_param = pr;
                   var_as_ret = EINA_TRUE;
                   def_ret = eolian_parameter_default_value_get(pr);
+                  rtpn = eolian_parameter_c_type_get(pr, EINA_TRUE);
                }
              eina_iterator_free(itr);
           }
@@ -499,7 +541,8 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
         if (eina_iterator_next(itr, &d1) && !eina_iterator_next(itr, &d2))
           {
              Eolian_Function_Parameter *pr = d1;
-             reflect_type = eolian_parameter_type_get(pr);
+             if (!eolian_parameter_is_by_ref(pr))
+               reflect_param = pr;
           }
         eina_iterator_free(itr);
      }
@@ -514,19 +557,18 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
    {
       Eina_Iterator *itr = eolian_property_keys_get(fid, ftype);
       if (itr) /* has keys: no reflection */
-        reflect_type = NULL;
+        reflect_param = NULL;
       Eolian_Function_Parameter *pr;
       EINA_ITERATOR_FOREACH(itr, pr)
         {
            const char *prn = eolian_parameter_name_get(pr);
-           const Eolian_Type *pt = eolian_parameter_type_get(pr);
-           Eina_Stringshare *ptn = eolian_type_c_type_get(pt, EOLIAN_C_TYPE_PARAM);
+           Eina_Stringshare *ptn = eolian_parameter_c_type_get(pr, EINA_FALSE);
 
            if (eina_strbuf_length_get(params))
              eina_strbuf_append(params, ", ");
            eina_strbuf_append(params, prn);
 
-           if (eina_strbuf_length_get(params_full) || !eolian_function_is_class(fid))
+           if (eina_strbuf_length_get(params_full) || !eolian_function_is_static(fid))
              {
                 eina_strbuf_append(params_full, ", ");
                 eina_strbuf_append(params_full_imp, ", ");
@@ -596,11 +638,11 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
         Eolian_Function_Parameter *pr;
         EINA_ITERATOR_FOREACH(itr, pr)
           {
-             Eolian_Parameter_Dir pd = eolian_parameter_direction_get(pr);
+             Eolian_Parameter_Direction pd = eolian_parameter_direction_get(pr);
              const Eolian_Expression *dfv = eolian_parameter_default_value_get(pr);
              const char *prn = eolian_parameter_name_get(pr);
              const Eolian_Type *pt = eolian_parameter_type_get(pr);
-             Eina_Stringshare *ptn = eolian_type_c_type_get(pt, EOLIAN_C_TYPE_PARAM);
+             Eina_Stringshare *ptn = eolian_parameter_c_type_get(pr, EINA_FALSE);
              const Eolian_Typedecl *ptd = eolian_type_typedecl_get(pt);
 
              Eina_Bool had_star = ptn[strlen(ptn) - 1] == '*';
@@ -616,7 +658,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
              if (eina_strbuf_length_get(params))
                eina_strbuf_append(params, ", ");
 
-             if (eina_strbuf_length_get(params_full_imp) || !eolian_function_is_class(fid))
+             if (eina_strbuf_length_get(params_full_imp) || !eolian_function_is_static(fid))
                eina_strbuf_append(params_full_imp, ", ");
              eina_strbuf_append(params_full_imp, ptn);
              if (!had_star)
@@ -627,7 +669,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
                eina_strbuf_append(params_full_imp, " EINA_UNUSED");
              eina_strbuf_append(params, prn);
 
-             if (eina_strbuf_length_get(params_full) || !eolian_function_is_class(fid))
+             if (eina_strbuf_length_get(params_full) || !eolian_function_is_static(fid))
                eina_strbuf_append(params_full, ", ");
              eina_strbuf_append(params_full, ptn);
              if (!had_star)
@@ -674,8 +716,8 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
    if (impl_same_class && eolian_implement_is_pure_virtual(impl, ftype))
      impl_need = EINA_FALSE;
 
-   Eina_Stringshare *rtpn = rtp ? eolian_type_c_type_get(rtp, EOLIAN_C_TYPE_RETURN)
-                                : eina_stringshare_add("void");
+   if (!rtpn)
+     rtpn = eina_stringshare_add("void");
 
    char *cname = NULL, *cnamel = NULL, *ocnamel = NULL;
    eo_gen_class_names_get(cl, &cname, NULL, &cnamel);
@@ -685,7 +727,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
      {
         /* figure out the data type */
         Eina_Stringshare *dt = NULL;
-        if (eolian_function_is_class(fid))
+        if (eolian_function_is_static(fid))
           dt = eina_stringshare_add("void");
         else
           dt = eolian_class_c_data_type_get(cl);
@@ -707,7 +749,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
              eina_strbuf_append(buf, func_suffix);
              /* ([const ]Eo *obj, Data_Type *pd, impl_full_params); */
              eina_strbuf_append_char(buf, '(');
-             if (!eolian_function_is_class(fid))
+             if (!eolian_function_is_static(fid))
                {
                   if ((ftype == EOLIAN_PROP_GET) || eolian_function_object_is_const(fid))
                     eina_strbuf_append(buf, "const ");
@@ -716,7 +758,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
                   eina_strbuf_append(buf, " *pd");
                }
              eina_strbuf_append(buf, eina_strbuf_string_get(params_full_imp));
-             if (eina_strbuf_length_get(params_full_imp) == 0 && eolian_function_is_class(fid))
+             if (eina_strbuf_length_get(params_full_imp) == 0 && eolian_function_is_static(fid))
                eina_strbuf_append(buf, "void");
              eina_strbuf_append(buf, ");\n\n");
           }
@@ -763,7 +805,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
              if (rtp)
                {
                   eina_strbuf_append(buf, "   return ");
-                  _append_defval(buf, def_ret, rtp);
+                  _append_defval(buf, def_ret, rtp, rtpn);
                   eina_strbuf_append(buf, ";\n");
                }
              eina_strbuf_append(buf, "}\n\n");
@@ -788,15 +830,15 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
         eina_stringshare_del(dt);
      }
 
-   if (impl_same_class && !eolian_function_is_class(fid))
+   if (impl_same_class && !eolian_function_is_static(fid))
      {
         /* generate reflection implementation */
-        if (reflect_type)
+        if (reflect_param)
           {
              if (ftype == EOLIAN_PROP_GET)
-               _gen_reflect_get(buf, cnamel, reflect_type, fid, refh);
+               _gen_reflect_get(buf, cnamel, reflect_param, fid, refh);
              else
-               _gen_reflect_set(buf, cnamel, reflect_type, fid, refh);
+               _gen_reflect_set(buf, cnamel, reflect_param, fid, refh);
           }
 
         void *data;
@@ -831,7 +873,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
         if (has_params)
           eina_strbuf_append_char(buf, 'V');
         if ((ftype == EOLIAN_PROP_GET) || eolian_function_object_is_const(fid)
-            || eolian_function_is_class(fid))
+            || eolian_function_is_static(fid))
           {
              eina_strbuf_append(buf, "_CONST");
           }
@@ -847,7 +889,7 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
         if (strcmp(rtpn, "void"))
           {
              eina_strbuf_append_printf(buf, ", %s, ", rtpn);
-             _append_defval(buf, def_ret, rtp);
+             _append_defval(buf, def_ret, rtp, rtpn);
           }
 
         if (fallback_free_ownership)
@@ -865,8 +907,8 @@ _gen_func(const Eolian_Class *cl, const Eolian_Function *fid,
 
         eina_stringshare_del(eofn);
      }
-   if (impl_same_class && eolian_function_is_class(fid))
-     _emit_class_function(buf, fid, rtp, params_full, ocnamel, func_suffix, params, eolian_function_full_c_name_get(fid, ftype));
+   if (impl_same_class && eolian_function_is_static(fid))
+     _emit_class_function(buf, fid, rtpn, params_full, ocnamel, func_suffix, params, eolian_function_full_c_name_get(fid, ftype));
 
    free(cname);
    free(cnamel);
@@ -959,7 +1001,7 @@ _gen_initializer(const Eolian_Class *cl, Eina_Strbuf *buf, Eina_Hash *refh)
         Eolian_Function_Type ftype;
         const Eolian_Function *fid = eolian_implement_function_get(imp, &ftype);
 
-        if (eolian_function_is_class(fid)) continue;
+        if (eolian_function_is_static(fid)) continue;
 
         if (!eina_strbuf_length_get(ops))
           eina_strbuf_append_printf(ops, "   EFL_OPS_DEFINE(ops,\n");
@@ -1054,7 +1096,7 @@ eo_gen_source_gen(const Eolian_Class *cl, Eina_Strbuf *buf)
       Eolian_Event *ev;
       EINA_ITERATOR_FOREACH(itr, ev)
         {
-           Eina_Stringshare *evn = eolian_event_c_name_get(ev);
+           Eina_Stringshare *evn = eolian_event_c_macro_get(ev);
            eina_strbuf_append(buf, "EWAPI const Efl_Event_Description _");
            eina_strbuf_append(buf, evn);
            eina_strbuf_append(buf, " =\n   EFL_EVENT_DESCRIPTION");
@@ -1163,14 +1205,14 @@ eo_gen_source_gen(const Eolian_Class *cl, Eina_Strbuf *buf)
         eina_strbuf_append(buf, ", NULL");
       else
         {
-           Eina_Stringshare *mname = eolian_class_c_name_get(icl);
+           Eina_Stringshare *mname = eolian_class_c_macro_get(icl);
            eina_strbuf_append_printf(buf, ", %s", mname);
            eina_stringshare_del(mname);
         }
       Eina_Iterator *itr = eolian_class_extensions_get(cl);
       EINA_ITERATOR_FOREACH(itr, icl)
         {
-           Eina_Stringshare *mname = eolian_class_c_name_get(icl);
+           Eina_Stringshare *mname = eolian_class_c_macro_get(icl);
            eina_strbuf_append_printf(buf, ", %s", mname);
            eina_stringshare_del(mname);
         }
@@ -1199,8 +1241,7 @@ _gen_params(const Eolian_Function *fid, Eolian_Function_Type ftype,
       EINA_ITERATOR_FOREACH(itr, pr)
         {
            const char *prn = eolian_parameter_name_get(pr);
-           const Eolian_Type *pt = eolian_parameter_type_get(pr);
-           Eina_Stringshare *ptn = eolian_type_c_type_get(pt, EOLIAN_C_TYPE_PARAM);
+           Eina_Stringshare *ptn = eolian_parameter_c_type_get(pr, EINA_FALSE);
 
            eina_strbuf_append(params, ", ");
            eina_strbuf_append(params, prn);
@@ -1226,11 +1267,11 @@ _gen_params(const Eolian_Function *fid, Eolian_Function_Type ftype,
         Eolian_Function_Parameter *pr;
         EINA_ITERATOR_FOREACH(itr, pr)
           {
-             Eolian_Parameter_Dir pd = eolian_parameter_direction_get(pr);
+             Eolian_Parameter_Direction pd = eolian_parameter_direction_get(pr);
              const char *prn = eolian_parameter_name_get(pr);
              const Eolian_Type *pt = eolian_parameter_type_get(pr);
              const Eolian_Typedecl *ptd = eolian_type_typedecl_get(pt);
-             Eina_Stringshare *ptn = eolian_type_c_type_get(pt, EOLIAN_C_TYPE_PARAM);
+             Eina_Stringshare *ptn = eolian_parameter_c_type_get(pr, EINA_FALSE);
 
              if (ptd && eolian_typedecl_type_get(ptd) == EOLIAN_TYPEDECL_FUNCTION_POINTER)
                {
@@ -1293,6 +1334,7 @@ _gen_proto(const Eolian_Class *cl, const Eolian_Function *fid,
 
    Eina_Bool var_as_ret = EINA_FALSE;
    const Eolian_Type *rtp = eolian_function_return_type_get(fid, ftype);
+   Eina_Stringshare *rtpn = NULL;
    if ((ftype == EOLIAN_PROP_GET) && !rtp)
      {
         void *d1, *d2;
@@ -1301,6 +1343,7 @@ _gen_proto(const Eolian_Class *cl, const Eolian_Function *fid,
           {
              Eolian_Function_Parameter *pr = d1;
              rtp = eolian_parameter_type_get(pr);
+             rtpn = eolian_parameter_c_type_get(pr, EINA_FALSE);
              var_as_ret = EINA_TRUE;
           }
         eina_iterator_free(itr);
@@ -1309,7 +1352,8 @@ _gen_proto(const Eolian_Class *cl, const Eolian_Function *fid,
    eina_strbuf_append(buf, "EOLIAN static ");
    if (rtp)
      {
-        Eina_Stringshare *rtpn = eolian_type_c_type_get(rtp, EOLIAN_C_TYPE_RETURN);
+        if (!rtpn)
+          rtpn = eolian_function_return_c_type_get(fid, ftype);
         eina_strbuf_append(buf, rtpn);
         eina_stringshare_del(rtpn);
      }
@@ -1342,7 +1386,7 @@ _gen_proto(const Eolian_Class *cl, const Eolian_Function *fid,
      if (!strcmp(efname + strlen(efname) - sizeof("destructor") + 1, "destructor"))
        {
           Eina_Stringshare *fcn = eolian_function_full_c_name_get(fid, ftype);
-          Eina_Stringshare *mname = eolian_class_c_name_get(cl);
+          Eina_Stringshare *mname = eolian_class_c_macro_get(cl);
           eina_strbuf_append(buf, "   ");
           eina_strbuf_append(buf, fcn);
           eina_stringshare_del(fcn);
