@@ -1,8 +1,24 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 #pragma warning disable 1591
 
 using System;
 using System.Text;
 using System.Runtime.InteropServices;
+using System.ComponentModel;
 
 namespace Eina
 {
@@ -10,8 +26,8 @@ namespace Eina
 namespace Callbacks
 {
 
-public delegate int EinaCompareCb(IntPtr data1, IntPtr data2);
-public delegate void EinaFreeCb(IntPtr data);
+internal delegate int EinaCompareCb(IntPtr data1, IntPtr data2);
+internal delegate void EinaFreeCb(IntPtr data);
 
 }
 
@@ -41,7 +57,10 @@ internal static class NativeCustomExportFunctions
         efl_mono_native_efl_unref_addr_get();
 }
 
-/// <summary>Wrapper around native memory DllImport'd functions</summary>
+/// <summary>Wrapper around native memory DllImport'd functions.
+/// <para>Since EFL 1.23.</para>
+/// </summary>
+[EditorBrowsable(EditorBrowsableState.Never)]
 public static class MemoryNative
 {
     public static void Free(IntPtr ptr)
@@ -75,6 +94,41 @@ public static class MemoryNative
         return NativeCustomExportFunctions.efl_mono_native_strdup(str);
     }
 
+    /// <summary>
+    ///   Retrieves an instance of a string for use in program.
+    /// <para>Since EFL 1.23.</para>
+    /// </summary>
+    /// <param name="str"> The NULL-terminated string to retrieve an instance of.</param>
+    /// <returns> A pointer to an instance of the string on success,
+    ///  on failure a exception is raised.</returns>
+    public static IntPtr AddStringshare(string str)
+    {
+        IntPtr nativeStr = StringConversion.ManagedStringToNativeUtf8Alloc(str);
+        try
+        {
+            var strShare = NativeMethods.eina_stringshare_add(nativeStr);
+            return strShare;
+        }
+        finally
+        {
+            Eina.MemoryNative.Free(nativeStr);
+        }
+    }
+
+    /// <summary>
+    ///   Notes that the given string has lost an instance.
+    /// </summary>
+    /// <param name="str">the given string</param>
+    public static void DelStringshare(IntPtr str)
+    {
+        NativeMethods.eina_stringshare_del(str);
+    }
+
+    public static void DelStringshareRef(IntPtr ptr)
+    {
+        NativeMethods.efl_mono_native_stringshare_del_ref(ptr);
+    }
+
     // IntPtr's for some native functions
     public static IntPtr PtrCompareFuncPtrGet()
     {
@@ -91,12 +145,22 @@ public static class MemoryNative
         return NativeCustomExportFunctions.efl_mono_native_free_addr_get();
     }
 
+    public static IntPtr StringshareDelFuncPtrGet()
+    {
+        return NativeMethods.efl_mono_native_stringshare_del_addr_get();
+    }
+
     public static IntPtr EflUnrefFuncPtrGet()
     {
         return NativeCustomExportFunctions.efl_mono_native_efl_unref_addr_get();
     }
 }
 
+/// <summary>
+/// Conversor of raw pointer to  a type and type to raw pointer
+/// <para>Since EFL 1.23.</para>
+/// </summary>
+[EditorBrowsable(EditorBrowsableState.Never)]
 public static class PrimitiveConversion
 {
    public static T PointerToManaged<T>(IntPtr nat)
@@ -119,6 +183,11 @@ public static class PrimitiveConversion
    }
 }
 
+/// <summary>
+/// Conversor of string to native string and native string to string.
+/// <para>Since EFL 1.23.</para>
+/// </summary>
+[EditorBrowsable(EditorBrowsableState.Never)]
 public static class StringConversion
 {
     public static IntPtr ManagedStringToNativeUtf8Alloc(string managedString)
@@ -130,9 +199,17 @@ public static class StringConversion
 
         byte[] strbuf = Encoding.UTF8.GetBytes(managedString);
         IntPtr native = MemoryNative.Alloc(strbuf.Length + 1);
-        Marshal.Copy(strbuf, 0, native, strbuf.Length);
-        Marshal.WriteByte(native + strbuf.Length, 0); // write the terminating null
-        return native;
+        try
+        {
+            Marshal.Copy(strbuf, 0, native, strbuf.Length);
+            Marshal.WriteByte(native + strbuf.Length, 0); // write the terminating null
+            return native;
+        }
+        catch (Exception)
+        {
+            MemoryNative.Free(native);
+            throw;
+        }
     }
 
     public static string NativeUtf8ToManagedString(IntPtr pNativeData)
@@ -154,7 +231,10 @@ public static class StringConversion
     }
 }
 
-/// <summary>Enum to handle resource ownership between managed and unmanaged code.</summary>
+/// <summary>Enum to handle resource ownership between managed and unmanaged code.
+/// <para>Since EFL 1.23.</para>
+/// </summary>
+[EditorBrowsable(EditorBrowsableState.Never)]
 public enum Ownership
 {
     /// <summary> The resource is owned by the managed code. It should free the handle on disposal.</summary>
