@@ -1,3 +1,18 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 #pragma warning disable 1591
 
 using System;
@@ -5,6 +20,7 @@ using System.Linq;
 using System.Runtime.InteropServices;
 using System.Collections.Generic;
 using System.Reflection;
+using System.ComponentModel;
 
 using Eina.Callbacks;
 using static Eina.HashNativeFunctions;
@@ -15,13 +31,16 @@ using static Eina.NativeCustomExportFunctions;
 namespace Eina
 {
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public enum ElementType
 {
     NumericType,
     StringType,
+    StringshareType,
     ObjectType
 };
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 [StructLayout(LayoutKind.Sequential)]
 public struct InlistMem
 {
@@ -30,6 +49,7 @@ public struct InlistMem
     public IntPtr last {get;set;}
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 [StructLayout(LayoutKind.Sequential)]
 public struct InlistNode<T>
 {
@@ -37,6 +57,7 @@ public struct InlistNode<T>
     public T Val {get;set;}
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public interface IBaseElementTraits<T>
 {
     IntPtr ManagedToNativeAlloc(T man);
@@ -57,6 +78,7 @@ public interface IBaseElementTraits<T>
     IntPtr EinaHashIteratorKeyNew(IntPtr hash);
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class StringElementTraits : IBaseElementTraits<string>
 {
     public StringElementTraits()
@@ -195,6 +217,147 @@ public class StringElementTraits : IBaseElementTraits<string>
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
+public class StringshareElementTraits : IBaseElementTraits<Eina.Stringshare>
+{
+    public StringshareElementTraits()
+    {
+    }
+
+    public IntPtr ManagedToNativeAlloc(Eina.Stringshare man)
+    {
+        var strShare = MemoryNative.AddStringshare(man);
+        return strShare;
+    }
+
+    public IntPtr ManagedToNativeAllocInlistNode(Eina.Stringshare man)
+    {
+        var node = new InlistNode<IntPtr>();
+        node.Val = ManagedToNativeAlloc(man);
+        GCHandle pinnedData = GCHandle.Alloc(node, GCHandleType.Pinned);
+        IntPtr ptr = pinnedData.AddrOfPinnedObject();
+        IntPtr nat = MemoryNative.AllocCopy
+            (ptr, Marshal.SizeOf<InlistMem>() + Marshal.SizeOf<IntPtr>());
+        pinnedData.Free();
+        return nat;
+    }
+
+    public void ManagedToNativeCopyTo(Eina.Stringshare man, IntPtr mem)
+    {
+        IntPtr stringptr = ManagedToNativeAlloc(man);
+        Marshal.WriteIntPtr(mem, stringptr);
+    }
+
+    public void NativeFree(IntPtr nat)
+    {
+        if (nat != IntPtr.Zero)
+        {
+            MemoryNative.DelStringshare(nat);
+        }
+    }
+
+    public void NativeFreeInlistNodeElement(IntPtr nat)
+    {
+        if (nat == IntPtr.Zero)
+        {
+            return;
+        }
+
+        var val = Marshal.PtrToStructure<IntPtr>
+            (nat + Marshal.SizeOf<InlistMem>());
+        NativeFree(val);
+    }
+
+    public void NativeFreeInlistNode(IntPtr nat, bool freeElement)
+    {
+        if (nat == IntPtr.Zero)
+        {
+            return;
+        }
+
+        if (freeElement)
+        {
+            NativeFreeInlistNodeElement(nat);
+        }
+
+        MemoryNative.Free(nat);
+    }
+
+    public void NativeFreeInplace(IntPtr nat)
+    {
+        MemoryNative.DelStringshareRef(nat);
+    }
+
+    public void ResidueFreeInplace(IntPtr nat)
+    {
+    }
+
+    public Eina.Stringshare NativeToManaged(IntPtr nat)
+    {
+        if (nat == IntPtr.Zero)
+        {
+            return default(Eina.Stringshare);
+        }
+
+        return StringConversion.NativeUtf8ToManagedString(nat);
+    }
+
+    public Eina.Stringshare NativeToManagedInlistNode(IntPtr nat)
+    {
+        if (nat == IntPtr.Zero)
+        {
+            Eina.Log.Error("Null pointer for Inlist node.");
+            return default(Eina.Stringshare);
+        }
+
+        IntPtr ptr_location = nat + Marshal.SizeOf<InlistMem>();
+        return NativeToManaged(Marshal.ReadIntPtr(ptr_location));
+    }
+
+    // Strings inplaced are always a pointer, because they are variable-sized
+    public Eina.Stringshare NativeToManagedInplace(IntPtr nat)
+    {
+        if (nat == IntPtr.Zero)
+        {
+            return default(Eina.Stringshare);
+        }
+
+        nat = Marshal.ReadIntPtr(nat);
+        if (nat == IntPtr.Zero)
+        {
+            return default(Eina.Stringshare);
+        }
+
+        return NativeToManaged(nat);
+    }
+
+    public IntPtr EinaCompareCb()
+    {
+        return MemoryNative.StrCompareFuncPtrGet();
+    }
+
+    public IntPtr EinaFreeCb()
+    {
+        return MemoryNative.StringshareDelFuncPtrGet();
+    }
+
+    public IntPtr EinaHashNew()
+    {
+        return eina_hash_stringshared_new(MemoryNative.StringshareDelFuncPtrGet());
+    }
+
+    public IntPtr EinaInarrayNew(uint step)
+    {
+        return eina_inarray_new((uint)Marshal.SizeOf<IntPtr>(), step);
+    }
+
+    public IntPtr EinaHashIteratorKeyNew(IntPtr hash)
+    {
+        return eina_hash_iterator_key_new(hash);
+    }
+}
+
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class EflObjectElementTraits<T> : IBaseElementTraits<T>
 {
     public IntPtr ManagedToNativeAlloc(T man)
@@ -229,7 +392,7 @@ public class EflObjectElementTraits<T> : IBaseElementTraits<T>
     {
         if (nat != IntPtr.Zero)
         {
-	    Efl.Eo.Globals.efl_mono_thread_safe_efl_unref(nat);
+            Efl.Eo.Globals.efl_mono_thread_safe_efl_unref(nat);
         }
     }
 
@@ -352,9 +515,10 @@ public class EflObjectElementTraits<T> : IBaseElementTraits<T>
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public abstract class PrimitiveElementTraits<T>
 {
-    private Eina_Compare_Cb dlgt = null;
+    private Eina.Callbacks.EinaCompareCb dlgt = null;
 
     public IntPtr ManagedToNativeAlloc(T man)
     {
@@ -431,7 +595,7 @@ public abstract class PrimitiveElementTraits<T>
     {
         if (dlgt == null)
         {
-            dlgt = new Eina_Compare_Cb(PrimitiveCompareCb);
+            dlgt = new Eina.Callbacks.EinaCompareCb(PrimitiveCompareCb);
         }
 
         return Marshal.GetFunctionPointerForDelegate(dlgt);
@@ -453,6 +617,7 @@ public abstract class PrimitiveElementTraits<T>
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 abstract public class Primitive32ElementTraits<T> : PrimitiveElementTraits<T>, IBaseElementTraits<T>
 {
     private static IBaseElementTraits<Int32> int32Traits = null;
@@ -491,6 +656,7 @@ abstract public class Primitive32ElementTraits<T> : PrimitiveElementTraits<T>, I
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 abstract public class Primitive64ElementTraits<T> : PrimitiveElementTraits<T>, IBaseElementTraits<T>
 {
     private static IBaseElementTraits<Int64> int64Traits = null;
@@ -529,6 +695,7 @@ abstract public class Primitive64ElementTraits<T> : PrimitiveElementTraits<T>, I
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class IntElementTraits : Primitive32ElementTraits<int>, IBaseElementTraits<int>
 {
     override public void ManagedToNativeCopyTo(int man, IntPtr mem)
@@ -553,6 +720,7 @@ public class IntElementTraits : Primitive32ElementTraits<int>, IBaseElementTrait
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class CharElementTraits : Primitive32ElementTraits<char>, IBaseElementTraits<char>
 {
     override public void ManagedToNativeCopyTo(char man, IntPtr mem)
@@ -577,6 +745,7 @@ public class CharElementTraits : Primitive32ElementTraits<char>, IBaseElementTra
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class LongElementTraits : Primitive64ElementTraits<long>, IBaseElementTraits<long>
 {
     override public void ManagedToNativeCopyTo(long man, IntPtr mem)
@@ -601,6 +770,7 @@ public class LongElementTraits : Primitive64ElementTraits<long>, IBaseElementTra
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class ShortElementTraits : Primitive32ElementTraits<short>, IBaseElementTraits<short>
 {
     override public void ManagedToNativeCopyTo(short man, IntPtr mem)
@@ -625,6 +795,7 @@ public class ShortElementTraits : Primitive32ElementTraits<short>, IBaseElementT
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class FloatElementTraits : Primitive32ElementTraits<float>, IBaseElementTraits<float>
 {
     override public void ManagedToNativeCopyTo(float man, IntPtr mem)
@@ -649,6 +820,7 @@ public class FloatElementTraits : Primitive32ElementTraits<float>, IBaseElementT
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class DoubleElementTraits : Primitive64ElementTraits<double>, IBaseElementTraits<double>
 {
     override public void ManagedToNativeCopyTo(double man, IntPtr mem)
@@ -673,6 +845,7 @@ public class DoubleElementTraits : Primitive64ElementTraits<double>, IBaseElemen
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public class ByteElementTraits : Primitive32ElementTraits<byte>, IBaseElementTraits<byte>
 {
     override public void ManagedToNativeCopyTo(byte man, IntPtr mem)
@@ -697,6 +870,7 @@ public class ByteElementTraits : Primitive32ElementTraits<byte>, IBaseElementTra
     }
 }
 
+[EditorBrowsable(EditorBrowsableState.Never)]
 public static class TraitFunctions
 {
     public static bool IsEflObject(System.Type type)
@@ -709,6 +883,11 @@ public static class TraitFunctions
         return type == typeof(string);
     }
 
+    public static bool IsStringshare(System.Type type)
+    {
+        return type == typeof(Eina.Stringshare);
+    }
+
     public static Eina.ElementType GetElementTypeCode(System.Type type)
     {
         if (IsEflObject(type))
@@ -719,6 +898,10 @@ public static class TraitFunctions
         {
             return ElementType.StringType;
         }
+        else if (IsStringshare(type))
+        {
+            return ElementType.StringshareType;
+        }
         else
         {
             return ElementType.NumericType;
@@ -764,6 +947,10 @@ public static class TraitFunctions
         {
             traits = new StringElementTraits();
         }
+        else if (IsStringshare(type))
+        {
+            traits = new StringshareElementTraits();
+        }
         else if (type.IsValueType)
         {
             if (type == typeof(int))
