@@ -71,7 +71,7 @@ _efl_net_dialer_unix_efl_object_destructor(Eo *o, Efl_Net_Dialer_Unix_Data *pd)
 }
 
 static Eina_Value
-_efl_net_dialer_unix_connect_timeout(Eo *o, const Eina_Value v)
+_efl_net_dialer_unix_connect_timeout(Eo *o, void *data EINA_UNUSED, const Eina_Value v)
 {
    Efl_Net_Dialer_Unix_Data *pd = efl_data_scope_get(o, MY_CLASS);
    Eina_Error err = ETIMEDOUT;
@@ -84,7 +84,7 @@ _efl_net_dialer_unix_connect_timeout(Eo *o, const Eina_Value v)
 
    efl_ref(o);
    efl_io_reader_eos_set(o, EINA_TRUE);
-   efl_event_callback_call(o, EFL_NET_DIALER_EVENT_ERROR, &err);
+   efl_event_callback_call(o, EFL_NET_DIALER_EVENT_DIALER_ERROR, &err);
    efl_unref(o);
    return v;
 }
@@ -105,7 +105,7 @@ _efl_net_dialer_unix_connected(void *data, const struct sockaddr *addr, socklen_
    efl_loop_fd_set(o, sockfd);
    if (efl_net_socket_address_remote_get(o))
      {
-        efl_event_callback_call(o, EFL_NET_DIALER_EVENT_RESOLVED, NULL);
+        efl_event_callback_call(o, EFL_NET_DIALER_EVENT_DIALER_RESOLVED, NULL);
         efl_net_dialer_connected_set(o, EINA_TRUE);
      }
    else
@@ -120,7 +120,7 @@ _efl_net_dialer_unix_connected(void *data, const struct sockaddr *addr, socklen_
    if (err)
      {
         efl_io_reader_eos_set(o, EINA_TRUE);
-        efl_event_callback_call(o, EFL_NET_DIALER_EVENT_ERROR, &err);
+        efl_event_callback_call(o, EFL_NET_DIALER_EVENT_DIALER_ERROR, &err);
      }
 
    efl_unref(o);
@@ -129,9 +129,9 @@ _efl_net_dialer_unix_connected(void *data, const struct sockaddr *addr, socklen_
 static void
 _timeout_schedule(Eo *o, Efl_Net_Dialer_Unix_Data *pd)
 {
-   efl_future_Eina_FutureXXX_then(o, efl_loop_timeout(efl_loop_get(o), pd->timeout_dial),
-                                  .success = _efl_net_dialer_unix_connect_timeout,
-                                  .storage = &pd->connect.timeout);
+   efl_future_then(o, efl_loop_timeout(efl_loop_get(o), pd->timeout_dial),
+                   .success = _efl_net_dialer_unix_connect_timeout,
+                   .storage = &pd->connect.timeout);
 }
 
 EOLIAN static Eina_Error
@@ -222,7 +222,7 @@ _efl_net_dialer_unix_efl_net_dialer_connected_set(Eo *o, Efl_Net_Dialer_Unix_Dat
    if (pd->connect.timeout) eina_future_cancel(pd->connect.timeout);
    if (pd->connected == connected) return;
    pd->connected = connected;
-   if (connected) efl_event_callback_call(o, EFL_NET_DIALER_EVENT_CONNECTED, NULL);
+   if (connected) efl_event_callback_call(o, EFL_NET_DIALER_EVENT_DIALER_CONNECTED, NULL);
 }
 
 EOLIAN static Eina_Bool
