@@ -671,6 +671,7 @@ _ecore_wl2_input_ungrab(Ecore_Wl2_Input *input)
    input->grab.window = NULL;
    input->grab.button = 0;
    input->grab.count = 0;
+   input->grab.touch_count = 0;
 }
 
 static void
@@ -765,6 +766,7 @@ _pointer_cb_button(void *data, struct wl_pointer *pointer EINA_UNUSED, unsigned
    if (!input) return;
 
    input->display->serial = serial;
+   input->timestamp = timestamp;
 
    if (state == WL_POINTER_BUTTON_STATE_PRESSED)
      {
@@ -802,6 +804,8 @@ _pointer_cb_axis(void *data, struct wl_pointer *pointer EINA_UNUSED, unsigned in
    input = data;
    if (!input) return;
 
+   input->timestamp = timestamp;
+
    _ecore_wl2_input_mouse_wheel_send(input, axis, wl_fixed_to_int(value),
                                      timestamp);
 }
@@ -1056,6 +1060,7 @@ _keyboard_cb_key(void *data, struct wl_keyboard *keyboard EINA_UNUSED, unsigned
    if (!window) return;
 
    input->display->serial = serial;
+   input->timestamp = timestamp;
 
    /* xkb rules reflect X broken keycodes, so offset by 8 */
    code = keycode + 8;
@@ -1205,6 +1210,8 @@ _touch_cb_down(void *data, struct wl_touch *touch EINA_UNUSED, unsigned int seri
    if (!window) return;
 
    input->focus.touch = window;
+   input->timestamp = timestamp;
+   input->grab.touch_count++;
 
    _pointer_cb_enter(data, NULL, serial, surface, x, y);
 
@@ -1234,9 +1241,13 @@ _touch_cb_up(void *data, struct wl_touch *touch EINA_UNUSED, unsigned int serial
                                   BTN_LEFT, timestamp);
 
    if (input->grab.count) input->grab.count--;
+   if (input->grab.touch_count) input->grab.touch_count--;
    if ((input->grab.window) && (input->grab.button == BTN_LEFT) &&
        (!input->grab.count))
      _ecore_wl2_input_ungrab(input);
+
+   if (input->grab.touch_count == 0) input->focus.touch = NULL;
+
 }
 
 static void
@@ -1273,7 +1284,9 @@ static const struct wl_touch_listener _touch_listener =
    _touch_cb_up,
    _touch_cb_motion,
    _touch_cb_frame,
-   _touch_cb_cancel
+   _touch_cb_cancel,
+   NULL, // XXX: FIXME: add shape
+   NULL, // XXX: FIXME: add orientation
 };
 
 static void
