@@ -12,7 +12,7 @@
 #include "draw.h"
 
 static void
-_blend_color_argb(int count, const SW_FT_Span *spans, void *user_data)
+_blend_argb(int count, const SW_FT_Span *spans, void *user_data)
 {
    Span_Data *sd = user_data;
    uint32_t color, *buffer, *target;
@@ -34,11 +34,13 @@ _blend_color_argb(int count, const SW_FT_Span *spans, void *user_data)
 }
 
 static void
-_blend_color_argb_with_maskA(int count, const SW_FT_Span *spans, void *user_data)
+_comp_matte_alpha(int count, const SW_FT_Span *spans, void *user_data)
 {
    Span_Data *sd = user_data;
    const int pix_stride = sd->raster_buffer->stride / 4;
-   Ector_Software_Buffer_Base_Data *mask = sd->mask;
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   if (!comp || !comp->pixels.u32) return;
+   const int comp_stride = comp->stride / 4;
 
    // multiply the color with mul_col if any
    uint32_t color = DRAW_MUL4_SYM(sd->color, sd->mul_col);
@@ -47,7 +49,7 @@ _blend_color_argb_with_maskA(int count, const SW_FT_Span *spans, void *user_data
    // move to the offset location
    uint32_t *buffer =
          sd->raster_buffer->pixels.u32 + ((pix_stride * sd->offy) + sd->offx);
-   uint32_t *mbuffer = mask->pixels.u32;
+   uint32_t *mbuffer = comp->pixels.u32;
 
    //Temp buffer for intermediate processing
    int tsize = sd->raster_buffer->generic->w;
@@ -57,12 +59,12 @@ _blend_color_argb_with_maskA(int count, const SW_FT_Span *spans, void *user_data
      {
         uint32_t *target = buffer + ((pix_stride * spans->y) + spans->x);
         uint32_t *mtarget =
-              mbuffer + ((mask->generic->w * spans->y) + spans->x);
+              mbuffer + ((comp_stride * spans->y) + spans->x);
         uint32_t *temp = tbuffer;
         memset(temp, 0x00, sizeof(uint32_t) * spans->len);
         comp_func(temp, spans->len, color, spans->coverage);
 
-        //masking
+        //composite
         for (int i = 0; i < spans->len; i++)
           {
              *temp = draw_mul_256(((*mtarget)>>24), *temp);
@@ -77,11 +79,13 @@ _blend_color_argb_with_maskA(int count, const SW_FT_Span *spans, void *user_data
 }
 
 static void
-_blend_color_argb_with_maskInvA(int count, const SW_FT_Span *spans, void *user_data)
+_comp_matte_alpha_inv(int count, const SW_FT_Span *spans, void *user_data)
 {
    Span_Data *sd = user_data;
    const int pix_stride = sd->raster_buffer->stride / 4;
-   Ector_Software_Buffer_Base_Data *mask = sd->mask;
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   if (!comp || !comp->pixels.u32) return;
+   const int comp_stride = comp->stride / 4;
 
    // multiply the color with mul_col if any
    uint32_t color = DRAW_MUL4_SYM(sd->color, sd->mul_col);
@@ -90,7 +94,7 @@ _blend_color_argb_with_maskInvA(int count, const SW_FT_Span *spans, void *user_d
    // move to the offset location
    uint32_t *buffer =
          sd->raster_buffer->pixels.u32 + ((pix_stride * sd->offy) + sd->offx);
-   uint32_t *mbuffer = mask->pixels.u32;
+   uint32_t *mbuffer = comp->pixels.u32;
 
    //Temp buffer for intermediate processing
    int tsize = sd->raster_buffer->generic->w;
@@ -100,12 +104,12 @@ _blend_color_argb_with_maskInvA(int count, const SW_FT_Span *spans, void *user_d
      {
         uint32_t *target = buffer + ((pix_stride * spans->y) + spans->x);
         uint32_t *mtarget =
-              mbuffer + ((mask->generic->w * spans->y) + spans->x);
+              mbuffer + ((comp_stride * spans->y) + spans->x);
         uint32_t *temp = tbuffer;
         memset(temp, 0x00, sizeof(uint32_t) * spans->len);
         comp_func(temp, spans->len, color, spans->coverage);
 
-        //masking
+        //composite
         for (int i = 0; i < spans->len; i++)
           {
              if (*mtarget)
@@ -120,6 +124,125 @@ _blend_color_argb_with_maskInvA(int count, const SW_FT_Span *spans, void *user_d
      }
 }
 
+static void
+_comp_mask_add(int count, const SW_FT_Span *spans, void *user_data)
+{
+   Span_Data *sd = user_data;
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   if (!comp || !comp->pixels.u32) return;
+   const int comp_stride = comp->stride / 4;
+
+   uint32_t color = DRAW_MUL4_SYM(sd->color, sd->mul_col);
+   RGBA_Comp_Func_Solid comp_func = efl_draw_func_solid_span_get(sd->op, color);
+   uint32_t *mbuffer = comp->pixels.u32;
+
+   int tsize = sd->raster_buffer->generic->w;
+   uint32_t *ttarget = alloca(sizeof(uint32_t) * tsize);
+
+   while (count--)
+     {
+        uint32_t *mtarget = mbuffer + ((comp_stride * spans->y) + spans->x);
+        memset(ttarget, 0x00, sizeof(uint32_t) * spans->len);
+        comp_func(ttarget, spans->len, color, spans->coverage);
+        for (int i = 0; i < spans->len; i++)
+          mtarget[i] = draw_mul_256(0xFF - (ttarget[i]>>24), mtarget[i]) + ttarget[i];
+        ++spans;
+     }
+}
+
+static void
+_comp_mask_sub(int count, const SW_FT_Span *spans, void *user_data)
+{
+   Span_Data *sd = user_data;
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   if (!comp || !comp->pixels.u32) return;
+   const int comp_stride = comp->stride / 4;
+
+   uint32_t color = DRAW_MUL4_SYM(sd->color, sd->mul_col);
+   RGBA_Comp_Func_Solid comp_func = efl_draw_func_solid_span_get(sd->op, color);
+   uint32_t *mbuffer = comp->pixels.u32;
+
+   int tsize = sd->raster_buffer->generic->w;
+   uint32_t *ttarget = alloca(sizeof(uint32_t) * tsize);
+
+   while (count--)
+     {
+        uint32_t *mtarget = mbuffer + ((comp_stride * spans->y) + spans->x);
+        memset(ttarget, 0x00, sizeof(uint32_t) * spans->len);
+        comp_func(ttarget, spans->len, color, spans->coverage);
+        for (int i = 0; i < spans->len; i++)
+          mtarget[i] = draw_mul_256(0xFF - (ttarget[i]>>24), mtarget[i]);
+        ++spans;
+     }
+}
+
+
+static void
+_comp_mask_ins(int count, const SW_FT_Span *spans, void *user_data)
+{
+   Span_Data *sd = user_data;
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   if (!comp || !comp->pixels.u32) return;
+   const int comp_stride = comp->stride / 4;
+
+   uint32_t color = DRAW_MUL4_SYM(sd->color, sd->mul_col);
+   RGBA_Comp_Func_Solid comp_func = efl_draw_func_solid_span_get(sd->op, color);
+   uint32_t *mbuffer = comp->pixels.u32;
+
+   int tsize = sd->raster_buffer->generic->w;
+   uint32_t *ttarget = alloca(sizeof(uint32_t) * tsize);
+
+   for(unsigned int y = 0; y < comp->generic->h; y++)
+     {
+        for(unsigned int x = 0; x < comp->generic->w; x++)
+          {
+             if (x == (unsigned int)spans->x && x + spans->len <= comp->generic->w &&
+                 y == (unsigned int)spans->y && count > 0)
+               {
+                  memset(ttarget, 0x00, sizeof(uint32_t) * spans->len);
+                  uint32_t *mtarget = mbuffer + ((comp_stride * spans->y) + spans->x);
+                  comp_func(ttarget, spans->len, color, spans->coverage);
+                  for (int c = 0; c < spans->len; c++)
+                    mtarget[c] = draw_mul_256(ttarget[c]>>24, mtarget[c]);
+                  x += spans->len - 1;
+                  ++spans;
+                  --count;
+               }
+             else
+               {
+                  mbuffer[x + (comp_stride * y)] = (0x00FFFFFF & mbuffer[x + (comp_stride * y)]);
+               }
+          }
+     }
+}
+
+
+static void
+_comp_mask_diff(int count, const SW_FT_Span *spans, void *user_data)
+{
+   Span_Data *sd = user_data;
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   if (!comp || !comp->pixels.u32) return;
+   const int comp_stride = comp->stride / 4;
+
+   uint32_t color = DRAW_MUL4_SYM(sd->color, sd->mul_col);
+   RGBA_Comp_Func_Solid comp_func = efl_draw_func_solid_span_get(sd->op, color);
+   uint32_t *mbuffer = comp->pixels.u32;
+
+   int tsize = sd->raster_buffer->generic->w;
+   uint32_t *ttarget = alloca(sizeof(uint32_t) * tsize);
+
+   while (count--)
+     {
+        memset(ttarget, 0x00, sizeof(uint32_t) * spans->len);
+        uint32_t *mtarget = mbuffer + ((comp_stride * spans->y) + spans->x);
+        comp_func(ttarget, spans->len, color, spans->coverage);
+        for (int i = 0; i < spans->len; i++)
+          mtarget[i] = draw_mul_256(0xFF - (mtarget[i]>>24), ttarget[i]) + draw_mul_256(0xFF - (ttarget[i]>>24), mtarget[i]);
+        ++spans;
+     }
+}
+
 #define BLEND_GRADIENT_BUFFER_SIZE 2048
 
 typedef void (*src_fetch) (unsigned int *buffer, Span_Data *data, int y, int x, int length);
@@ -128,23 +251,22 @@ static void
 _blend_gradient(int count, const SW_FT_Span *spans, void *user_data)
 {
    RGBA_Comp_Func comp_func;
-   Span_Data *data = (Span_Data *)(user_data);
+   Span_Data *sd = (Span_Data *)(user_data);
    src_fetch fetchfunc = NULL;
    unsigned int buffer[BLEND_GRADIENT_BUFFER_SIZE], *target, *destbuffer;
    int length, l;
-   const int pix_stride = data->raster_buffer->stride / 4;
+   const int pix_stride = sd->raster_buffer->stride / 4;
 
    // FIXME: Get the proper composition function using ,color, ECTOR_OP etc.
-   if (data->type == LinearGradient) fetchfunc = &fetch_linear_gradient;
-   if (data->type == RadialGradient) fetchfunc = &fetch_radial_gradient;
+   if (sd->type == LinearGradient) fetchfunc = &fetch_linear_gradient;
+   if (sd->type == RadialGradient) fetchfunc = &fetch_radial_gradient;
 
-   if (!fetchfunc)
-     return;
+   if (!fetchfunc || !sd->raster_buffer->pixels.u32) return;
 
-   comp_func = efl_draw_func_span_get(data->op, data->mul_col, data->gradient->alpha);
+   comp_func = efl_draw_func_span_get(sd->op, sd->mul_col, sd->gradient->alpha);
 
    // move to the offset location
-   destbuffer = data->raster_buffer->pixels.u32 + ((pix_stride * data->offy) + data->offx);
+   destbuffer = sd->raster_buffer->pixels.u32 + ((pix_stride * sd->offy) + sd->offx);
 
    while (count--)
      {
@@ -153,8 +275,9 @@ _blend_gradient(int count, const SW_FT_Span *spans, void *user_data)
         while (length)
           {
              l = MIN(length, BLEND_GRADIENT_BUFFER_SIZE);
-             fetchfunc(buffer, data, spans->y, spans->x, l);
-             comp_func(target, buffer, l, data->mul_col, spans->coverage);
+             //FIXME: span->x must have adding an offset as much as subtracted length...
+             fetchfunc(buffer, sd, spans->y, spans->x, l);
+             comp_func(target, buffer, l, sd->mul_col, spans->coverage);
              target += l;
              length -= l;
           }
@@ -162,6 +285,106 @@ _blend_gradient(int count, const SW_FT_Span *spans, void *user_data)
      }
 }
 
+static void
+_blend_gradient_alpha(int count, const SW_FT_Span *spans, void *user_data)
+{
+   Span_Data *sd = (Span_Data *)(user_data);
+   src_fetch fetchfunc = NULL;
+   uint32_t *buffer;
+   const int pix_stride = sd->raster_buffer->stride / 4;
+   uint32_t gbuffer[BLEND_GRADIENT_BUFFER_SIZE];  //gradient buffer
+
+   // FIXME: Get the proper composition function using ,color, ECTOR_OP etc.
+   if (sd->type == LinearGradient) fetchfunc = &fetch_linear_gradient;
+   if (sd->type == RadialGradient) fetchfunc = &fetch_radial_gradient;
+
+   if (!fetchfunc) return;
+
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   uint32_t *mbuffer = comp->pixels.u32;
+   const int comp_stride = comp->stride / 4;
+
+   // move to the offset location
+   buffer = sd->raster_buffer->pixels.u32 + ((pix_stride * sd->offy) + sd->offx);
+
+   while (count--)
+     {
+        uint32_t *target = buffer + ((pix_stride * spans->y) + spans->x);
+        uint32_t *mtarget = mbuffer + ((comp_stride * spans->y) + spans->x);
+        int length = spans->len;
+
+        while (length)
+          {
+             int l = MIN(length, BLEND_GRADIENT_BUFFER_SIZE);
+             //FIXME: span->x must have adding an offset as much as subtracted length...
+             fetchfunc(gbuffer, sd, spans->y, spans->x, l);
+             uint32_t *temp = gbuffer;
+
+             for (int i = 0; i < l; i++)
+               {
+                  *temp = draw_mul_256(((*mtarget)>>24), *temp);
+                  int alpha = 255 - ((*temp) >> 24);
+                  *target = *temp + draw_mul_256(alpha, *target);
+                  ++temp;
+                  ++mtarget;
+                  ++target;
+               }
+             length -= l;
+          }
+        ++spans;
+     }
+}
+
+static void
+_blend_gradient_alpha_inv(int count, const SW_FT_Span *spans, void *user_data)
+{
+   Span_Data *sd = (Span_Data *)(user_data);
+   src_fetch fetchfunc = NULL;
+   uint32_t *buffer;
+   const int pix_stride = sd->raster_buffer->stride / 4;
+   uint32_t gbuffer[BLEND_GRADIENT_BUFFER_SIZE];  //gradient buffer
+
+   // FIXME: Get the proper composition function using ,color, ECTOR_OP etc.
+   if (sd->type == LinearGradient) fetchfunc = &fetch_linear_gradient;
+   if (sd->type == RadialGradient) fetchfunc = &fetch_radial_gradient;
+
+   if (!fetchfunc) return;
+
+   Ector_Software_Buffer_Base_Data *comp = sd->comp;
+   uint32_t *mbuffer = comp->pixels.u32;
+   const int comp_stride = comp->stride / 4;
+
+   // move to the offset location
+   buffer = sd->raster_buffer->pixels.u32 + ((pix_stride * sd->offy) + sd->offx);
+
+   while (count--)
+     {
+        uint32_t *target = buffer + ((pix_stride * spans->y) + spans->x);
+        uint32_t *mtarget = mbuffer + ((comp_stride * spans->y) + spans->x);
+        int length = spans->len;
+
+        while (length)
+          {
+             int l = MIN(length, BLEND_GRADIENT_BUFFER_SIZE);
+             //FIXME: span->x must have adding an offset as much as subtracted length...
+             fetchfunc(gbuffer, sd, spans->y, spans->x, l);
+             uint32_t *temp = gbuffer;
+
+             for (int i = 0; i < l; i++)
+               {
+                  if (*mtarget)
+                    *temp = draw_mul_256((255 - ((*mtarget)>>24)), *temp);
+                  int alpha = 255 - ((*temp) >> 24);
+                  *target = *temp + draw_mul_256(alpha, *target);
+                  ++temp;
+                  ++mtarget;
+                  ++target;
+               }
+             length -= l;
+          }
+        ++spans;
+     }
+}
 /*!
     \internal
     spans must be sorted on y
@@ -354,28 +577,49 @@ static void
 _adjust_span_fill_methods(Span_Data *spdata)
 {
    //Blending Function
-   switch(spdata->type)
+   if (spdata->comp)
      {
-        case None:
-          spdata->unclipped_blend = NULL;
-          break;
-        case Solid:
+        switch (spdata->comp_method)
           {
-             if (spdata->mask)
-                {
-                   if (spdata->mask_op == 2)
-                     spdata->unclipped_blend = &_blend_color_argb_with_maskInvA;
-                   else
-                     spdata->unclipped_blend = &_blend_color_argb_with_maskA;
-                }
-             else
-                spdata->unclipped_blend = &_blend_color_argb;
-           }
-          break;
-        case LinearGradient:
-        case RadialGradient:
+           default:
+           case EFL_GFX_VG_COMPOSITE_METHOD_MATTE_ALPHA:
+              if (spdata->type == Solid)
+                spdata->unclipped_blend = &_comp_matte_alpha;
+              else if (spdata->type == LinearGradient || spdata->type == RadialGradient)
+                spdata->unclipped_blend = &_blend_gradient_alpha;
+              else //None
+                spdata->unclipped_blend = NULL;
+              break;
+           case EFL_GFX_VG_COMPOSITE_METHOD_MATTE_ALPHA_INVERSE:
+              if (spdata->type == Solid)
+                spdata->unclipped_blend = &_comp_matte_alpha_inv;
+              else if (spdata->type == LinearGradient || spdata->type == RadialGradient)
+                spdata->unclipped_blend = &_blend_gradient_alpha_inv;
+              else //None
+                spdata->unclipped_blend = NULL;
+              break;
+           case EFL_GFX_VG_COMPOSITE_METHOD_MASK_ADD:
+              spdata->unclipped_blend = &_comp_mask_add;
+              break;
+           case EFL_GFX_VG_COMPOSITE_METHOD_MASK_SUBSTRACT:
+              spdata->unclipped_blend = &_comp_mask_sub;
+              break;
+           case EFL_GFX_VG_COMPOSITE_METHOD_MASK_INTERSECT:
+              spdata->unclipped_blend = &_comp_mask_ins;
+              break;
+           case EFL_GFX_VG_COMPOSITE_METHOD_MASK_DIFFERENCE:
+              spdata->unclipped_blend = &_comp_mask_diff;
+              break;
+          }
+     }
+   else
+     {
+        if (spdata->type == Solid)
+          spdata->unclipped_blend = &_blend_argb;
+        else if (spdata->type == LinearGradient || spdata->type == RadialGradient)
           spdata->unclipped_blend = &_blend_gradient;
-          break;
+        else //None
+          spdata->unclipped_blend = NULL;
      }
 
    // Clipping Function
@@ -397,7 +641,7 @@ void ector_software_thread_init(Ector_Software_Thread *thread)
 
    SW_FT_Stroker_New(&thread->stroker);
    SW_FT_Stroker_Set(thread->stroker, 1 << 6,
-                     SW_FT_STROKER_LINECAP_BUTT, SW_FT_STROKER_LINEJOIN_MITER, 0);
+                     SW_FT_STROKER_LINECAP_BUTT, SW_FT_STROKER_LINEJOIN_MITER_FIXED, 0x4<<16);
 }
 
 void ector_software_rasterizer_init(Software_Rasterizer *rasterizer)
@@ -419,12 +663,16 @@ void ector_software_thread_shutdown(Ector_Software_Thread *thread)
 void ector_software_rasterizer_stroke_set(Ector_Software_Thread *thread,
                                           Software_Rasterizer *rasterizer EINA_UNUSED, double width,
                                           Efl_Gfx_Cap cap_style, Efl_Gfx_Join join_style,
-                                          Eina_Matrix3 *m)
+                                          Eina_Matrix3 *m, double miterlimit)
 {
    SW_FT_Stroker_LineCap cap;
    SW_FT_Stroker_LineJoin join;
    int stroke_width;
    double scale_factor = 1.0;
+
+   // convert to freetype co-ordinate
+   SW_FT_Fixed miter_limit = miterlimit * (1<<16);
+
    if (m)
      {
         // get the minimum scale factor from matrix
@@ -458,10 +706,10 @@ void ector_software_rasterizer_stroke_set(Ector_Software_Thread *thread,
           join = SW_FT_STROKER_LINEJOIN_ROUND;
           break;
         default:
-          join = SW_FT_STROKER_LINEJOIN_MITER;
+          join = SW_FT_STROKER_LINEJOIN_MITER_FIXED;
           break;
      }
-   SW_FT_Stroker_Set(thread->stroker, stroke_width, cap, join, 0);
+   SW_FT_Stroker_Set(thread->stroker, stroke_width, cap, join, miter_limit);
 }
 
 static void
@@ -640,18 +888,19 @@ void
 ector_software_rasterizer_draw_rle_data(Software_Rasterizer *rasterizer,
                                         int x, int y, uint32_t mul_col,
                                         Efl_Gfx_Render_Op op, Shape_Rle_Data* rle,
-                                        Ector_Buffer *mask,
-                                        int mask_op)
+                                        Ector_Buffer *comp,
+                                        Efl_Gfx_Vg_Composite_Method comp_method)
 {
    if (!rle) return;
+   if (!rasterizer->fill_data.raster_buffer->pixels.u32) return;
 
    rasterizer->fill_data.offx = x;
    rasterizer->fill_data.offy = y;
    rasterizer->fill_data.mul_col = mul_col;
    rasterizer->fill_data.op = op;
-   rasterizer->fill_data.mask =
-         mask ? efl_data_scope_get(mask, ECTOR_SOFTWARE_BUFFER_BASE_MIXIN) : NULL;
-   rasterizer->fill_data.mask_op = mask_op;
+   rasterizer->fill_data.comp =
+         comp ? efl_data_scope_get(comp, ECTOR_SOFTWARE_BUFFER_BASE_MIXIN) : NULL;
+   rasterizer->fill_data.comp_method = comp_method;
 
    _setup_span_fill_matrix(rasterizer);
    _adjust_span_fill_methods(&rasterizer->fill_data);
