@@ -24,10 +24,6 @@
 #include <stdio.h>
 #include <string.h>
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #include "eina_config.h"
 #include "eina_private.h"
 #include "eina_alloca.h"
