@@ -75,7 +75,7 @@
  *          out file size and type.
  *
  * @warning All functions in this group are @b blocking, which means they may
- *          take a long time to return, use them carefully.
+ *          take a long time to return; use them carefully.
  *
  * See an example @ref eina_file_example_01_page "here".
  *
@@ -288,7 +288,7 @@ EAPI Eina_Array    *eina_file_split(char *path) EINA_WARN_UNUSED_RESULT EINA_ARG
  *          only fetched when advancing the iterator, which means there is very little
  *          cost associated with creating the list and stopping halfway through it.
  *
- * @param [in] dir The name of the directory to list
+ * @param[in] dir The name of the directory to list
  * @return An #Eina_Iterator that walks over the files and directories
  *         in @p dir. On failure, it returns @c NULL.
  *
@@ -309,7 +309,7 @@ EAPI Eina_Iterator *eina_file_ls(const char *dir) EINA_WARN_UNUSED_RESULT EINA_A
  *          dir is only fetched when advancing the iterator, which means there is
  *          cost associated with creating the list and stopping halfway through it.
  *
- * @param [in] dir The name of the directory to list
+ * @param[in] dir The name of the directory to list
  *
  * @return An #Eina_Iterator that walks over the files and
  *         directories in @p dir. On failure, it returns @c NULL.
@@ -409,7 +409,7 @@ EAPI Eina_Bool eina_file_mkdtemp(const char *templatename, Eina_Tmpstr **path) E
  *          @p dir is only fetched when advancing the iterator, which means there is
  *          cost associated with creating the list and stopping halfway through it.
  *
- * @param [in] dir The name of the directory to list
+ * @param[in] dir The name of the directory to list
  *
  * @return An Eina_Iterator that walks over the files and
  *         directories in @p dir. On failure, it returns @c NULL.
@@ -768,6 +768,38 @@ EAPI Eina_Bool eina_file_close_on_exec(int fd, Eina_Bool on);
 
 #include "eina_inline_file.x"
 
+/**
+ * @typedef Eina_Statgen
+ * @brief Stat Generation count state with it being 0 when disabled or some other value that is comparable (== or !=) to a stored value and if it is not equal, then do the actual stat i/o work
+ * @since 1.23
+ */
+typedef unsigned int Eina_Statgen;
+
+/**
+ * @brief Force the stat generation counter to tick over so any following i/o does real i/o and stat calls
+ * @since 1.23
+ */
+EAPI void         eina_file_statgen_next(void);
+
+/**
+ * @brief Get the current stat generation counter value
+ * @return 0 if you should always do stat calls and compare, or some other value that changes like a generation counter
+ * @since 1.23
+ */
+EAPI Eina_Statgen eina_file_statgen_get(void);
+
+/**
+ * @brief Enable stat generation count optimiziing to only stat/do file i/o between generation counts changing
+ * @since 1.23
+ */
+EAPI void         eina_file_statgen_enable(void);
+
+/**
+ * @brief Disable stat generation count optimiziing to only stat/do file i/o between generation counts changing
+ * @since 1.23
+ */
+EAPI void         eina_file_statgen_disable(void);
+
 /**
  * @}
  */
