@@ -42,7 +42,8 @@
 #endif
 
 #ifdef _WIN32
-# include <Evil.h>
+# include <direct.h> /* getcwd */
+# include <evil_private.h> /* path_is_absolute realpath dladdr */
 #endif
 
 #ifdef HAVE_ESCAPE
