@@ -333,6 +333,10 @@ _eina_future_cb_dispatch(Eina_Future *f, const Eina_Value value)
 {
    Eina_Future_Cb cb = f->cb;
 
+   // Cleaning up prev and past to avoid recursion
+   if (f->next) f->next->prev = NULL;
+   if (f->prev) f->prev->next = NULL;
+
    f->cb = EINA_FUTURE_DISPATCHED;
    if (f->storage) *f->storage = NULL;
 
@@ -364,6 +368,7 @@ _eina_future_dispatch_internal(Eina_Future **f,
         _eina_promise_value_dbg("No future to deliver value", NULL, value);
         return value;
      }
+   if ((*f)->cb == EINA_FUTURE_DISPATCHED) return value;
    next_value = _eina_future_cb_dispatch(*f, value);
    *f = _eina_future_free(*f);
    return next_value;
@@ -396,6 +401,12 @@ _eina_future_dispatch(Eina_Future_Scheduler *scheduler, Eina_Future *f, Eina_Val
          return;
       }
 
+    // Break early if finding a cb that is already dispatching
+    if (f->cb == EINA_FUTURE_DISPATCHED)
+      {
+         eina_value_flush(&next_value);
+         return;
+      }
     if (next_value.type == &EINA_VALUE_TYPE_PROMISE)
       {
          if (EINA_UNLIKELY(eina_log_domain_level_check(_promise_log_dom, EINA_LOG_LEVEL_DBG)))
@@ -463,6 +474,8 @@ _eina_future_cancel(Eina_Future *f, int err)
 
    while (f)
      {
+        // Stop on partially dispatched future
+        if (f->cb == EINA_FUTURE_DISPATCHED) break;
         if (f->cb)
           {
              Eina_Value r = _eina_future_cb_dispatch(f, value);
@@ -635,6 +648,11 @@ _eina_promise_clean_dispatch(Eina_Promise *p, Eina_Value v)
         // This function is called on a promise created with a scheduler, not a continue one.
         _eina_future_dispatch(p->scheduler, f, v);
      }
+   else
+     {
+        // Nobody is going to flush this value if we don't
+        eina_value_flush(&v);
+     }
    eina_mempool_free(_promise_mp, p);
 }
 
@@ -686,7 +704,7 @@ eina_future_as_value(Eina_Future *f)
    EINA_FUTURE_CHECK_RETURN_VAL(f, v);
    p = eina_promise_new(_scheduler_get(f), _dummy_cancel, NULL);
    EINA_SAFETY_ON_NULL_GOTO(p, err_promise);
-   r_future = eina_future_then(f, _future_proxy, p);
+   r_future = eina_future_then(f, _future_proxy, p, NULL);
    //If eina_future_then() fails f will be cancelled
    EINA_SAFETY_ON_NULL_GOTO(r_future, err_future);
 
@@ -1096,22 +1114,6 @@ eina_future_cb_convert_to(const Eina_Value_Type *type)
    return (Eina_Future_Desc){.cb = _eina_future_cb_convert_to, .data = type};
 }
 
-EAPI void *
-eina_promise_data_get(const Eina_Promise *p)
-{
-   EINA_SAFETY_ON_NULL_RETURN_VAL(p, NULL);
-   return (void *)p->data;
-}
-
-EAPI void
-eina_promise_data_set(Eina_Promise *p,
-                      void *data)
-{
-   EINA_SAFETY_ON_NULL_RETURN(p);
-   p->data = data;
-}
-
-
 static Eina_Value
 _eina_future_cb_easy(void *data, const Eina_Value value,
                      const Eina_Future *dead_future)
@@ -1216,7 +1218,7 @@ _race_then_cb(void *data, const Eina_Value v,
    Eina_Promise *p = ctx->base.promise;
    Eina_Bool found, r;
    Eina_Value result;
-   unsigned int i;
+   unsigned int i = 0;
 
    //This is not allowed!
    assert(v.type != &EINA_VALUE_TYPE_PROMISE);
@@ -1305,7 +1307,7 @@ promise_proxy_of_future_array_create(Eina_Future *array[],
 
    for (i = 0; i < ctx->futures_len; i++)
      {
-        ctx->futures[i] = eina_future_then(array[i], future_cb, ctx);
+        ctx->futures[i] = eina_future_then(array[i], future_cb, ctx, NULL);
         //Futures will be cancelled by the caller...
         EINA_SAFETY_ON_NULL_GOTO(ctx->futures[i], err_then);
      }
@@ -1341,7 +1343,7 @@ eina_promise_all_array(Eina_Future *array[])
 
    for (i = 0; i < ctx->base.futures_len; i++)
      {
-        Eina_Value v;
+        Eina_Value v = { 0 };
 
         //Stub values...
         r = eina_value_setup(&v, EINA_VALUE_TYPE_INT);
@@ -1393,7 +1395,7 @@ static Eina_Value
 _eina_future_cb_ignore_error(void *data, const Eina_Value value,
                              const Eina_Future *dead_future EINA_UNUSED)
 {
-   Eina_Error expected_err = (Eina_Error)(long)data;
+   Eina_Error expected_err = (Eina_Error)(intptr_t)data;
 
    if (value.type == EINA_VALUE_TYPE_ERROR)
      {
@@ -1411,7 +1413,7 @@ _eina_future_cb_ignore_error(void *data, const Eina_Value value,
 EAPI Eina_Future_Desc
 eina_future_cb_ignore_error(Eina_Error err)
 {
-   return (Eina_Future_Desc){ _eina_future_cb_ignore_error, (void *)(long)err };
+   return (Eina_Future_Desc){ _eina_future_cb_ignore_error, (void*)(uintptr_t)err, NULL };
 }
 
 EAPI void
