@@ -3,7 +3,11 @@
 #endif
 
 #include <sys/types.h>
-#include <pwd.h>
+#ifdef _WIN32
+# include <evil_private.h> /* mkdir */
+#else
+# include <pwd.h>
+#endif
 
 #include <Eina.h>
 
@@ -195,11 +199,11 @@ eina_vpath_shutdown(void)
    return EINA_TRUE;
 }
 
+#ifdef HAVE_GETPWENT
 static Eina_Bool
 _fetch_user_homedir(char **str, const char *name, const char *error)
 {
   *str = NULL;
-#ifdef HAVE_GETPWENT
   struct passwd *pwent;
 
   pwent = getpwnam(name);
@@ -211,11 +215,8 @@ _fetch_user_homedir(char **str, const char *name, const char *error)
   *str = pwent->pw_dir;
 
   return EINA_TRUE;
-#else
-  ERR("User fetching is disabled on this system\nThe string was: %s", error);
-  return EINA_FALSE;
-#endif
 }
+#endif
 
 static int
 _eina_vpath_resolve(const char *path, char *str, size_t size)
@@ -231,6 +232,10 @@ _eina_vpath_resolve(const char *path, char *str, size_t size)
           }
         // ~username/ <- homedir of user "username"
         else
+#ifndef HAVE_GETPWENT
+          ERR("User fetching is disabled on this system\nThe string was: %s", path);
+          return 0;
+#else
           {
              const char *p;
              char *name;
@@ -247,43 +252,60 @@ _eina_vpath_resolve(const char *path, char *str, size_t size)
                return 0;
              path = p;
            }
+#endif
          if (home)
            {
               return snprintf(str, size, "%s%s", home, path);
            }
      }
    // (:xxx:)/* ... <- meta hash table
-   else if ((path[0] == '(') && (path[1] == ':'))
+   else if (((path[0] == '(') && (path[1] == ':')) ||
+            ((path[0] == '$') && (path[1] == '{')))
      {
         const char *p, *end, *meta;
+        const char *msg_start, *msg_end;
         char *name;
+        int offset;
         Eina_Bool found = EINA_FALSE;
 
-        end = p = strstr(path + 2, ":)");
+        if (path[0] == '(')
+          {
+             end = p = strstr(path + 2, ":)");
+             offset = 2;
+             msg_start = "(:";
+             msg_end = ":)";
+          }
+        else
+          {
+             end = p = strchr(path + 2, '}');
+             offset = 1;
+             msg_start = "${";
+             msg_end = "}";
+          }
         if (p) found = EINA_TRUE;
-        p += 2;
+        p += offset;
 
         if (!found)
           {
-             ERR("(: Needs to have a matching ':)'\nThe string was: %s", path);
+             ERR("'%s' Needs to have a matching '%s'\nThe string was: %s", msg_start, msg_end, path);
              return 0;
           }
 
         if (*p != '/')
           {
-             ERR("A / is expected after :)\nThe string was: %s", path);
+             ERR("A / is expected after '%s'\nThe string was: %s", msg_end, path);
              return 0;
           }
 
         if (found)
           {
              name = alloca(end - path);
-             strncpy(name, path + 2, end - path - 2);
+             strncpy(name, path + 2, end - path - offset);
              name[end - path - 2] = 0;
              meta = _eina_vpath_data_get(name);
              if (meta)
                {
-                  return snprintf(str, size, "%s%s", meta, end + 2);
+                  return snprintf(str, size, "%s%s", meta, end + offset);
                }
              else
                {
@@ -305,6 +327,7 @@ EAPI char *
 eina_vpath_resolve(const char* path)
 {
    char buf[PATH_MAX];
+   EINA_SAFETY_ON_NULL_RETURN_VAL(path, NULL);
 
    if (_eina_vpath_resolve(path, buf, sizeof(buf)) > 0)
      return strdup(buf);
