@@ -34,7 +34,7 @@ _delay_change(void *data)
    EFL_UI_SLIDER_DATA_GET(data, sd);
 
    sd->delay = NULL;
-   efl_event_callback_call(data, EFL_UI_SLIDER_EVENT_DELAY_CHANGED, NULL);
+   efl_event_callback_call(data, EFL_UI_RANGE_EVENT_STEADY, NULL);
 
    if (_elm_config->atspi_mode)
      efl_access_value_changed_signal_emit(data);
@@ -43,41 +43,54 @@ _delay_change(void *data)
 }
 
 static inline Eina_Bool
-_is_horizontal(Efl_Ui_Dir dir)
+_is_horizontal(Efl_Ui_Layout_Orientation dir)
 {
-   return efl_ui_dir_is_horizontal(dir, EINA_TRUE);
-}
-
-static inline Eina_Bool
-_is_inverted(Efl_Ui_Dir dir)
-{
-   if ((dir == EFL_UI_DIR_LEFT) || (dir == EFL_UI_DIR_DOWN))
-     return EINA_TRUE;
-
-   return EINA_FALSE;
+   return efl_ui_layout_orientation_is_horizontal(dir, EINA_TRUE);
 }
 
 static void
-_efl_ui_slider_val_fetch(Evas_Object *obj, Efl_Ui_Slider_Data *sd,  Eina_Bool user_event)
+_emit_events(Eo *obj, Efl_Ui_Slider_Data *sd)
 {
-   Eina_Bool rtl;
-   double posx = 0.0, posy = 0.0, pos = 0.0, val;
+   efl_event_callback_call(obj, EFL_UI_RANGE_EVENT_CHANGED, NULL);
 
+   if (sd->val == sd->val_min)
+     efl_event_callback_call(obj, EFL_UI_RANGE_EVENT_MIN_REACHED, NULL);
+
+   if (sd->val == sd->val_max)
+     efl_event_callback_call(obj, EFL_UI_RANGE_EVENT_MAX_REACHED, NULL);
+
+   // emit accessibility event also if value was changed by API
+   if (_elm_config->atspi_mode)
+     efl_access_value_changed_signal_emit(obj);
+}
+
+static void
+_user_value_update(Evas_Object *obj, double value)
+{
+   EFL_UI_SLIDER_DATA_GET(obj, sd);
+
+   efl_ui_range_value_set(obj, value);
+
+   ecore_timer_del(sd->delay);
+   sd->delay = ecore_timer_add(SLIDER_DELAY_CHANGED_INTERVAL, _delay_change, obj);
+
+   evas_object_smart_changed(obj);
+}
+
+static void
+_drag_value_fetch(Evas_Object *obj)
+{
+   EFL_UI_SLIDER_DATA_GET(obj, sd);
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
-   if (elm_widget_is_legacy(obj))
-     efl_ui_drag_value_get(efl_part(wd->resize_obj, "elm.dragable.slider"),
-                           &posx, &posy);
-   else
-     efl_ui_drag_value_get(efl_part(wd->resize_obj, "efl.dragable.slider"),
+   double posx = 0.0, posy = 0.0, pos = 0.0, val;
+
+   efl_ui_drag_value_get(efl_part(wd->resize_obj, "efl.draggable.slider"),
                            &posx, &posy);
    if (_is_horizontal(sd->dir)) pos = posx;
    else pos = posy;
 
-   rtl = efl_ui_mirrored_get(obj);
-   if ((!rtl && _is_inverted(sd->dir)) ||
-       (rtl && ((sd->dir == EFL_UI_DIR_UP) ||
-                (sd->dir == EFL_UI_DIR_RIGHT))))
+   if (efl_ui_mirrored_get(obj) ^ efl_ui_layout_orientation_is_inverted(sd->dir))
      {
         pos = 1.0 - pos;
      }
@@ -86,90 +99,39 @@ _efl_ui_slider_val_fetch(Evas_Object *obj, Efl_Ui_Slider_Data *sd,  Eina_Bool us
 
    if (fabs(val - sd->val) > DBL_EPSILON)
      {
-        sd->val = val;
-        if (user_event)
-          {
-             efl_event_callback_call(obj, EFL_UI_SLIDER_EVENT_CHANGED, NULL);
-             efl_event_callback_legacy_call(obj, EFL_UI_SLIDER_EVENT_CHANGED, NULL);
-             ecore_timer_del(sd->delay);
-             sd->delay = ecore_timer_add(SLIDER_DELAY_CHANGED_INTERVAL, _delay_change, obj);
-          }
+        _user_value_update(obj, val);
      }
 }
 
 static void
-_efl_ui_slider_val_set(Evas_Object *obj, Efl_Ui_Slider_Data *sd)
+_adjust_to_step(Efl_Ui_Slider *obj,  Efl_Ui_Slider_Data *pd)
 {
+   if (pd->step)
+     {
+        double relative_step = pd->step/(pd->val_max - pd->val_min);
+        double new_value = (round(pd->val/relative_step))*relative_step;
+        _user_value_update(obj, new_value);
+     }
+}
+
+static void
+_drag_value_update(Evas_Object *obj)
+{
+   EFL_UI_SLIDER_DATA_GET(obj, sd);
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
-   Eina_Bool rtl;
    double pos;
 
-   if (sd->val_max > sd->val_min)
-     {
-        pos = (sd->val - sd->val_min) / (sd->val_max - sd->val_min);
-     }
-   else
-     {
-        pos = 0.0;
-     }
+   pos = (sd->val - sd->val_min) / (sd->val_max - sd->val_min);
 
-   if (pos < 0.0) pos = 0.0;
-   else if (pos > 1.0)
-     pos = 1.0;
-
-   rtl = efl_ui_mirrored_get(obj);
-   if ((!rtl && _is_inverted(sd->dir)) ||
-       (rtl && ((sd->dir == EFL_UI_DIR_UP) ||
-                (sd->dir == EFL_UI_DIR_RIGHT))))
+   if (efl_ui_mirrored_get(obj) ^ efl_ui_layout_orientation_is_inverted(sd->dir))
      {
         pos = 1.0 - pos;
      }
 
-   if (elm_widget_is_legacy(obj))
-     efl_ui_drag_value_set(efl_part(wd->resize_obj, "elm.dragable.slider"),
-                           pos, pos);
-   else
-     efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.dragable.slider"),
+   efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.draggable.slider"),
                            pos, pos);
 
-   // emit accessibility event also if value was changed by API
-   if (_elm_config->atspi_mode)
-     efl_access_value_changed_signal_emit(obj);
-
-   evas_object_smart_changed(obj);
-}
-
-static void
-_efl_ui_slider_down_knob(Evas_Object *obj, Efl_Ui_Slider_Data *sd EINA_UNUSED, double button_x, double button_y)
-{
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
-
-   if (elm_widget_is_legacy(obj))
-     efl_ui_drag_value_set(efl_part(wd->resize_obj, "elm.dragable.slider"),
-                           button_x, button_y);
-   else
-     efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.dragable.slider"),
-                           button_x, button_y);
-}
-
-static void
-_efl_ui_slider_move_knob(Evas_Object *obj, Efl_Ui_Slider_Data *sd EINA_UNUSED, double button_x, double button_y)
-{
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
-
-   if (elm_widget_is_legacy(obj))
-     efl_ui_drag_value_set(efl_part(wd->resize_obj, "elm.dragable.slider"),
-                           button_x, button_y);
-   else
-     efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.dragable.slider"),
-                           button_x, button_y);
-}
-
-static void
-_slider_update(Evas_Object *obj, Eina_Bool user_event)
-{
-   efl_ui_slider_val_fetch(obj, user_event);
    evas_object_smart_changed(obj);
 }
 
@@ -179,7 +141,7 @@ _drag(void *data,
       const char *emission EINA_UNUSED,
       const char *source EINA_UNUSED)
 {
-   _slider_update(data, EINA_TRUE);
+   _drag_value_fetch(data);
 }
 
 static void
@@ -190,8 +152,8 @@ _drag_start(void *data,
 {
    if (!efl_ui_focus_object_focus_get(data))
      elm_object_focus_set(data, EINA_TRUE);
-   _slider_update(data, EINA_TRUE);
    efl_event_callback_call(data, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_START, NULL);
+   _drag_value_fetch(data);
    elm_widget_scroll_freeze_push(data);
 }
 
@@ -201,7 +163,7 @@ _drag_stop(void *data,
            const char *emission EINA_UNUSED,
            const char *source EINA_UNUSED)
 {
-   _slider_update(data, EINA_TRUE);
+   _drag_value_fetch(data);
    efl_event_callback_call(data, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP, NULL);
    elm_widget_scroll_freeze_pop(data);
 }
@@ -212,51 +174,47 @@ _drag_step(void *data,
            const char *emission EINA_UNUSED,
            const char *source EINA_UNUSED)
 {
-   _slider_update(data, EINA_TRUE);
+   _drag_value_fetch(data);
 }
 
 static void
-_drag_up(void *data,
-         Evas_Object *obj,
-         const char *emission EINA_UNUSED,
-         const char *source EINA_UNUSED)
+_drag_up(Evas_Object *obj)
 {
    double step;
+   double relative_step;
+
+   EFL_UI_SLIDER_DATA_GET(obj, sd);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
-   EFL_UI_SLIDER_DATA_GET(data, sd);
    step = sd->step;
 
-   if (_is_inverted(sd->dir)) step *= -1.0;
+   if (efl_ui_layout_orientation_is_inverted(sd->dir)) step *= -1.0;
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(data, wd);
-   if (elm_widget_is_legacy(obj))
-     efl_ui_drag_step_move(efl_part(wd->resize_obj, "elm.dragable.slider"),
-                           step, step);
-   else
-     efl_ui_drag_step_move(efl_part(wd->resize_obj, "efl.dragable.slider"),
-                           step, step);
+   relative_step = step/(sd->val_max - sd->val_min);
+
+   efl_ui_drag_step_move(efl_part(wd->resize_obj, "efl.draggable.slider"),
+                           relative_step, relative_step);
+   _drag_value_fetch(obj);
 }
 
 static void
-_drag_down(void *data,
-           Evas_Object *obj,
-           const char *emission EINA_UNUSED,
-           const char *source EINA_UNUSED)
+_drag_down(Evas_Object *obj)
 {
    double step;
+   double relative_step;
+
+   EFL_UI_SLIDER_DATA_GET(obj, sd);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
-   EFL_UI_SLIDER_DATA_GET(data, sd);
    step = -sd->step;
 
-   if (_is_inverted(sd->dir)) step *= -1.0;
+   if (efl_ui_layout_orientation_is_inverted(sd->dir)) step *= -1.0;
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(data, wd);
-   if (elm_widget_is_legacy(obj))
-     efl_ui_drag_step_move(efl_part(wd->resize_obj, "elm.dragable.slider"),
-                           step, step);
-   else
-     efl_ui_drag_step_move(efl_part(wd->resize_obj, "efl.dragable.slider"),
-                           step, step);
+   relative_step = step/(sd->val_max - sd->val_min);
+
+   efl_ui_drag_step_move(efl_part(wd->resize_obj, "efl.draggable.slider"),
+                           relative_step, relative_step);
+   _drag_value_fetch(obj);
 }
 
 static Eina_Bool
@@ -264,42 +222,46 @@ _key_action_drag(Evas_Object *obj, const char *params)
 {
    EFL_UI_SLIDER_DATA_GET(obj, sd);
    const char *dir = params;
+   double old_value, new_value;
+
+   old_value = efl_ui_range_value_get(obj);
 
    if (!strcmp(dir, "left"))
      {
         if (!_is_horizontal(sd->dir))
           return EINA_FALSE;
-        if (!_is_inverted(sd->dir))
-          _drag_down(obj, NULL, NULL, NULL);
-        else _drag_up(obj, NULL, NULL, NULL);
+        if (!efl_ui_layout_orientation_is_inverted(sd->dir))
+          _drag_down(obj);
+        else _drag_up(obj);
      }
    else if (!strcmp(dir, "right"))
      {
         if (!_is_horizontal(sd->dir))
           return EINA_FALSE;
-        if (!_is_inverted(sd->dir))
-          _drag_up(obj, NULL, NULL, NULL);
-        else _drag_down(obj, NULL, NULL, NULL);
+        if (!efl_ui_layout_orientation_is_inverted(sd->dir))
+          _drag_up(obj);
+        else _drag_down(obj);
      }
    else if (!strcmp(dir, "up"))
      {
         if (_is_horizontal(sd->dir))
           return EINA_FALSE;
-        if (_is_inverted(sd->dir))
-          _drag_up(obj, NULL, NULL, NULL);
-        else _drag_down(obj, NULL, NULL, NULL);
+        if (efl_ui_layout_orientation_is_inverted(sd->dir))
+          _drag_up(obj);
+        else _drag_down(obj);
      }
    else if (!strcmp(dir, "down"))
      {
         if (_is_horizontal(sd->dir))
           return EINA_FALSE;
-        if (_is_inverted(sd->dir))
-          _drag_down(obj, NULL, NULL, NULL);
-        else _drag_up(obj, NULL, NULL, NULL);
+        if (efl_ui_layout_orientation_is_inverted(sd->dir))
+          _drag_down(obj);
+        else _drag_up(obj);
      }
    else return EINA_FALSE;
 
-   return EINA_TRUE;
+   new_value = efl_ui_range_value_get(obj);
+   return !EINA_DBL_EQ(new_value, old_value);
 }
 
 // _slider_efl_ui_widget_widget_input_event_handler
@@ -325,22 +287,22 @@ _efl_ui_slider_efl_ui_widget_widget_input_event_handler(Eo *obj, Efl_Ui_Slider_D
         if (efl_input_pointer_wheel_delta_get(ev) < 0)
           {
              if (_is_horizontal(sd->dir))
-               _drag_up(obj, NULL, NULL, NULL);
+               _drag_up(obj);
              else
-               _drag_down(obj, NULL, NULL, NULL);
+               _drag_down(obj);
           }
         else
           {
              if (_is_horizontal(sd->dir))
-               _drag_down(obj, NULL, NULL, NULL);
+               _drag_down(obj);
              else
-               _drag_up(obj, NULL, NULL, NULL);
+               _drag_up(obj);
           }
         efl_input_processed_set(ev, EINA_TRUE);
      }
    else return EINA_FALSE;
 
-   _slider_update(obj, EINA_TRUE);
+   _drag_value_fetch(obj);
 
    return EINA_TRUE;
 }
@@ -354,19 +316,19 @@ _efl_ui_slider_efl_ui_widget_on_access_activate(Eo *obj, Efl_Ui_Slider_Data *sd,
    if ((act == EFL_UI_ACTIVATE_UP) ||
        (act == EFL_UI_ACTIVATE_RIGHT))
      {
-        if (!_is_inverted(sd->dir))
-          _drag_up(obj, NULL, NULL, NULL);
-        else _drag_down(obj, NULL, NULL, NULL);
+        if (!efl_ui_layout_orientation_is_inverted(sd->dir))
+          _drag_up(obj);
+        else _drag_down(obj);
      }
    else if ((act == EFL_UI_ACTIVATE_DOWN) ||
             (act == EFL_UI_ACTIVATE_LEFT))
      {
-        if (!_is_inverted(sd->dir))
-          _drag_down(obj, NULL, NULL, NULL);
-        else _drag_up(obj, NULL, NULL, NULL);
+        if (!efl_ui_layout_orientation_is_inverted(sd->dir))
+          _drag_down(obj);
+        else _drag_up(obj);
      }
 
-   _slider_update(obj, EINA_TRUE);
+   _drag_value_fetch(obj);
 
    return EINA_TRUE;
 }
@@ -440,22 +402,12 @@ _efl_ui_slider_efl_ui_widget_theme_apply(Eo *obj, Efl_Ui_Slider_Data *sd)
    int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
    if (int_ret == EFL_UI_THEME_APPLY_ERROR_GENERIC) return int_ret;
 
-   if (elm_widget_is_legacy(obj))
-     {
-        if (_is_inverted(sd->dir))
-          efl_layout_signal_emit(obj, "elm,state,inverted,on", "elm");
-        else
-          efl_layout_signal_emit(obj, "elm,state,inverted,off", "elm");
-     }
+   if (efl_ui_layout_orientation_is_inverted(sd->dir))
+     efl_layout_signal_emit(obj, "efl,state,inverted,on", "efl");
    else
-     {
-        if (_is_inverted(sd->dir))
-          efl_layout_signal_emit(obj, "efl,state,inverted,on", "efl");
-        else
-          efl_layout_signal_emit(obj, "efl,state,inverted,off", "efl");
-     }
+     efl_layout_signal_emit(obj, "efl,state,inverted,off", "efl");
 
-   efl_ui_slider_val_set(obj);
+   _drag_value_update(obj);
 
    efl_layout_signal_process(wd->resize_obj, EINA_FALSE);
    evas_object_smart_changed(obj);
@@ -463,19 +415,6 @@ _efl_ui_slider_efl_ui_widget_theme_apply(Eo *obj, Efl_Ui_Slider_Data *sd)
    return int_ret;
 }
 
-EOLIAN static void
-_efl_ui_slider_elm_layout_sizing_eval(Eo *obj, Efl_Ui_Slider_Data *_pd EINA_UNUSED)
-{
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
-   Evas_Coord minw = -1, minh = -1;
-
-   elm_coords_finger_size_adjust(1, &minw, 1, &minh);
-   edje_object_size_min_restricted_calc
-     (wd->resize_obj, &minw, &minh, minw, minh);
-   efl_gfx_hint_size_restricted_min_set(obj, EINA_SIZE2D(minw, minh));
-   efl_gfx_hint_size_max_set(obj, EINA_SIZE2D(-1, -1));
-}
-
 static void
 _spacer_down_cb(void *data,
                 Evas *e EINA_UNUSED,
@@ -483,6 +422,7 @@ _spacer_down_cb(void *data,
                 void *event_info)
 {
    EFL_UI_SLIDER_DATA_GET(data, sd);
+   ELM_WIDGET_DATA_GET_OR_RETURN(data, wd);
 
    Evas_Event_Mouse_Down *ev = event_info;
    Eina_Rect sr;
@@ -505,12 +445,13 @@ _spacer_down_cb(void *data,
         if (button_y < 0) button_y = 0;
      }
 
-   efl_ui_slider_down_knob(data, button_x, button_y);
+   efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.draggable.slider"),
+                           button_x, button_y);
 
    if (!efl_ui_focus_object_focus_get(data))
      elm_object_focus_set(data, EINA_TRUE);
-   _slider_update(data, EINA_TRUE);
    efl_event_callback_call(data, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_START, NULL);
+   _drag_value_fetch(data);
 }
 
 static void
@@ -520,6 +461,7 @@ _spacer_move_cb(void *data,
                 void *event_info)
 {
    EFL_UI_SLIDER_DATA_GET(data, sd);
+   ELM_WIDGET_DATA_GET_OR_RETURN(data, wd);
 
    Eina_Rect sr;
    double button_x = 0.0, button_y = 0.0;
@@ -546,7 +488,7 @@ _spacer_move_cb(void *data,
         if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD)
           {
              if (sd->spacer_down) sd->spacer_down = EINA_FALSE;
-             _slider_update(data, EINA_TRUE);
+             _drag_value_fetch(data);
              efl_event_callback_call
                (data, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP, NULL);
              if (sd->frozen)
@@ -569,8 +511,9 @@ _spacer_move_cb(void *data,
              if (button_y < 0) button_y = 0;
           }
 
-        efl_ui_slider_move_knob(data, button_x, button_y);
-        _slider_update(data, EINA_TRUE);
+        efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.draggable.slider"),
+                              button_x, button_y);
+        _drag_value_fetch(data);
      }
 }
 
@@ -585,7 +528,8 @@ _spacer_up_cb(void *data,
    if (!sd->spacer_down) return;
    if (sd->spacer_down) sd->spacer_down = EINA_FALSE;
 
-   _slider_update(data, EINA_TRUE);
+   _drag_value_fetch(data);
+   _adjust_to_step(data, sd);
    efl_event_callback_call(data, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP, NULL);
 
    if (sd->frozen)
@@ -665,7 +609,7 @@ _efl_ui_slider_efl_object_constructor(Eo *obj, Efl_Ui_Slider_Data *priv)
 
    free(group);
 
-   priv->dir = EFL_UI_DIR_RIGHT;
+   priv->dir = EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL;
    priv->val_max = 1.0;
    priv->step = SLIDER_STEP;
 
@@ -676,13 +620,9 @@ _efl_ui_slider_efl_object_constructor(Eo *obj, Efl_Ui_Slider_Data *priv)
    efl_layout_signal_callback_add(obj, "drag,page", "*", obj, _drag_stop, NULL);
 
    priv->spacer = efl_add(EFL_CANVAS_RECTANGLE_CLASS, obj,
-                          efl_gfx_color_set(efl_added, 0, 0, 0, 0),
-                          efl_canvas_object_pass_events_set(efl_added, EINA_TRUE));
+                          efl_gfx_color_set(efl_added, 0, 0, 0, 0));
 
-   if (elm_widget_is_legacy(obj))
-     efl_content_set(efl_part(obj, "elm.swallow.bar"), priv->spacer);
-   else
-     efl_content_set(efl_part(obj, "efl.bar"), priv->spacer);
+   efl_content_set(efl_part(obj, "efl.bar"), priv->spacer);
 
    evas_object_event_callback_add
      (priv->spacer, EVAS_CALLBACK_MOUSE_DOWN, _spacer_down_cb, obj);
@@ -721,33 +661,48 @@ _efl_ui_slider_efl_object_destructor(Eo *obj,
 }
 
 EOLIAN static void
-_efl_ui_slider_efl_ui_direction_direction_set(Eo *obj, Efl_Ui_Slider_Data *sd, Efl_Ui_Dir dir)
+_efl_ui_slider_efl_ui_layout_orientable_orientation_set(Eo *obj, Efl_Ui_Slider_Data *sd, Efl_Ui_Layout_Orientation dir)
 {
    sd->dir = dir;
 
    efl_ui_widget_theme_apply(obj);
 }
 
-EOLIAN static Efl_Ui_Dir
-_efl_ui_slider_efl_ui_direction_direction_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd)
+EOLIAN static Efl_Ui_Layout_Orientation
+_efl_ui_slider_efl_ui_layout_orientable_orientation_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd)
 {
    return sd->dir;
 }
 
 EOLIAN static void
-_efl_ui_slider_efl_ui_range_display_range_min_max_set(Eo *obj, Efl_Ui_Slider_Data *sd, double min, double max)
+_efl_ui_slider_efl_ui_range_display_range_limits_set(Eo *obj, Efl_Ui_Slider_Data *sd, double min, double max)
 {
-   if ((sd->val_min == min) && (sd->val_max == max)) return;
+   double val;
+
+   if (max < min)
+     {
+        ERR("Wrong params. min(%lf) is greater than max(%lf).", min, max);
+        return;
+     }
+   if (EINA_DBL_EQ(max, min))
+     {
+        ERR("min and max must have a different value");
+        return;
+     }
+   if ((EINA_DBL_EQ(sd->val_min, min)) && (EINA_DBL_EQ(sd->val_max, max))) return;
+
    sd->val_min = min;
    sd->val_max = max;
-   if (sd->val < sd->val_min) sd->val = sd->val_min;
-   if (sd->val > sd->val_max) sd->val = sd->val_max;
 
-   efl_ui_slider_val_set(obj);
+   val = sd->val;
+   if (val < sd->val_min) val = sd->val_min;
+   if (val > sd->val_max) val = sd->val_max;
+
+   efl_ui_range_value_set(obj, val);
 }
 
 EOLIAN static void
-_efl_ui_slider_efl_ui_range_display_range_min_max_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd, double *min, double *max)
+_efl_ui_slider_efl_ui_range_display_range_limits_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd, double *min, double *max)
 {
    if (min) *min = sd->val_min;
    if (max) *max = sd->val_max;
@@ -756,13 +711,22 @@ _efl_ui_slider_efl_ui_range_display_range_min_max_get(const Eo *obj EINA_UNUSED,
 EOLIAN static void
 _efl_ui_slider_efl_ui_range_display_range_value_set(Eo *obj, Efl_Ui_Slider_Data *sd, double val)
 {
-   if (sd->val == val) return;
+   if (val < sd->val_min)
+     {
+        ERR("Error, value is less than minimum");
+        return;
+     }
+   if (val > sd->val_max)
+     {
+        ERR("Error, value is greater than maximum");
+        return;
+     }
+
+   if (EINA_DBL_EQ(val, sd->val)) return;
    sd->val = val;
 
-   if (sd->val < sd->val_min) sd->val = sd->val_min;
-   if (sd->val > sd->val_max) sd->val = sd->val_max;
-
-   efl_ui_slider_val_set(obj);
+   _drag_value_update(obj);
+   _emit_events(obj, sd);
 }
 
 EOLIAN static double
@@ -780,10 +744,13 @@ _efl_ui_slider_efl_ui_range_interactive_range_step_get(const Eo *obj EINA_UNUSED
 EOLIAN static void
 _efl_ui_slider_efl_ui_range_interactive_range_step_set(Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd, double step)
 {
-   if (sd->step == step) return;
+   if (step <= 0)
+     {
+        ERR("Wrong param. The step(%lf) should be greater than 0.0", step);
+        return;
+     }
 
-   if (step < 0.0) step = 0.0;
-   else if (step > 1.0) step = 1.0;
+   if (sd->step == step) return;
 
    sd->step = step;
 }
@@ -810,16 +777,16 @@ _efl_ui_slider_efl_access_value_value_and_text_get(const Eo *obj EINA_UNUSED, Ef
 EOLIAN static Eina_Bool
 _efl_ui_slider_efl_access_value_value_and_text_set(Eo *obj, Efl_Ui_Slider_Data *sd, double value, const char *text EINA_UNUSED)
 {
-   double oldval = sd->val;
-
    if (value < sd->val_min) value = sd->val_min;
    if (value > sd->val_max) value = sd->val_max;
 
    efl_event_callback_call(obj, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_START, NULL);
-   sd->val = value;
-   efl_ui_slider_val_set(obj);
-   sd->val = oldval;
-   _slider_update(obj, EINA_TRUE);
+
+   if (fabs(value - sd->val) > DBL_EPSILON)
+     {
+        _user_value_update(obj, value);
+     }
+
    efl_event_callback_call(obj, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP, NULL);
 
    return EINA_TRUE;
@@ -853,18 +820,5 @@ _efl_ui_slider_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSE
 }
 
 // A11Y Accessibility - END
-/* Internal EO APIs and hidden overrides */
-
-EFL_VOID_FUNC_BODYV(efl_ui_slider_val_fetch, EFL_FUNC_CALL(user_event), Eina_Bool user_event)
-EFL_VOID_FUNC_BODY(efl_ui_slider_val_set)
-EFL_VOID_FUNC_BODYV(efl_ui_slider_down_knob, EFL_FUNC_CALL(button_x, button_y), double button_x, double button_y)
-EFL_VOID_FUNC_BODYV(efl_ui_slider_move_knob, EFL_FUNC_CALL(button_x, button_y), double button_x, double button_y)
-
-#define EFL_UI_SLIDER_EXTRA_OPS \
-   ELM_LAYOUT_SIZING_EVAL_OPS(efl_ui_slider), \
-   EFL_UI_SLIDER_VAL_FETCH_OPS(efl_ui_slider), \
-   EFL_UI_SLIDER_VAL_SET_OPS(efl_ui_slider), \
-   EFL_UI_SLIDER_DOWN_KNOB_OPS(efl_ui_slider), \
-   EFL_UI_SLIDER_MOVE_KNOB_OPS(efl_ui_slider), \
 
 #include "efl_ui_slider.eo.c"
