@@ -121,11 +121,11 @@ _elm_combobox_efl_ui_widget_theme_apply(Eo *obj, Elm_Combobox_Data *sd)
 }
 
 static void
-_on_hover_clicked(void *data, const Efl_Event *event)
+_on_hover_clicked(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    const char *dismissstr;
 
-   dismissstr = elm_layout_data_get(event->object, "dismiss");
+   dismissstr = elm_layout_data_get(obj, "dismiss");
 
    if (!dismissstr || strcmp(dismissstr, "on"))
      elm_combobox_hover_end(data); // for backward compatibility
@@ -303,7 +303,7 @@ _on_changed(void *data, const Efl_Event *event EINA_UNUSED)
 }
 
 static void
-_on_clicked(void *data, const Efl_Event *event EINA_UNUSED)
+_on_clicked(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    elm_combobox_hover_begin(data);
 }
@@ -334,7 +334,7 @@ _elm_combobox_efl_canvas_group_group_add(Eo *obj, Elm_Combobox_Data *sd EINA_UNU
 
    efl_ui_mirrored_automatic_set(obj, EINA_FALSE);
 
-   efl_event_callback_add(obj, EFL_UI_EVENT_CLICKED, _on_clicked, obj);
+   evas_object_smart_callback_add(obj, "clicked", _on_clicked, obj);
 
    //What are you doing here?
    efl_ui_widget_theme_apply(obj);
@@ -364,11 +364,14 @@ _elm_combobox_efl_gfx_entity_visible_set(Eo *obj, Elm_Combobox_Data *sd, Eina_Bo
      }
 }
 
-EOLIAN static Eina_Bool
-_elm_combobox_efl_ui_autorepeat_autorepeat_supported_get(const Eo *obj EINA_UNUSED,
-                                                         Elm_Combobox_Data *sd EINA_UNUSED)
+EOLIAN static void
+_elm_combobox_efl_ui_autorepeat_autorepeat_enabled_set(const Eo *obj EINA_UNUSED,
+                                                       Elm_Combobox_Data *sd EINA_UNUSED,
+                                                       Eina_Bool enabled)
 {
-   return EINA_FALSE;
+   if (enabled)
+     ERR("You cannot enable autorepeat on this object");
+   efl_ui_autorepeat_enabled_set(efl_super(obj, MY_CLASS), EINA_FALSE);
 }
 
 EAPI Evas_Object *
@@ -389,6 +392,7 @@ _elm_combobox_efl_object_constructor(Eo *obj, Elm_Combobox_Data *sd)
 
    sd->first_filter = EINA_TRUE;
 
+   efl_ui_autorepeat_enabled_set(obj, EINA_FALSE);
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
    efl_access_object_role_set(obj, EFL_ACCESS_ROLE_GLASS_PANE);
@@ -406,8 +410,7 @@ _elm_combobox_efl_object_constructor(Eo *obj, Elm_Combobox_Data *sd)
    elm_hover_target_set(sd->hover, obj);
    elm_widget_sub_object_add(obj, sd->hover);
 
-   efl_event_callback_add
-     (sd->hover, EFL_UI_EVENT_CLICKED, _on_hover_clicked, obj);
+   evas_object_smart_callback_add(sd->hover, "clicked", _on_hover_clicked, obj);
    elm_layout_signal_callback_add
      (sd->hover, "elm,action,hide,finished", "elm", _hover_end_finished, obj);
 
@@ -526,7 +529,7 @@ _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
      elm_combobox_hover_begin(obj);
    else
      {
-        efl_event_callback_legacy_call(sd->genlist, EFL_UI_EVENT_PRESSED, sd->item);
+        evas_object_smart_callback_call(sd->genlist, "pressed", sd->item);
         elm_entry_cursor_end_set(sd->entry);
      }
    return EINA_TRUE;
@@ -609,7 +612,7 @@ _elm_combobox_class_initializer(Efl_Class *klass)
       EFL_OBJECT_OP_FUNC(efl_ui_widget_theme_apply, _elm_combobox_efl_ui_widget_theme_apply),
       EFL_OBJECT_OP_FUNC(efl_ui_l10n_translation_update, _elm_combobox_efl_ui_l10n_translation_update),
       EFL_OBJECT_OP_FUNC(efl_ui_widget_input_event_handler, _elm_combobox_efl_ui_widget_widget_input_event_handler),
-      EFL_OBJECT_OP_FUNC(efl_ui_autorepeat_supported_get, _elm_combobox_efl_ui_autorepeat_autorepeat_supported_get),
+      EFL_OBJECT_OP_FUNC(efl_ui_autorepeat_enabled_set, _elm_combobox_efl_ui_autorepeat_autorepeat_enabled_set),
       EFL_OBJECT_OP_FUNC(elm_obj_genlist_filter_set, _elm_combobox_elm_genlist_filter_set),
       EFL_OBJECT_OP_FUNC(efl_access_widget_action_elm_actions_get, _elm_combobox_efl_access_widget_action_elm_actions_get),
       EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_combobox)
@@ -628,7 +631,7 @@ static const Efl_Class_Description _elm_combobox_class_desc = {
    NULL
 };
 
-EFL_DEFINE_CLASS(elm_combobox_class_get, &_elm_combobox_class_desc, EFL_UI_BUTTON_CLASS, EFL_UI_SELECTABLE_INTERFACE, EFL_ACCESS_WIDGET_ACTION_MIXIN, ELM_ENTRY_CLASS, ELM_GENLIST_CLASS, ELM_HOVER_CLASS, EFL_UI_LEGACY_INTERFACE, NULL);
+EFL_DEFINE_CLASS(elm_combobox_class_get, &_elm_combobox_class_desc, EFL_UI_BUTTON_CLASS, EFL_ACCESS_WIDGET_ACTION_MIXIN, ELM_ENTRY_CLASS, ELM_GENLIST_CLASS, ELM_HOVER_CLASS, EFL_UI_LEGACY_INTERFACE, NULL);
 
 EAPI Eina_Bool
 elm_combobox_expanded_get(const Elm_Combobox *obj)
