@@ -48,7 +48,6 @@ EOLIAN static void
 _elm_access_efl_canvas_group_group_add(Eo *obj, void *_pd EINA_UNUSED)
 {
    efl_canvas_group_add(efl_super(obj, MY_CLASS));
-   elm_widget_sub_object_parent_add(obj);
 }
 
 static Eina_Bool
@@ -701,7 +700,7 @@ _elm_access_highlight_cycle(Evas_Object *obj, Elm_Focus_Direction dir)
           }
         else
           {
-             efl_ui_focus_util_focus(EFL_UI_FOCUS_UTIL_CLASS, obj);
+             efl_ui_focus_util_focus(obj);
              efl_ui_focus_manager_move(elm_widget_top_get(obj), dir);
           }
      }
@@ -869,8 +868,7 @@ _elm_access_object_highlight(Evas_Object *obj)
                                   _access_obj_hilight_resize_cb, NULL);
    evas_object_raise(o);
    evas_object_geometry_get(obj, &x, &y, &w, &h);
-   evas_object_move(o, x, y);
-   evas_object_resize(o, w, h);
+   evas_object_geometry_set(o, x, y, w, h);
 
    widget = _elm_access_widget_target_get(obj);
    if (widget)
@@ -965,8 +963,7 @@ _access_object_register(Evas_Object *obj, Evas_Object *parent)
                                   _content_move, ao);
 
    evas_object_geometry_get(obj, &x, &y, &w, &h);
-   evas_object_move(ao, x, y);
-   evas_object_resize(ao, w, h);
+   evas_object_geometry_set(ao, x, y, w, h);
    evas_object_show(ao);
 
    /* register access object */
@@ -1209,8 +1206,7 @@ _elm_access_widget_item_register(Elm_Widget_Item_Data *item)
                                   _content_move, ao);
 
    evas_object_geometry_get(ho, &x, &y, &w, &h);
-   evas_object_move(ao, x, y);
-   evas_object_resize(ao, w, h);
+   evas_object_geometry_set(ao, x, y, w, h);
    evas_object_show(ao);
 
    // register access object
@@ -1534,8 +1530,8 @@ _elm_access_efl_access_object_state_set_get(const Eo *obj, void *pd EINA_UNUSED)
    Elm_Access_Info *info = _elm_access_info_get(obj);
    if (info && !evas_object_visible_get(info->part_object))
      {
-        STATE_TYPE_UNSET(ret, EFL_ACCESS_STATE_VISIBLE);
-        STATE_TYPE_UNSET(ret, EFL_ACCESS_STATE_SHOWING);
+        STATE_TYPE_UNSET(ret, EFL_ACCESS_STATE_TYPE_VISIBLE);
+        STATE_TYPE_UNSET(ret, EFL_ACCESS_STATE_TYPE_SHOWING);
      }
 
    return ret;
@@ -1546,4 +1542,4 @@ _elm_access_efl_access_object_state_set_get(const Eo *obj, void *pd EINA_UNUSED)
 #define ELM_ACCESS_EXTRA_OPS \
    EFL_CANVAS_GROUP_ADD_OPS(elm_access)
 
-#include "elm_access.eo.c"
+#include "elm_access_eo.c"
