@@ -311,7 +311,7 @@ _elm_code_widget_fill_whitespace(Elm_Code_Widget *widget, Eina_Unicode character
 static void
 _elm_code_widget_cursor_update(Elm_Code_Widget *widget, Elm_Code_Widget_Data *pd)
 {
-   Evas_Coord cx, cy, cw, ch;
+   Evas_Coord cx = 0, cy = 0, cw = 0, ch = 0;
 
    elm_code_widget_geometry_for_position_get(widget, pd->cursor_line, pd->cursor_col, &cx, &cy, &cw, &ch);
 
@@ -542,6 +542,8 @@ _elm_code_widget_refresh(Elm_Code_Widget *widget, Elm_Code_Line *line)
      return ;
 
    _elm_code_widget_fill_update(widget, first_row, last_row, line);
+   if (pd->editable)
+     _elm_code_widget_cursor_update(widget, pd);
 }
 
 static void
@@ -798,6 +800,7 @@ _elm_code_widget_geometry_for_position_get(Elm_Code_Widget *widget, Elm_Code_Wid
    gutter = efl_ui_code_widget_text_left_gutter_width_get(widget);
 
    grid = eina_list_nth(pd->grids, row - 1);
+   evas_object_smart_calculate(pd->gridbox);
    evas_object_geometry_get(grid, x, y, NULL, NULL);
 
    if (x)
@@ -1440,7 +1443,7 @@ _elm_code_widget_change_create(unsigned int start_col, unsigned int start_line,
    info->end_col = end_col;
    info->end_line = end_line;
 
-   info->content = strndup(text, length);
+   info->content = eina_strndup(text, length);
    info->length = length;
 
    return info;
@@ -1524,7 +1527,7 @@ _elm_code_widget_newline(Elm_Code_Widget *widget)
         line = elm_code_file_line_get(code->file, row);
      }
    oldtext = (char *) elm_code_line_text_get(line, &oldlen);
-   oldtext = strndup(oldtext, oldlen);
+   oldtext = eina_strndup(oldtext, oldlen);
 
    position = elm_code_widget_line_text_position_for_column_get(widget, line, col);
    elm_code_line_split_at(line, position);
@@ -1891,7 +1894,7 @@ _elm_code_widget_efl_ui_widget_widget_input_event_handler(Eo *obj EINA_UNUSED, E
    if (eo_event->desc != EFL_EVENT_KEY_DOWN) return EINA_FALSE;
 
    // FIXME: This should use key bindings and the standard implementation!
-   if (eina_streq(efl_input_key_get(ev), "BackSpace"))
+   if (eina_streq(efl_input_key_sym_get(ev), "BackSpace"))
      {
         efl_input_processed_set(ev, EINA_TRUE);
         return EINA_TRUE;
