@@ -1668,3 +1668,19 @@ EINA_DEPRECATED EAPI char *elm_access_external_info_get(const Evas_Object *obj);
 // elm_win
 EINA_DEPRECATED EAPI void elm_win_type_set(Evas_Object *obj, Elm_Win_Type type);
 EINA_DEPRECATED EAPI void elm_win_name_set(Evas_Object *obj, const char *name);
+
+/**
+ * @brief Set a circle with given center, radius, and start angle.
+ *
+ * @param[in] obj The object.
+ * @param[in] x X coordinate of center
+ * @param[in] y Y coordinate of center
+ * @param[in] radius Radius of the circle
+ * @param[in] start_angle Start angle of the circle
+ * @param[in] direction Textpath direction
+ *
+ * @deprecated Use elm_textpath_circluar_set() instead.
+ *
+ * @ingroup Elm_Textpath_Group
+ */
+EINA_DEPRECATED EAPI void elm_textpath_circle_set(Efl_Ui_Textpath *obj, double x, double y, double radius, double start_angle, Efl_Ui_Textpath_Direction direction);
