@@ -20,7 +20,7 @@
 #define MY_CLASS_NAME "Elm_Notify"
 #define MY_CLASS_NAME_LEGACY "elm_notify"
 
-static Efl_Ui_Theme_Apply
+static Eina_Error
 _notify_theme_apply(Evas_Object *obj)
 {
    const char *style = elm_widget_style_get(obj);
@@ -96,8 +96,7 @@ _notify_move_to_orientation(Evas_Object *obj, Evas_Coord x, Evas_Coord y, Evas_C
    x = x + ((w - minw) * ax);
    y = y + ((h - minh) * ay);
 
-   evas_object_move(sd->notify, x, y);
-   evas_object_resize(sd->notify, minw, minh);
+   evas_object_geometry_set(sd->notify, x, y, minw, minh);
 }
 
 static void
@@ -137,20 +136,23 @@ _sizing_eval(Evas_Object *obj)
         x = 0;
         y = 0;
      }
-   evas_object_move(obj, x, y);
-   evas_object_resize(obj, w, h);
+   evas_object_geometry_set(obj, x, y, w, h);
 }
 
-EOLIAN static Efl_Ui_Theme_Apply
+EOLIAN static Eina_Error
 _elm_notify_efl_ui_widget_theme_apply(Eo *obj, Elm_Notify_Data *sd)
 {
-   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   Eina_Error int_ret = EFL_UI_THEME_APPLY_ERROR_GENERIC;
+   Eina_Error notify_theme_ret = EFL_UI_THEME_APPLY_ERROR_GENERIC;
    int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
+   if (int_ret == EFL_UI_THEME_APPLY_ERROR_GENERIC) return int_ret;
 
    _mirrored_set(obj, efl_ui_mirrored_get(obj));
 
-   int_ret &= _notify_theme_apply(obj);
+   notify_theme_ret = _notify_theme_apply(obj);
+   if (notify_theme_ret == EFL_UI_THEME_APPLY_ERROR_GENERIC)
+     return notify_theme_ret;
+
    if (sd->block_events) _block_events_theme_apply(obj);
 
    edje_object_scale_set
@@ -158,7 +160,11 @@ _elm_notify_efl_ui_widget_theme_apply(Eo *obj, Elm_Notify_Data *sd)
 
    _sizing_eval(obj);
 
-   return int_ret;
+   if ((int_ret == EFL_UI_THEME_APPLY_ERROR_DEFAULT) ||
+       (notify_theme_ret == EFL_UI_THEME_APPLY_ERROR_DEFAULT))
+     return EFL_UI_THEME_APPLY_ERROR_DEFAULT;
+
+   return EFL_UI_THEME_APPLY_ERROR_NONE;
 }
 
 /* Legacy compat. Note that notify has no text parts in the default theme... */
@@ -376,6 +382,7 @@ _elm_notify_content_set(Eo *obj, Elm_Notify_Data *sd, const char *part, Evas_Obj
           _changed_size_hints_cb, obj);
         edje_object_part_swallow(sd->notify, "elm.swallow.content", content);
      }
+   efl_event_callback_call(obj, EFL_CONTENT_EVENT_CONTENT_CHANGED, content);
 
    _calc(obj);
 
@@ -401,6 +408,7 @@ _elm_notify_content_unset(Eo *obj, Elm_Notify_Data *sd, const char *part)
    content = sd->content;
    _elm_widget_sub_object_redirect_to_top(obj, sd->content);
    edje_object_part_unswallow(sd->notify, content);
+   efl_event_callback_call(obj, EFL_CONTENT_EVENT_CONTENT_CHANGED, NULL);
 
    return content;
 }
@@ -441,7 +449,6 @@ EOLIAN static void
 _elm_notify_efl_canvas_group_group_add(Eo *obj, Elm_Notify_Data *priv)
 {
    efl_canvas_group_add(efl_super(obj, MY_CLASS));
-   elm_widget_sub_object_parent_add(obj);
 
    priv->allow_events = EINA_TRUE;
 
@@ -474,26 +481,9 @@ elm_notify_add(Evas_Object *parent)
    return elm_legacy_add(MY_CLASS, parent);
 }
 
-EOLIAN static Eo *
-_elm_notify_efl_object_constructor(Eo *obj, Elm_Notify_Data *sd EINA_UNUSED)
-{
-   obj = efl_constructor(efl_super(obj, MY_CLASS));
-   efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
-   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_NOTIFICATION);
 
-   return obj;
-}
-
-EAPI void
-elm_notify_parent_set(Evas_Object *obj,
-                      Evas_Object *parent)
-{
-   ELM_NOTIFY_CHECK(obj);
-   efl_ui_widget_parent_set(obj, parent);
-}
-
-EOLIAN static void
-_elm_notify_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Notify_Data *sd, Evas_Object *parent)
+static void
+_parent_setup(Eo *obj, Elm_Notify_Data *sd, Evas_Object *parent)
 {
    if (sd->parent)
      {
@@ -530,6 +520,28 @@ _elm_notify_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Notify_Data *sd, Evas_O
    _calc(obj);
 }
 
+EOLIAN static Eo *
+_elm_notify_efl_object_constructor(Eo *obj, Elm_Notify_Data *sd EINA_UNUSED)
+{
+   obj = efl_constructor(efl_super(obj, MY_CLASS));
+   efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_NOTIFICATION);
+   _parent_setup(obj, sd, efl_parent_get(obj));
+
+   return obj;
+}
+
+EAPI void
+elm_notify_parent_set(Evas_Object *obj,
+                      Evas_Object *parent)
+{
+   ELM_NOTIFY_CHECK(obj);
+   ELM_NOTIFY_DATA_GET(obj, sd);
+   if (parent)
+     efl_ui_widget_sub_object_add(parent, obj);
+   _parent_setup(obj, sd, parent);
+}
+
 EAPI Evas_Object *
 elm_notify_parent_get(const Evas_Object *obj)
 {
@@ -539,12 +551,6 @@ elm_notify_parent_get(const Evas_Object *obj)
    return ret;
 }
 
-EOLIAN static Evas_Object*
-_elm_notify_efl_ui_widget_widget_parent_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
-{
-   return sd->parent;
-}
-
 EINA_DEPRECATED EAPI void
 elm_notify_orient_set(Evas_Object *obj,
                       Elm_Notify_Orient orient)
@@ -712,14 +718,14 @@ ELM_PART_OVERRIDE_CONTENT_UNSET(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
 ELM_PART_CONTENT_DEFAULT_GET(elm_notify, "default")
 
 EOLIAN static const char *
-_elm_notify_part_efl_ui_translatable_translatable_text_get(const Eo *obj, void *_pd EINA_UNUSED, const char **domain)
+_elm_notify_part_efl_ui_l10n_l10n_text_get(const Eo *obj, void *_pd EINA_UNUSED, const char **domain)
 {
    Elm_Part_Data *pd = efl_data_scope_get(obj, EFL_UI_WIDGET_PART_CLASS);
    return elm_widget_part_translatable_text_get(pd->obj, pd->part, domain);
 }
 
 EOLIAN static void
-_elm_notify_part_efl_ui_translatable_translatable_text_set(Eo *obj, void *_pd EINA_UNUSED, const char *label, const char *domain)
+_elm_notify_part_efl_ui_l10n_l10n_text_set(Eo *obj, void *_pd EINA_UNUSED, const char *label, const char *domain)
 {
    Elm_Part_Data *pd = efl_data_scope_get(obj, EFL_UI_WIDGET_PART_CLASS);
    elm_widget_part_translatable_text_set(pd->obj, pd->part, label, domain);
@@ -735,4 +741,4 @@ _elm_notify_part_efl_ui_translatable_translatable_text_set(Eo *obj, void *_pd EI
    ELM_PART_CONTENT_DEFAULT_OPS(elm_notify), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_notify)
 
-#include "elm_notify.eo.c"
+#include "elm_notify_eo.c"
