@@ -9,4 +9,4 @@
  */
 EAPI Evas_Object                 *elm_panel_add(Evas_Object *parent);
 
-#include "elm_panel.eo.legacy.h"
\ No newline at end of file
+#include "elm_panel_eo.legacy.h"
\ No newline at end of file
