@@ -326,7 +326,7 @@ _elm_scroller_efl_ui_widget_on_access_activate(Eo *obj, Elm_Scroller_Data *_pd E
 }
 
 EOLIAN static void
-_elm_scroller_elm_layout_sizing_eval(Eo *obj, Elm_Scroller_Data *sd)
+_elm_scroller_efl_canvas_group_group_calculate(Eo *obj, Elm_Scroller_Data *sd)
 {
    Evas_Coord vw = 0, vh = 0, minw = 0, minh = 0, maxw = 0, maxh = 0, w, h,
               vmw, vmh;
@@ -487,8 +487,7 @@ static void
 _scroll_cb(Evas_Object *obj,
            void *data EINA_UNUSED)
 {
-   efl_event_callback_legacy_call
-     (obj, EFL_UI_EVENT_SCROLL, NULL);
+   evas_object_smart_callback_call(obj, "scroll", NULL);
 }
 
 static void
@@ -523,32 +522,29 @@ static void
 _scroll_anim_start_cb(Evas_Object *obj,
                       void *data EINA_UNUSED)
 {
-   efl_event_callback_legacy_call
-     (obj, EFL_UI_EVENT_SCROLL_ANIM_START, NULL);
+   evas_object_smart_callback_call(obj, "scroll,anim,start", NULL);
 }
 
 static void
 _scroll_anim_stop_cb(Evas_Object *obj,
                      void *data EINA_UNUSED)
 {
-   efl_event_callback_legacy_call
-     (obj, EFL_UI_EVENT_SCROLL_ANIM_STOP, NULL);
+   evas_object_smart_callback_call(obj, "scroll,anim,stop", NULL);
 }
 
 static void
 _scroll_drag_start_cb(Evas_Object *obj,
                       void *data EINA_UNUSED)
 {
-   efl_event_callback_legacy_call
-     (obj, EFL_UI_EVENT_SCROLL_DRAG_START, NULL);
+   evas_object_smart_callback_call(obj, "scroll,drag,start", NULL);
 }
 
+
 static void
 _scroll_drag_stop_cb(Evas_Object *obj,
                      void *data EINA_UNUSED)
 {
-   efl_event_callback_legacy_call
-     (obj, EFL_UI_EVENT_SCROLL_DRAG_STOP, NULL);
+   evas_object_smart_callback_call(obj, "scroll,drag,stop", NULL);
 }
 
 static void
@@ -1208,13 +1204,13 @@ elm_scroller_movement_block_set(Evas_Object *obj,
                                 Elm_Scroller_Movement_Block block)
 {
    ELM_SCROLLABLE_CHECK(obj);
-   Efl_Ui_Scroll_Block mode = EFL_UI_SCROLL_BLOCK_NONE;
+   Efl_Ui_Layout_Orientation mode = EFL_UI_LAYOUT_ORIENTATION_DEFAULT;
 
    // legacy -> eo
    if (block == ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL)
-     mode = EFL_UI_SCROLL_BLOCK_HORIZONTAL;
+     mode = EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL;
    else if (block == ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL)
-     mode = EFL_UI_SCROLL_BLOCK_VERTICAL;
+     mode = EFL_UI_LAYOUT_ORIENTATION_VERTICAL;
 
    elm_interface_scrollable_movement_block_set(obj, mode);
 }
@@ -1222,16 +1218,16 @@ elm_scroller_movement_block_set(Evas_Object *obj,
 EAPI Elm_Scroller_Movement_Block
 elm_scroller_movement_block_get(const Evas_Object *obj)
 {
-   Efl_Ui_Scroll_Block mode;
+   Efl_Ui_Layout_Orientation mode;
 
    ELM_SCROLLABLE_CHECK(obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
 
    mode = elm_interface_scrollable_movement_block_get(obj);
 
    // eo -> legacy
-   if (mode == EFL_UI_SCROLL_BLOCK_HORIZONTAL)
+   if (mode == EFL_UI_LAYOUT_ORIENTATION_HORIZONTAL)
      return ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL;
-   else if (mode == EFL_UI_SCROLL_BLOCK_VERTICAL)
+   else if (mode == EFL_UI_LAYOUT_ORIENTATION_VERTICAL)
      return ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL;
 
    return ELM_SCROLLER_MOVEMENT_NO_BLOCK;
@@ -1257,14 +1253,9 @@ elm_scroller_step_size_get(const Evas_Object *obj,
    elm_interface_scrollable_step_size_get((Eo *) obj, x, y);
 }
 
-EAPI void
-elm_scroller_loop_set(Evas_Object *obj,
-                      Eina_Bool loop_h,
-                      Eina_Bool loop_v)
+EOLIAN static void
+_elm_scroller_elm_interface_scrollable_content_loop_set(Eo *obj, Elm_Scroller_Data *sd, Eina_Bool loop_h, Eina_Bool loop_v)
 {
-   ELM_SCROLLABLE_CHECK(obj);
-   ELM_SCROLLER_DATA_GET(obj, sd);
-
    int i;
 
    if (sd->loop_h == loop_h && sd->loop_v == loop_v) return;
@@ -1272,7 +1263,7 @@ elm_scroller_loop_set(Evas_Object *obj,
    sd->loop_h = loop_h;
    sd->loop_v = loop_v;
 
-   elm_interface_scrollable_content_loop_set(obj, loop_h, loop_v);
+   elm_interface_scrollable_content_loop_set(efl_super(obj, MY_CLASS), loop_h, loop_v);
 
    if (sd->content)
      {
@@ -1303,6 +1294,23 @@ elm_scroller_loop_set(Evas_Object *obj,
    elm_layout_sizing_eval(obj);
 }
 
+EAPI void
+elm_scroller_loop_set(Evas_Object *obj,
+                      Eina_Bool loop_h,
+                      Eina_Bool loop_v)
+{
+   ELM_SCROLLABLE_CHECK(obj);
+
+   elm_interface_scrollable_content_loop_set(obj, loop_h, loop_v);
+}
+
+EOLIAN static void
+_elm_scroller_elm_interface_scrollable_content_loop_get(Eo *obj EINA_UNUSED, Elm_Scroller_Data *sd, Eina_Bool *loop_h, Eina_Bool *loop_v)
+{
+   if (loop_h) *loop_h = sd->loop_h;
+   if (loop_v) *loop_v = sd->loop_v;
+}
+
 EAPI void
 elm_scroller_loop_get(const Evas_Object *obj,
                       Eina_Bool *loop_h,
@@ -1390,7 +1398,7 @@ ELM_PART_OVERRIDE_CONTENT_UNSET(elm_scroller, ELM_SCROLLER, Elm_Scroller_Data)
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_SCROLLER_EXTRA_OPS \
-   ELM_LAYOUT_SIZING_EVAL_OPS(elm_scroller), \
+   EFL_CANVAS_GROUP_CALC_OPS(elm_scroller), \
    EFL_CANVAS_GROUP_ADD_OPS(elm_scroller)
 
 #include "elm_scroller_eo.c"
