@@ -445,8 +445,8 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
      {
         const char *style = tt->style ? tt->style : "default";
         const char *str;
-        if (!_elm_theme_object_set(tt->tt_win ? : tt->owner, tt->tooltip,
-                                  "tooltip", NULL, style))
+        if (_elm_theme_object_set(tt->tt_win ? : tt->owner, tt->tooltip,
+                                  "tooltip", NULL, style) == EFL_UI_THEME_APPLY_ERROR_GENERIC)
           {
              ERR("Could not apply the theme to the tooltip! style=%s", style);
              if (tt->tt_win) evas_object_del(tt->tt_win);
@@ -654,19 +654,24 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
         if ((py + cy) > (ch / 2)) ty = cy + py - 1 - th;
         else ty = cy + py + 1;
      }
-   if (ow > 1) rel_x = (double)((ox + (ow / 2)) - ((tx - cx) + (tw / 2))) /
-     (double)(ow / 2);
-   else rel_x = 0.0;
-   if (oh > 1) rel_y = (double)((oy + (oh / 2)) - ((ty - cy) + (th / 2))) /
-     (double)(oh / 2);
-   else rel_y = 0.0;
+
+   if (inside_eventarea)
+     {
+        rel_x = (px - (tx - cx)) / (double)tw;
+        rel_y = (py - (ty - cy)) / (double)th;
+     }
+   else
+     {
+        rel_x = (ox + (ow / 2) - (tx - cx)) / (double)tw;
+        rel_y = (oy + (oh / 2) - (ty - cy)) / (double)th;
+     }
+
    tx += basex;
    ty += basey;
    // XXX: if this is a window for toolkit this relies on abs positioning
    // and this is not portable to wayland so we need relative positioning
    // implemented lower down for this
-   evas_object_move(tt->tt_win ? : tt->tooltip, tx, ty);
-   evas_object_resize(tt->tt_win ? : tt->tooltip, tw, th);
+   evas_object_geometry_set(tt->tt_win ? : tt->tooltip, tx, ty, tw, th);
    TTDBG("FINAL: tx=%d,ty=%d,tw=%d,th=%d\n", tx, ty, tw, th);
    evas_object_show(tt->tooltip);
 
