@@ -55,8 +55,7 @@ _elm_ews_border_geo_apply(Ecore_Evas *ee, Evas_Object *o)
 {
    int x, y, w, h;
    ecore_evas_geometry_get(ee, &x, &y, &w, &h);
-   evas_object_move(o, x, y);
-   evas_object_resize(o, w, h);
+   evas_object_geometry_set(o, x, y, w, h);
 }
 
 static void
@@ -283,7 +282,7 @@ _elm_ews_border_sig_move_start(void *data, Evas_Object *o EINA_UNUSED, const cha
    _ews_border_mover_off.x = x - ox;
    _ews_border_mover_off.y = y - oy;
    _ews_border_mover_obj = bs_o;
-   _ews_border_mover = ecore_animator_add(_elm_ews_border_mover, ee);
+   _ews_border_mover = ecore_evas_animator_add(bs_o, _elm_ews_border_mover, ee);
 }
 
 static void
@@ -477,7 +476,7 @@ _elm_ews_wm_init(void)
    o = edje_object_add(e);
    if (!o) return EINA_FALSE;
 
-   if (!_elm_theme_set(NULL, o, "ews", "background", "default", EINA_TRUE))
+   if (_elm_theme_set(NULL, o, "ews", "background", "default", EINA_TRUE) == EFL_UI_THEME_APPLY_ERROR_GENERIC)
      {
         ERR("Could not set background theme, fallback to rectangle");
         evas_object_del(o);
