@@ -1,6 +1,6 @@
 #include "elput_private.h"
 
-#ifdef HAVE_SYSTEMD
+#if defined(HAVE_SYSTEMD) || defined(HAVE_ELOGIND)
 
 static void
 _logind_session_active_cb_free(void *data EINA_UNUSED, void *event)
@@ -41,7 +41,6 @@ _logind_device_pause_complete(Elput_Manager *em, uint32_t major, uint32_t minor)
    if (!msg)
      {
         ERR("Could not create method call for proxy");
-        eldbus_message_unref(msg);
         return;
      }
 
