@@ -1,6 +1,6 @@
-#include "elua_private.h"
-
+#include <limits.h>
 #include <Ecore_File.h>
+#include "elua_private.h"
 
 static Eina_Prefix *_elua_pfx = NULL;
 
@@ -77,8 +77,21 @@ elua_state_new(const char *progname)
    ret->luastate = L;
    if (progname) ret->progname = eina_stringshare_add(progname);
    luaL_openlibs(L);
-   lua_pushlightuserdata(L, ret);
-   lua_setfield(L, LUA_REGISTRYINDEX, "elua_ptr");
+   /* on 64-bit, split the state pointer into two and reconstruct later */
+   size_t retn = (size_t)ret;
+   if (sizeof(void *) < sizeof(lua_Number))
+     {
+        lua_pushnumber(L, 0);
+        lua_pushnumber(L, (lua_Number)retn);
+     }
+   else
+     {
+        size_t hbits = (sizeof(void *) / 2) * CHAR_BIT;
+        lua_pushnumber(L, (lua_Number)(retn >> hbits));
+        lua_pushnumber(L, (lua_Number)(retn & (((size_t)1 << hbits) - 1)));
+     }
+   lua_setfield(L, LUA_REGISTRYINDEX, "elua_ptr1");
+   lua_setfield(L, LUA_REGISTRYINDEX, "elua_ptr2");
    return ret;
 }
 
@@ -257,14 +270,18 @@ EAPI Elua_State *
 elua_state_from_lua_state_get(lua_State *L)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(L, NULL);
-   lua_getfield(L, LUA_REGISTRYINDEX, "elua_ptr");
-   if (!lua_isnil(L, -1))
+   lua_getfield(L, LUA_REGISTRYINDEX, "elua_ptr1");
+   lua_getfield(L, LUA_REGISTRYINDEX, "elua_ptr2");
+   if (!lua_isnil(L, -1) && !lua_isnil(L, -2))
      {
-        void *st = lua_touserdata(L, -1);
-        lua_pop(L, 1);
-        return (Elua_State *)st;
+        size_t p1 = (size_t)lua_tonumber(L, -2),
+               p2 = (size_t)lua_tonumber(L, -1);
+        if (p2 && (sizeof(void *) >= sizeof(lua_Number)))
+          p1 |= p2 << ((sizeof(void *) / 2) * CHAR_BIT);
+        lua_pop(L, 2);
+        return (Elua_State *)p1;
      }
-   lua_pop(L, 1);
+   lua_pop(L, 2);
    return NULL;
 }
 
@@ -355,22 +372,50 @@ _elua_get_localeconv(lua_State *L)
    return 1;
 };
 
+#ifdef ENABLE_NLS
+static int
+_elua_dgettext(lua_State *L)
+{
+   const char *domain = luaL_checkstring(L, 1);
+   const char *msgid  = luaL_checkstring(L, 2);
+   char *ret = dgettext(domain, msgid);
+   if (!ret)
+     lua_pushnil(L);
+   else
+     lua_pushstring(L, ret);
+   return 1;
+}
+
+static int
+_elua_dngettext(lua_State *L)
+{
+   const char *domain  = luaL_checkstring(L, 1);
+   const char *msgid   = luaL_checkstring(L, 2);
+   const char *plmsgid = luaL_checkstring(L, 3);
+   char *ret = dngettext(domain, msgid, plmsgid, luaL_checklong(L, 4));
+   if (!ret)
+     lua_pushnil(L);
+   else
+     lua_pushstring(L, ret);
+   return 1;
+}
+#endif
+
 const luaL_Reg gettextlib[] =
 {
    { "bind_textdomain", _elua_gettext_bind_textdomain },
    { "get_message_language", _elua_get_message_language },
    { "get_localeconv", _elua_get_localeconv },
+#ifdef ENABLE_NLS
+   { "dgettext", _elua_dgettext },
+   { "dngettext", _elua_dngettext },
+#endif
    { NULL, NULL }
 };
 
 static Eina_Bool
-_elua_state_i18n_setup(const Elua_State *es)
+_elua_state_i18n_setup(Elua_State *es)
 {
-#ifdef ENABLE_NLS
-   char *(*dgettextp)(const char*, const char*) = dgettext;
-   char *(*dngettextp)(const char*, const char*, const char*, unsigned long)
-      = dngettext;
-#endif
    char buf[PATH_MAX];
    EINA_SAFETY_ON_NULL_RETURN_VAL(es, EINA_FALSE);
    EINA_SAFETY_ON_NULL_RETURN_VAL(es->coredir, EINA_FALSE);
@@ -380,12 +425,6 @@ _elua_state_i18n_setup(const Elua_State *es)
      return EINA_FALSE;
    lua_createtable(es->luastate, 0, 0);
    luaL_register(es->luastate, NULL, gettextlib);
-#ifdef ENABLE_NLS
-   lua_pushlightuserdata(es->luastate, *((void**)&dgettextp));
-   lua_setfield(es->luastate, -2, "dgettext");
-   lua_pushlightuserdata(es->luastate, *((void**)&dngettextp));
-   lua_setfield(es->luastate, -2, "dngettext");
-#endif
    lua_call(es->luastate, 1, 0);
    return EINA_TRUE;
 }
