@@ -2,33 +2,17 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif
-
-#ifdef _WIN32
-#include <winsock2.h>
-#endif
-
 #ifdef ENABLE_LIBLZ4
 #include <lz4.h>
 #else
 #include "lz4.h"
 #endif
 
-#ifdef _WIN32
-#define XMD_H /* This prevents libjpeg to redefine INT32 */
-#endif
-
 #include <stdio.h>
 #include <setjmp.h>
 #include <jpeglib.h>
 #include <jerror.h>
 
-#ifdef _WIN32
-#include <Evil.h>
-#endif
-
 #include "rg_etc1.h"
 #include "Emile.h"
 #include "emile_private.h"
@@ -342,8 +326,8 @@ _emile_tgv_head(Emile_Image *image,
    image->compress = m[OFFSET_OPTIONS] & 0x1;
    image->blockless = (m[OFFSET_OPTIONS] & 0x2) != 0;
 
-   image->size.width = ntohl(*((unsigned int *)&(m[OFFSET_WIDTH])));
-   image->size.height = ntohl(*((unsigned int *)&(m[OFFSET_HEIGHT])));
+   image->size.width = eina_ntohl(*((unsigned int *)&(m[OFFSET_WIDTH])));
+   image->size.height = eina_ntohl(*((unsigned int *)&(m[OFFSET_HEIGHT])));
 
    if (image->blockless)
      {
