@@ -39,6 +39,7 @@ typedef struct
    Eo                        *composite_parent;
    Eina_Inlist               *generic_data;
    Eo                      ***wrefs;
+   Eina_Hash                 *providers;
 } Efl_Object_Extension;
 
 struct _Efl_Object_Data
@@ -60,6 +61,7 @@ struct _Efl_Object_Data
    unsigned short             event_cb_efl_event_callback_del_count;
    unsigned short             event_cb_efl_event_del_count;
    unsigned short             event_cb_efl_event_noref_count;
+   unsigned short             event_cb_efl_event_invalidate_count;
    Eina_Bool                  callback_stopped : 1;
    Eina_Bool                  need_cleaning : 1;
    Eina_Bool                  allow_parent_unref : 1; // Allows unref to zero even with a parent
@@ -125,11 +127,46 @@ _efl_pending_futures_clear(Efl_Object_Data *pd)
      }
 }
 
+static inline void
+_efl_object_extension_free(Efl_Object_Extension *ext)
+{
+   eina_freeq_ptr_main_add(ext, free, sizeof(*ext));
+}
+
+static inline Efl_Object_Extension *
+_efl_object_extension_need(Efl_Object_Data *pd)
+{
+   if (!pd->ext) pd->ext = calloc(1, sizeof(Efl_Object_Extension));
+   return pd->ext;
+}
+
+static inline void
+_efl_object_extension_noneed(Efl_Object_Data *pd)
+{
+   Efl_Object_Extension *ext = pd->ext;
+   if ((!ext) ||
+       (ext->name) ||
+       (ext->comment) ||
+       (ext->generic_data) ||
+       (ext->wrefs) ||
+       (ext->composite_parent) ||
+       (ext->providers)) return;
+   _efl_object_extension_free(pd->ext);
+   pd->ext = NULL;
+}
+
 static void
 _efl_object_invalidate(Eo *obj_id, Efl_Object_Data *pd)
 {
    _efl_pending_futures_clear(pd);
 
+   if (pd->ext && pd->ext->providers)
+     {
+        eina_hash_free(pd->ext->providers);
+        pd->ext->providers = NULL;
+        _efl_object_extension_noneed(pd);
+     }
+
    EO_OBJ_POINTER_RETURN(obj_id, obj);
 
    // Finally invalidate itself if it wasn't done already
@@ -185,33 +222,6 @@ _efl_invalidate(_Eo_Object *obj)
    obj->invalidate = EINA_TRUE;
 }
 
-static inline void
-_efl_object_extension_free(Efl_Object_Extension *ext)
-{
-   eina_freeq_ptr_main_add(ext, free, sizeof(*ext));
-}
-
-static inline Efl_Object_Extension *
-_efl_object_extension_need(Efl_Object_Data *pd)
-{
-   if (!pd->ext) pd->ext = calloc(1, sizeof(Efl_Object_Extension));
-   return pd->ext;
-}
-
-static inline void
-_efl_object_extension_noneed(Efl_Object_Data *pd)
-{
-   Efl_Object_Extension *ext = pd->ext;
-   if ((!ext) ||
-       (ext->name) ||
-       (ext->comment) ||
-       (ext->generic_data) ||
-       (ext->wrefs) ||
-       (ext->composite_parent)) return;
-   _efl_object_extension_free(pd->ext);
-   pd->ext = NULL;
-}
-
 static void _key_generic_cb_del(void *data, const Efl_Event *event);
 
 static void
@@ -832,6 +842,7 @@ EOLIAN static Efl_Object *
 _efl_object_provider_find(const Eo *obj, Efl_Object_Data *pd, const Efl_Object *klass)
 {
    Eina_Bool invalidate;
+   Efl_Object *r = NULL;
 
    invalidate = _efl_object_invalidated_get((Eo*) obj, NULL);
    if (invalidate)
@@ -839,10 +850,50 @@ _efl_object_provider_find(const Eo *obj, Efl_Object_Data *pd, const Efl_Object *
         ERR("Calling efl_provider_find(%p) after the object was invalidated.", obj);
         return NULL;
      }
+
+   if (efl_isa(obj, klass)) return (Eo *) obj;
+
+   if (pd->ext) r = eina_hash_find(pd->ext->providers, &klass);
+   if (r) return r;
+
    if (pd->parent) return efl_provider_find(pd->parent, klass);
    return NULL;
 }
 
+static Eina_Bool
+_efl_object_provider_register(Eo *obj EINA_UNUSED, Efl_Object_Data *pd, const Efl_Class *klass, const Efl_Object *provider)
+{
+   // The passed object does not provide that said class.
+   if (!efl_isa(provider, klass)) return EINA_FALSE;
+
+   _efl_object_extension_need(pd);
+   if (!pd->ext) return EINA_FALSE;
+   if (!pd->ext->providers) pd->ext->providers = eina_hash_pointer_new(EINA_FREE_CB(efl_unref));
+
+   // Prevent double insertion for the same class
+   if (eina_hash_find(pd->ext->providers, &klass)) return EINA_FALSE;
+
+   // Note: I would prefer to use efl_xref here, but I can't figure a nice way to
+   // call efl_xunref on hash destruction.
+   return eina_hash_add(pd->ext->providers, &klass, efl_ref(provider));
+}
+
+static Eina_Bool
+_efl_object_provider_unregister(Eo *obj EINA_UNUSED, Efl_Object_Data *pd, const Efl_Class *klass, const Efl_Object *provider)
+{
+   Eina_Bool r;
+
+   if (!pd->ext) return EINA_FALSE;
+   r = eina_hash_del(pd->ext->providers, &klass, provider);
+
+   if (eina_hash_population(pd->ext->providers) != 0) return r;
+   eina_hash_free(pd->ext->providers);
+   pd->ext->providers = NULL;
+   _efl_object_extension_noneed(pd);
+
+   return r;
+}
+
 /* Children accessor */
 typedef struct _Eo_Children_Iterator Eo_Children_Iterator;
 struct _Eo_Children_Iterator
@@ -1082,6 +1133,7 @@ efl_object_legacy_only_event_description_get(const char *_event_name)
         event_desc = calloc(1, sizeof(Efl_Event_Description));
         event_desc->name = event_name;
         event_desc->legacy_is = EINA_TRUE;
+        event_desc->unfreezable = EINA_TRUE;
         eina_hash_add(_legacy_events_hash, event_name, event_desc);
      }
    else
@@ -1107,7 +1159,6 @@ _legacy_events_hash_free_cb(void *_desc)
 }
 
 /* EOF Legacy */
-
 struct _Eo_Callback_Description
 {
    union
@@ -1177,8 +1228,16 @@ _special_event_count_inc(Eo *obj_id, Efl_Object_Data *pd, const Efl_Callback_Arr
 
         CB_COUNT_INC(pd->event_cb_efl_event_noref_count);
      }
+   else if (it->desc == EFL_EVENT_INVALIDATE)
+     CB_COUNT_INC(pd->event_cb_efl_event_invalidate_count);
    else if (it->desc == EFL_EVENT_DESTRUCT)
      pd->has_destroyed_event_cb = EINA_TRUE;
+   else if (it->desc == EFL_EVENT_OWNERSHIP_SHARED || it->desc == EFL_EVENT_OWNERSHIP_UNIQUE)
+     {
+        EO_OBJ_POINTER_RETURN(obj_id, obj);
+        obj->ownership_track = EINA_TRUE;
+        EO_OBJ_DONE(obj_id);
+     }
 }
 
 static inline void
@@ -1190,6 +1249,8 @@ _special_event_count_dec(Eo *obj_id, Efl_Object_Data *pd, const Efl_Callback_Arr
      CB_COUNT_DEC(pd->event_cb_efl_event_callback_del_count);
    else if (it->desc == EFL_EVENT_DEL)
      CB_COUNT_DEC(pd->event_cb_efl_event_del_count);
+   else if (it->desc == EFL_EVENT_INVALIDATE)
+     CB_COUNT_DEC(pd->event_cb_efl_event_invalidate_count);
    else if (it->desc == EFL_EVENT_NOREF)
      {
         CB_COUNT_DEC(pd->event_cb_efl_event_noref_count);
@@ -1628,6 +1689,8 @@ _event_callback_call(Eo *obj_id, Efl_Object_Data *pd,
             (pd->event_cb_efl_event_callback_del_count == 0)) return EINA_FALSE;
    else if ((desc == EFL_EVENT_DEL) &&
             (pd->event_cb_efl_event_del_count == 0)) return EINA_FALSE;
+   else if ((desc == EFL_EVENT_INVALIDATE) &&
+            (pd->event_cb_efl_event_invalidate_count == 0)) return EINA_FALSE;
    else if ((desc == EFL_EVENT_NOREF) &&
             (pd->event_cb_efl_event_noref_count == 0)) return EINA_FALSE;
 
