@@ -75,13 +75,13 @@ void _eo_pointer_error(const Eo *obj_id, const char *func_name, const char *file
 #define EO_CLASS_POINTER_PROXY(klass_id, klass)   \
    _Efl_Class *klass; \
    do { \
-      klass = _eo_class_pointer_get(klass_id, func_name, file, line); \
+      klass = _eo_class_pointer_get(klass_id); \
    } while (0)
 
 #define EO_CLASS_POINTER_RETURN_VAL(klass_id, klass, ret) \
    _Efl_Class *klass; \
    do { \
-      klass = _eo_class_pointer_get(klass_id, __FUNCTION__, __FILE__, __LINE__); \
+      klass = _eo_class_pointer_get(klass_id); \
       if (!klass) { \
          _EO_POINTER_ERR(klass_id, "Class (%p) is an invalid ref.", klass_id); \
          return ret; \
@@ -91,7 +91,7 @@ void _eo_pointer_error(const Eo *obj_id, const char *func_name, const char *file
 #define EO_CLASS_POINTER_RETURN_VAL_PROXY(klass_id, klass, ret) \
    _Efl_Class *klass; \
    do { \
-      klass = _eo_class_pointer_get(klass_id, func_name, file, line); \
+      klass = _eo_class_pointer_get(klass_id); \
       if (!klass) { \
          _EO_POINTER_ERR(klass_id, "Class (%p) is an invalid ref.", klass_id); \
          return ret; \
@@ -101,7 +101,7 @@ void _eo_pointer_error(const Eo *obj_id, const char *func_name, const char *file
 #define EO_CLASS_POINTER_RETURN(klass_id, klass)   \
    _Efl_Class *klass; \
    do { \
-      klass = _eo_class_pointer_get(klass_id, __FUNCTION__, __FILE__, __LINE__); \
+      klass = _eo_class_pointer_get(klass_id); \
       if (!klass) { \
          _EO_POINTER_ERR(klass_id, "Class (%p) is an invalid ref.", klass_id); \
          return; \
@@ -111,7 +111,7 @@ void _eo_pointer_error(const Eo *obj_id, const char *func_name, const char *file
 #define EO_CLASS_POINTER_RETURN_PROXY(klass_id, klass) \
    _Efl_Class *klass; \
    do { \
-      klass = _eo_class_pointer_get(klass_id, func_name, file, line); \
+      klass = _eo_class_pointer_get(klass_id); \
       if (!klass) { \
          _EO_POINTER_ERR(klass_id, "Class (%p) is an invalid ref.", klass_id); \
          return; \
