@@ -41,7 +41,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <ctype.h>
-#include <pwd.h>
+#ifndef _WIN32
+# include <pwd.h>
+#endif
 
 #ifdef HAVE_XATTR
 # include <sys/xattr.h>
@@ -51,10 +53,6 @@
 # define PATH_MAX 4096
 #endif
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #include <Eina.h>
 #include <eina_safety_checks.h>
 #include <Evas.h>
@@ -626,7 +624,10 @@ ethumb_frame_set(Ethumb *e, const char *theme_file, const char *group, const cha
      {
         edje_object_part_unswallow(frame->edje, e->img);
         if (!theme_file)
-          _ethumb_frame_free(frame);
+          {
+             _ethumb_frame_free(frame);
+             frame = NULL;
+          }
      }
 
    if (!theme_file)
@@ -931,7 +932,7 @@ _ethumb_generate_hash(const char *file)
    EINA_SAFETY_ON_NULL_RETURN_VAL(file, NULL);
 
    uri = alloca(3 * strlen(file) + 9);
-   memcpy(uri, "file://", sizeof("file://") - 1);
+   memcpy(uri, "file://", sizeof("file://"));
    t = uri + sizeof("file://") - 1;
 
    for (c = (const unsigned char *)file; *c != '\0'; c++)
@@ -1048,7 +1049,7 @@ _ethumb_file_generate_path(Ethumb *e)
           {
              ERR("fdo_format but size %d is not NORMAL (%d) or LARGE (%d)?",
                  e->tw, THUMB_SIZE_NORMAL, THUMB_SIZE_LARGE);
-             category = "unknown";
+             category = eina_stringshare_add("unknown");
           }
      }
 
