@@ -12,6 +12,12 @@ _efl_canvas_animation_player_target_set(Eo *eo_obj EINA_UNUSED,
                                  Efl_Canvas_Animation_Player_Data *pd,
                                  Efl_Canvas_Object *target)
 {
+   if (pd->target == target)
+     return;
+
+   if (pd->target)
+     efl_event_callback_del(pd->target, EFL_EVENT_DEL, _target_del_cb, pd);
+
    efl_event_callback_add(target, EFL_EVENT_DEL, _target_del_cb, pd);
 
    pd->target = target;
@@ -55,7 +61,7 @@ _efl_canvas_animation_player_animation_set(Eo *eo_obj,
 
    if (pd->animation)
      {
-        efl_player_stop(eo_obj);
+        efl_player_playing_set(eo_obj, EINA_FALSE);
         efl_unref(pd->animation);
      }
    pd->animation = anim;
@@ -77,7 +83,7 @@ _animator_cb(void *data)
    EFL_ANIMATION_PLAYER_ANIMATION_GET(eo_obj, anim);
    double duration, elapsed_time, vector;
 
-   if (efl_player_seekable_get(eo_obj))
+   if (efl_playable_seekable_get(eo_obj))
      {
         pd->time.current = ecore_loop_time_get();
 
@@ -107,6 +113,10 @@ _animator_cb(void *data)
         pd->progress = (double)(pd->is_direction_forward);
      }
 
+   /* The previously applied map effect should be reset before applying the
+    * current map effect. Otherwise, the incrementally added map effects
+    * increase numerical error. */
+   efl_gfx_mapping_reset(efl_animation_player_target_get(eo_obj));
    efl_animation_apply(anim, pd->progress, efl_animation_player_target_get(eo_obj));
 
    Efl_Canvas_Animation_Player_Event_Running event_running;
@@ -137,8 +147,9 @@ _animator_cb(void *data)
 
         return ECORE_CALLBACK_RENEW;
      }
-   efl_player_stop(eo_obj);
+   efl_player_playing_set(eo_obj, EINA_FALSE);
 
+   pd->animator = NULL;
    return ECORE_CALLBACK_CANCEL;
 }
 
@@ -178,17 +189,81 @@ _start_delay_timer_cb(void *data)
    return ECORE_CALLBACK_CANCEL;
 }
 
-EOLIAN static void
-_efl_canvas_animation_player_efl_player_start(Eo *eo_obj,
-                                       Efl_Canvas_Animation_Player_Data *pd)
+static Eina_Bool
+_is_final_state(Efl_Canvas_Animation *anim, double progress)
+{
+   if (!anim) return EINA_FALSE;
+   if ((progress != 0.0) && (progress != 1.0)) return EINA_FALSE;
+
+   if (efl_animation_repeat_mode_get(anim) == EFL_CANVAS_ANIMATION_REPEAT_MODE_REVERSE)
+     {
+        if (efl_animation_repeat_count_get(anim) & 1)
+          {
+             if (progress == 0.0)
+               return EINA_TRUE;
+          }
+        else
+          {
+             if (progress == 1.0)
+               return EINA_TRUE;
+          }
+     }
+   else
+     {
+        if (progress == 1.0)
+          return EINA_TRUE;
+     }
+
+   return EINA_FALSE;
+}
+
+static void
+_player_stop(Eo *eo_obj, Efl_Canvas_Animation_Player_Data *pd, Efl_Canvas_Animation *anim)
+{
+   //Reset the state of the target to the initial state
+   efl_gfx_mapping_reset(efl_animation_player_target_get(eo_obj));
+
+   if (efl_animation_final_state_keep_get(anim))
+     {
+        if (_is_final_state(anim, pd->progress))
+          {
+             /* Keep the final state only if efl_player_playing_set(EINA_FALSE) is called at
+              * the end of _animator_cb. */
+             efl_animation_apply(anim, pd->progress,
+                                 efl_animation_player_target_get(eo_obj));
+          }
+        else
+          {
+             pd->progress = 0.0;
+          }
+     }
+   else
+     {
+        pd->progress = 0.0;
+     }
+   efl_event_callback_call(eo_obj, EFL_ANIMATION_PLAYER_EVENT_ENDED, NULL);
+   if (pd->auto_del) efl_del(eo_obj);
+}
+
+EOLIAN static Eina_Bool
+_efl_canvas_animation_player_efl_player_playing_set(Eo *eo_obj, Efl_Canvas_Animation_Player_Data *pd, Eina_Bool playing)
 {
    double start_delay;
    EFL_ANIMATION_PLAYER_ANIMATION_GET(eo_obj, anim);
 
-   if (!efl_player_playable_get(eo_obj)) return;
-   pd->is_play = EINA_TRUE;
+   if (!efl_playable_get(eo_obj)) return EINA_FALSE;
+   if ((!playing) && (!pd->is_play)) return EINA_TRUE;
+   if ((playing) && (pd->is_play)) return EINA_TRUE;
+   pd->is_play = !!playing;
+   if (!playing)
+     {
+        if (!pd->is_play) return EINA_TRUE;
+        pd->is_paused = EINA_FALSE;
+        _player_stop(eo_obj, pd, anim);
+        return EINA_TRUE;
+     }
    //TODO: check this case is correct
-   if (pd->start_delay_timer) return;
+   if (pd->start_delay_timer) return EINA_TRUE;
 
    pd->progress = 0.0;
    start_delay = efl_animation_start_delay_get(anim);
@@ -196,59 +271,32 @@ _efl_canvas_animation_player_efl_player_start(Eo *eo_obj,
      {
         pd->start_delay_timer = ecore_timer_add(start_delay,
                                                 _start_delay_timer_cb, eo_obj);
-        return;
-     }
-
-   _start(eo_obj, pd);
-}
-
-EOLIAN static void
-_efl_canvas_animation_player_efl_player_stop(Eo *eo_obj,
-                                      Efl_Canvas_Animation_Player_Data *pd)
-{
-   EFL_ANIMATION_PLAYER_ANIMATION_GET(eo_obj, anim);
-   Eina_Bool play = efl_player_play_get(eo_obj);
-   if (play)
-     {
-        efl_player_play_set(eo_obj, EINA_FALSE);
-        //Reset the state of the target to the initial state
-        if ((efl_animation_final_state_keep_get(anim)) &&
-            (efl_animation_repeat_mode_get(anim) != EFL_CANVAS_ANIMATION_REPEAT_MODE_REVERSE) &&
-            (!(efl_animation_repeat_count_get(anim) & 1)))
-          {
-               pd->progress = 1.0;
-               efl_animation_apply(anim, pd->progress,
-                                   efl_animation_player_target_get(eo_obj));
-          }
-        else
-          {
-             pd->progress = 0.0;
-             efl_gfx_mapping_reset(efl_animation_player_target_get(eo_obj));
-          }
-        efl_event_callback_call(eo_obj, EFL_ANIMATION_PLAYER_EVENT_ENDED, NULL);
      }
    else
-     {
-         pd->progress = 0.0;
-         efl_gfx_mapping_reset(efl_animation_player_target_get(eo_obj));
-     }
-
-   if (pd->auto_del) efl_del(eo_obj);
+     _start(eo_obj, pd);
+   return EINA_TRUE;
 }
 
-EOLIAN static void
-_efl_canvas_animation_player_efl_player_play_set(Eo *eo_obj,
-                                          Efl_Canvas_Animation_Player_Data *pd,
-                                          Eina_Bool play)
+EOLIAN static Eina_Bool
+_efl_canvas_animation_player_efl_player_playing_get(const Eo *eo_obj EINA_UNUSED, Efl_Canvas_Animation_Player_Data *pd)
 {
-   if (efl_player_play_get(eo_obj) == !!play)
-     return;
+   return pd->is_play;
+}
 
-   pd->is_play = play;
-   if (play)
+EOLIAN static Eina_Bool
+_efl_canvas_animation_player_efl_player_paused_set(Eo *eo_obj,
+                                          Efl_Canvas_Animation_Player_Data *pd,
+                                          Eina_Bool paused)
+{
+   paused = !!paused;
+   /* can't pause if not playing */
+   if (!pd->is_play) return EINA_FALSE;
+   if (pd->is_paused == paused) return EINA_TRUE;
+   pd->is_paused = paused;
+   if (!paused)
      {
         //TODO: check this case is correct.
-        if (pd->start_delay_timer) return;
+        if (pd->start_delay_timer) return EINA_FALSE;
 
         pd->time.prev = ecore_loop_time_get();
         pd->animator = ecore_evas_animator_add(pd->target, _animator_cb, eo_obj);
@@ -262,17 +310,18 @@ _efl_canvas_animation_player_efl_player_play_set(Eo *eo_obj,
         ecore_animator_del(pd->animator);
         pd->animator = NULL;
      }
+   return EINA_TRUE;
 }
 
 EOLIAN static Eina_Bool
-_efl_canvas_animation_player_efl_player_play_get(const Eo *eo_obj EINA_UNUSED,
+_efl_canvas_animation_player_efl_player_paused_get(const Eo *eo_obj EINA_UNUSED,
                                           Efl_Canvas_Animation_Player_Data *pd)
 {
-   return pd->is_play;
+   return pd->is_paused;
 }
 
 EOLIAN static Eina_Bool
-_efl_canvas_animation_player_efl_player_playable_get(const Eo *eo_obj,
+_efl_canvas_animation_player_efl_playable_playable_get(const Eo *eo_obj,
                                               Efl_Canvas_Animation_Player_Data *pd EINA_UNUSED)
 {
    Efl_Canvas_Animation *anim = efl_animation_player_animation_get(eo_obj);
@@ -281,40 +330,45 @@ _efl_canvas_animation_player_efl_player_playable_get(const Eo *eo_obj,
 }
 
 EOLIAN static double
-_efl_canvas_animation_player_efl_player_pos_get(const Eo *eo_obj,
+_efl_canvas_animation_player_efl_player_playback_position_get(const Eo *eo_obj,
                                               Efl_Canvas_Animation_Player_Data *pd EINA_UNUSED)
 {
    //TODO: this is not correct
    Efl_Canvas_Animation *anim = efl_animation_player_animation_get(eo_obj);
    double length = efl_animation_duration_get(anim);
 
-   return length * efl_player_progress_get(eo_obj);
+   return length * efl_player_playback_progress_get(eo_obj);
 }
 
 EOLIAN static void
-_efl_canvas_animation_player_efl_player_pos_set(Eo *eo_obj,
+_efl_canvas_animation_player_efl_player_playback_position_set(Eo *eo_obj,
                                               Efl_Canvas_Animation_Player_Data *pd EINA_UNUSED,
                                               double sec)
 {
    //TODO: this is not correct
-   if (!efl_player_seekable_get(eo_obj))
+   if (!efl_playable_seekable_get(eo_obj))
      return;
 
    EFL_ANIMATION_PLAYER_ANIMATION_GET(eo_obj, anim);
    double length = efl_animation_duration_get(anim);
    pd->progress = sec / length;
+
+   /* The previously applied map effect should be reset before applying the
+    * current map effect. Otherwise, the incrementally added map effects
+    * increase numerical error. */
+   efl_gfx_mapping_reset(efl_animation_player_target_get(eo_obj));
    efl_animation_apply(anim, pd->progress, efl_animation_player_target_get(eo_obj));
 }
 
 EOLIAN static double
-_efl_canvas_animation_player_efl_player_progress_get(const Eo *eo_obj EINA_UNUSED,
+_efl_canvas_animation_player_efl_player_playback_progress_get(const Eo *eo_obj EINA_UNUSED,
                                               Efl_Canvas_Animation_Player_Data *pd)
 {
    return pd->progress;
 }
 
 EOLIAN static void
-_efl_canvas_animation_player_efl_player_play_speed_set(Eo *eo_obj EINA_UNUSED,
+_efl_canvas_animation_player_efl_player_playback_speed_set(Eo *eo_obj EINA_UNUSED,
                                                 Efl_Canvas_Animation_Player_Data *pd,
                                                 double play_speed)
 {
@@ -325,14 +379,14 @@ _efl_canvas_animation_player_efl_player_play_speed_set(Eo *eo_obj EINA_UNUSED,
 }
 
 EOLIAN static double
-_efl_canvas_animation_player_efl_player_play_speed_get(const Eo *eo_obj EINA_UNUSED,
+_efl_canvas_animation_player_efl_player_playback_speed_get(const Eo *eo_obj EINA_UNUSED,
                                                 Efl_Canvas_Animation_Player_Data *pd)
 {
    return pd->play_speed;
 }
 
 EOLIAN static double
-_efl_canvas_animation_player_efl_player_length_get(const Eo *eo_obj,
+_efl_canvas_animation_player_efl_playable_length_get(const Eo *eo_obj,
                                               Efl_Canvas_Animation_Player_Data *pd EINA_UNUSED)
 {
    EFL_ANIMATION_PLAYER_ANIMATION_GET(eo_obj, anim);
@@ -340,7 +394,7 @@ _efl_canvas_animation_player_efl_player_length_get(const Eo *eo_obj,
 }
 
 EOLIAN static Eina_Bool
-_efl_canvas_animation_player_efl_player_seekable_get(const Eo *eo_obj EINA_UNUSED,
+_efl_canvas_animation_player_efl_playable_seekable_get(const Eo *eo_obj EINA_UNUSED,
                                               Efl_Canvas_Animation_Player_Data *pd EINA_UNUSED)
 {
    EFL_ANIMATION_PLAYER_ANIMATION_GET(eo_obj, anim);
@@ -375,7 +429,7 @@ _efl_canvas_animation_player_efl_object_destructor(Eo *eo_obj,
         pd->animator = NULL;
 
         //Reset the state of the target to the initial state
-        efl_player_stop(eo_obj);
+        efl_player_playing_set(eo_obj, EINA_FALSE);
 
         efl_event_callback_call(eo_obj, EFL_ANIMATION_PLAYER_EVENT_ENDED, NULL);
      }
