@@ -117,7 +117,7 @@ _efl_canvas_vg_object_root_node_get(const Eo *obj, Efl_Canvas_Vg_Object_Data *pd
              evas_cache_vg_entry_del(pd->vg_entry);
              pd->vg_entry = vg_entry;
           }
-        root = evas_cache_vg_tree_get(pd->vg_entry);
+        root = evas_cache_vg_tree_get(pd->vg_entry, pd->frame_idx);
      }
    else if (pd->user_entry) root = pd->user_entry->root;
    else root = pd->root;
@@ -145,7 +145,7 @@ _efl_canvas_vg_object_root_node_set(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd, E
    if (pd->user_entry && pd->user_entry->root)
      {
         efl_canvas_vg_node_vg_obj_set(pd->user_entry->root, NULL, NULL);
-        efl_parent_set(pd->user_entry->root, NULL);
+        efl_replace(&pd->user_entry->root, NULL);
      }
 
    if (root_node)
@@ -160,10 +160,8 @@ _efl_canvas_vg_object_root_node_set(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd, E
                }
           }
         pd->user_entry->w = pd->user_entry->h = 0;
-        pd->user_entry->root = root_node;
 
-        // set the parent so that vg canvas can render it.
-        efl_parent_set(pd->user_entry->root, pd->root);
+        efl_replace(&pd->user_entry->root, root_node);
         efl_canvas_vg_node_vg_obj_set(root_node, eo_obj, pd);
      }
    else if (pd->user_entry)
@@ -289,7 +287,8 @@ _efl_canvas_vg_object_efl_file_load(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd)
    Evas_Object_Protected_Data *obj;
 
    obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
-   pd->vg_entry = evas_cache_vg_entry_create(file, key,
+   pd->vg_entry = evas_cache_vg_entry_create(evas_object_evas_get(eo_obj),
+                                             file, key,
                                              obj->cur->geometry.w,
                                              obj->cur->geometry.h);
    evas_object_change(eo_obj, obj);
@@ -332,8 +331,9 @@ _cleanup_reference(void *data, const Efl_Event *event EINA_UNUSED)
 }
 
 EOLIAN static void
-_efl_canvas_vg_object_efl_object_destructor(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd)
+_efl_canvas_vg_object_efl_object_invalidate(Eo *eo_obj, Efl_Canvas_Vg_Object_Data *pd)
 {
+   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    Evas *e = evas_object_evas_get(eo_obj);
 
    efl_event_callback_del(e, EFL_CANVAS_SCENE_EVENT_RENDER_POST, _cleanup_reference, pd);
@@ -342,11 +342,17 @@ _efl_canvas_vg_object_efl_object_destructor(Eo *eo_obj, Efl_Canvas_Vg_Object_Dat
    efl_unref(pd->root);
    pd->root = NULL;
 
-   if (pd->user_entry) free(pd->user_entry);
+   if (pd->user_entry)
+     {
+        Vg_User_Entry *user_entry = pd->user_entry;
+
+        ENFN->ector_surface_cache_drop(ENC, user_entry->root);
+        free(pd->user_entry);
+     }
    pd->user_entry = NULL;
    evas_cache_vg_entry_del(pd->vg_entry);
 
-   efl_destructor(efl_super(eo_obj, MY_CLASS));
+   efl_invalidate(efl_super(eo_obj, MY_CLASS));
 }
 
 EOLIAN static Eo *
@@ -363,7 +369,7 @@ _efl_canvas_vg_object_efl_object_constructor(Eo *eo_obj, Efl_Canvas_Vg_Object_Da
 
    /* default root node */
    pd->obj = obj;
-   pd->root = efl_add_ref(EFL_CANVAS_VG_CONTAINER_CLASS, NULL);
+   pd->root = efl_add_ref(EFL_CANVAS_VG_CONTAINER_CLASS, eo_obj);
 
    eina_array_step_set(&pd->cleanup, sizeof(pd->cleanup), 8);
 
@@ -374,7 +380,6 @@ static Efl_Object *
 _efl_canvas_vg_object_efl_object_finalize(Eo *obj, Efl_Canvas_Vg_Object_Data *pd)
 {
    Evas *e = evas_object_evas_get(obj);
-   efl_parent_set(pd->root, obj);
 
    // TODO: If we start to have to many Evas_Object_VG per canvas, it may be nice
    // to actually have one event per canvas and one array per canvas to.
@@ -386,22 +391,79 @@ _efl_canvas_vg_object_efl_object_finalize(Eo *obj, Efl_Canvas_Vg_Object_Data *pd
 static void
 _evas_vg_render(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
                 void *engine, void *output, void *context, Efl_VG *node,
-                Eina_Array *clips, Eina_Bool do_async)
+                Eina_Array *clips, int w, int h, Ector_Surface *ector, Eina_Bool do_async)
 {
    if (!efl_gfx_entity_visible_get(node)) return;
 
    if (efl_isa(node, EFL_CANVAS_VG_CONTAINER_CLASS))
      {
-        Efl_Canvas_Vg_Container_Data *cd =
-           efl_data_scope_get(node, EFL_CANVAS_VG_CONTAINER_CLASS);
-
-        if (cd->mask.target) return;   //Don't draw mask itself.
-
         Efl_VG *child;
         Eina_List *l;
+        Efl_Canvas_Vg_Container_Data *cd = efl_data_scope_get(node, EFL_CANVAS_VG_CONTAINER_CLASS);
 
-        EINA_LIST_FOREACH(cd->children, l, child)
-          _evas_vg_render(obj, pd, engine, output, context, child, clips, do_async);
+        if (cd->comp.src) return;   //Don't draw composite target itself.
+
+        int alpha = 255;
+        efl_gfx_color_get(node, NULL, NULL, NULL, &alpha);
+
+        if (alpha < 255)
+          {
+             //Replace with a new size.
+             if (cd->blend.buffer)
+               {
+                  int w2, h2;
+                  ector_buffer_size_get(cd->blend.buffer, &w2, &h2);
+                  if (w2 != w || h2 != h)
+                    efl_canvas_vg_container_blend_buffer_clear(node, cd);
+               }
+
+             if (!cd->blend.buffer)
+               {
+                  cd->blend.buffer = ENFN->ector_buffer_new(ENC, obj->layer->evas->evas,
+                                                            w, h,
+                                                            EFL_GFX_COLORSPACE_ARGB8888,
+                                                            ECTOR_BUFFER_FLAG_DRAWABLE |
+                                                            ECTOR_BUFFER_FLAG_CPU_READABLE |
+                                                            ECTOR_BUFFER_FLAG_CPU_WRITABLE);
+                  cd->blend.pixels = ector_buffer_map(cd->blend.buffer, &cd->blend.length,
+                                                      (ECTOR_BUFFER_FLAG_DRAWABLE |
+                                                       ECTOR_BUFFER_FLAG_CPU_READABLE |
+                                                       ECTOR_BUFFER_FLAG_CPU_WRITABLE),
+                                                      0, 0, w, h,
+                                                      EFL_GFX_COLORSPACE_ARGB8888,
+                                                      &cd->blend.stride);
+                  if (!cd->blend.pixels) ERR("Failed to map VG blend bufffer");
+               }
+             else
+               {
+                  if (cd->blend.pixels)
+                    memset(cd->blend.pixels, 0, cd->blend.length);
+               }
+
+             // Buffer change
+             ector_buffer_pixels_set(ector, cd->blend.pixels,
+                                     w, h, cd->blend.stride,
+                                     EFL_GFX_COLORSPACE_ARGB8888, EINA_TRUE);
+             ector_surface_reference_point_set(ector, 0,0);
+
+             // Draw child node to changed buffer
+             EINA_LIST_FOREACH(cd->children, l, child)
+                _evas_vg_render(obj, pd, engine, output, context, child, clips, w, h, ector, do_async);
+
+             // Re-set original surface
+             ENFN->ector_begin(engine, output, context, ector, 0, 0, EINA_FALSE, do_async);
+
+             // Draw buffer to original surface.(Ector_Surface)
+             ector_surface_draw_image(ector, cd->blend.buffer, 0, 0, alpha);
+
+          }
+        else
+          {
+             efl_canvas_vg_container_blend_buffer_clear(node, cd);
+
+             EINA_LIST_FOREACH(cd->children, l, child)
+                _evas_vg_render(obj, pd, engine, output, context, child, clips, w, h, ector, do_async);
+          }
      }
    else
      {
@@ -414,8 +476,8 @@ _evas_vg_render(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
 //renders a vg_tree to an offscreen buffer and push it to the cache.
 static void *
 _render_to_buffer(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd,
-                  void *engine, Efl_VG *root, int w, int h, void *key,
-                  void *buffer, Eina_Bool do_async)
+                  void *engine, Efl_VG *root, int w, int h, void *buffer,
+                  Eina_Bool do_async, Eina_Bool cacheable)
 {
    Ector_Surface *ector;
    RGBA_Draw_Context *context;
@@ -438,9 +500,9 @@ _render_to_buffer(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd
    evas_common_draw_context_set_render_op(context, _EVAS_RENDER_COPY);
    evas_common_draw_context_set_color(context, 255, 255, 255, 255);
 
-   //ector begin - end for drawing mask images.
+   //ector begin - end for drawing composite images.
    //ENFN->ector_begin(engine, buffer, context, ector, 0, 0, EINA_FALSE, EINA_FALSE);
-   _evas_vg_render_pre(obj, root, engine, buffer, context, ector, NULL, NULL, 0);
+   _evas_vg_render_pre(obj, root, engine, buffer, context, ector, NULL, 255, NULL, 0);
    //ENFN->ector_end(engine, buffer, context, ector, EINA_FALSE);
 
    //Actual content drawing
@@ -451,14 +513,19 @@ _render_to_buffer(Evas_Object_Protected_Data *obj, Efl_Canvas_Vg_Object_Data *pd
                    engine, buffer,
                    context, root,
                    NULL,
+                   w, h, ector,
                    do_async);
 
    ENFN->image_dirty_region(engine, buffer, 0, 0, w, h);
    ENFN->ector_end(engine, buffer, context, ector, do_async);
    evas_common_draw_context_free(context);
 
-   if (buffer_created)
-     ENFN->ector_surface_cache_set(engine, key, buffer);
+   if (buffer_created && cacheable)
+     {
+        //Use root as a cache key.
+        ENFN->ector_surface_cache_set(engine, root, buffer);
+        pd->cached_frame_idx = pd->frame_idx;
+     }
 
    return buffer;
 }
@@ -468,7 +535,7 @@ _render_buffer_to_screen(Evas_Object_Protected_Data *obj,
                          void *engine, void *output, void *context, void *surface,
                          void *buffer,
                          int x, int y, int w, int h,
-                         Eina_Bool do_async)
+                         Eina_Bool do_async, Eina_Bool cacheable)
 {
    Eina_Bool async_unref;
 
@@ -484,50 +551,107 @@ _render_buffer_to_screen(Evas_Object_Protected_Data *obj,
         evas_cache_image_ref((Image_Entry *)buffer);
         evas_unref_queue_image_put(obj->layer->evas, buffer);
      }
+
+   //TODO: Reuse buffer if size is same?
+   if (!cacheable) ENFN->ector_surface_destroy(engine, buffer);
 }
 
 static void
 _cache_vg_entry_render(Evas_Object_Protected_Data *obj,
                        Efl_Canvas_Vg_Object_Data *pd,
                        void *engine, void *output, void *context, void *surface,
-                       int x, int y, int w, int h, Eina_Bool do_async)
+                       int x, int y, int w, int h, Eina_Bool do_async,
+                       Eina_Bool cacheable)
 {
    Vg_Cache_Entry *vg_entry = pd->vg_entry;
    Efl_VG *root;
+   Eina_Position2D offset = {0, 0};  //Offset after keeping aspect ratio.
+   Eina_Bool drop_cache = EINA_FALSE;
+   void *buffer = NULL;
 
    // if the size changed in between path set and the draw call;
-
    if ((vg_entry->w != w) ||
        (vg_entry->h != h))
      {
-         vg_entry = evas_cache_vg_entry_resize(vg_entry, w, h);
-         evas_cache_vg_entry_del(pd->vg_entry);
-         pd->vg_entry = vg_entry;
+        Eina_Size2D size = evas_cache_vg_entry_default_size_get(pd->vg_entry);
+
+        //adjust size for aspect ratio.
+        if (size.w > 0 && size.h > 0)
+          {
+             float rw = (float) w / (float) size.w;
+             float rh = (float) h / (float) size.h;
+
+             if (rw < rh)
+               {
+                  size.w = w;
+                  size.h = (int) ((float) size.h * rw);
+               }
+             else
+               {
+                  size.w = (int) ((float) size.w * rh);
+                  size.h = h;
+               }
+          }
+        else
+          {
+              size.w = w;
+              size.h = h;
+          }
+
+        //Size is changed, cached data is invalid.
+        if ((size.w != vg_entry->w) || (size.h != vg_entry->h))
+          {
+             drop_cache = EINA_TRUE;
+             vg_entry = evas_cache_vg_entry_resize(vg_entry, size.w, size.h);
+             evas_cache_vg_entry_del(pd->vg_entry);
+             pd->vg_entry = vg_entry;
+          }
+
+        //update for adjusted pos and size.
+        offset.x = w - size.w;
+        if (offset.x > 0) offset.x /= 2;
+        offset.y = h - size.h;
+        if (offset.y > 0) offset.y /= 2;
+        w = size.w;
+        h = size.h;
+
      }
-   root = evas_cache_vg_tree_get(vg_entry);
+   root = evas_cache_vg_tree_get(vg_entry, pd->frame_idx);
    if (!root) return;
 
-   void *buffer = ENFN->ector_surface_cache_get(engine, root);
+   if (cacheable)
+     {
+        //if the size doesn't match, drop previous cache surface.
+        if (drop_cache)
+          ENFN->ector_surface_cache_drop(engine, (void *) root);
+        //Cache Hit!
+        else if (pd->frame_idx == pd->cached_frame_idx)
+          buffer = ENFN->ector_surface_cache_get(engine, (void *) root);
+        //Drop invalid one.
+        else
+          ENFN->ector_surface_cache_drop(engine, (void *) root);
+     }
 
    if (!buffer)
-     buffer = _render_to_buffer(obj, pd, engine, root, w, h, root, NULL,
-                                do_async);
+     buffer = _render_to_buffer(obj, pd, engine, root, w, h, NULL,
+                                do_async, cacheable);
    else
      //cache reference was increased when we get the cache.
-     ENFN->ector_surface_cache_drop(engine, root);
+     ENFN->ector_surface_cache_drop(engine, (void *) root);
 
    _render_buffer_to_screen(obj,
                             engine, output, context, surface,
                             buffer,
-                            x, y, w, h,
-                            do_async);
+                            x + offset.x, y + offset.y, w, h,
+                            do_async, cacheable);
 }
 
 static void
 _user_vg_entry_render(Evas_Object_Protected_Data *obj,
                       Efl_Canvas_Vg_Object_Data *pd,
                       void *engine, void *output, void *context, void *surface,
-                      int x, int y, int w, int h, Eina_Bool do_async)
+                      int x, int y, int w, int h, Eina_Bool do_async,
+                      Eina_Bool cacheable)
 {
    Vg_User_Entry *user_entry = pd->user_entry;
 
@@ -541,14 +665,16 @@ _user_vg_entry_render(Evas_Object_Protected_Data *obj,
      }
 
    //if the buffer is not created yet
-   void *buffer = ENFN->ector_surface_cache_get(engine, user_entry->root);
+   void *buffer = NULL;
+
+   if (cacheable)
+     buffer = ENFN->ector_surface_cache_get(engine, user_entry->root);
 
    if (!buffer)
      {
         // render to the buffer
         buffer = _render_to_buffer(obj, pd, engine, user_entry->root,
-                                   w, h, user_entry->root, buffer,
-                                   do_async);
+                                   w, h, buffer, do_async, cacheable);
      }
    else
      {
@@ -556,10 +682,8 @@ _user_vg_entry_render(Evas_Object_Protected_Data *obj,
         if (pd->changed)
           buffer = _render_to_buffer(obj, pd, engine,
                                      user_entry->root,
-                                     w, h,
-                                     user_entry->root,
-                                     buffer,
-                                     do_async);
+                                     w, h, buffer,
+                                     do_async, EINA_FALSE);
         //cache reference was increased when we get the cache.
         ENFN->ector_surface_cache_drop(engine, user_entry->root);
      }
@@ -568,7 +692,7 @@ _user_vg_entry_render(Evas_Object_Protected_Data *obj,
                             engine, output, context, surface,
                             buffer,
                             x, y, w, h,
-                            do_async);
+                            do_async, cacheable);
 }
 
 static void
@@ -590,19 +714,30 @@ _efl_canvas_vg_object_render(Evas_Object *eo_obj EINA_UNUSED,
    ENFN->context_anti_alias_set(engine, context, obj->cur->anti_alias);
    ENFN->context_render_op_set(engine, context, obj->cur->render_op);
 
+   //Cache surface?
+   Eina_Bool cacheable = EINA_FALSE;
+
+   /* Try caching buffer only for first and last frames
+      because it's an overhead task if it caches all frame images.
+      We assume the first and last frame images are the most resusable
+      in generic scenarios. */
+   if (pd->frame_idx == 0 ||
+       (pd->frame_idx == (int) (evas_cache_vg_anim_frame_count_get(pd->vg_entry) - 1)))
+     cacheable = EINA_TRUE;
+
    if (pd->vg_entry)
      {
         _cache_vg_entry_render(obj, pd,
                                engine, output, context, surface,
                                obj->cur->geometry.x + x, obj->cur->geometry.y + y,
-                               obj->cur->geometry.w, obj->cur->geometry.h, do_async);
+                               obj->cur->geometry.w, obj->cur->geometry.h, do_async, cacheable);
      }
    if (pd->user_entry)
      {
         _user_vg_entry_render(obj, pd,
                               engine, output, context, surface,
                               obj->cur->geometry.x + x, obj->cur->geometry.y + y,
-                              obj->cur->geometry.w, obj->cur->geometry.h, do_async);
+                              obj->cur->geometry.w, obj->cur->geometry.h, do_async, cacheable);
      }
    pd->changed = EINA_FALSE;
 }
@@ -638,12 +773,12 @@ _efl_canvas_vg_object_render_pre(Evas_Object *eo_obj,
    // FIXME: Move this render_pre to efl_canvas_vg_render()
    s = evas_ector_get(obj->layer->evas);
    if (pd->root && s)
-     _evas_vg_render_pre(obj, pd->root, NULL, NULL, NULL, s, NULL, NULL, 0);
+     _evas_vg_render_pre(obj, pd->root, NULL, NULL, NULL, s, NULL, 255, NULL, 0);
 
    /* now figure what changed and add draw rects */
    /* if it just became visible or invisible */
-   is_v = evas_object_is_visible(eo_obj, obj);
-   was_v = evas_object_was_visible(eo_obj,obj);
+   is_v = evas_object_is_visible(obj);
+   was_v = evas_object_was_visible(obj);
    if (!(is_v | was_v)) goto done;
 
    if (pd->changed)
@@ -682,7 +817,11 @@ _efl_canvas_vg_object_render_pre(Evas_Object *eo_obj,
    if ((obj->cur->color.r != obj->prev->color.r) ||
        (obj->cur->color.g != obj->prev->color.g) ||
        (obj->cur->color.b != obj->prev->color.b) ||
-       (obj->cur->color.a != obj->prev->color.a))
+       (obj->cur->color.a != obj->prev->color.a) ||
+       (obj->cur->cache.clip.r != obj->prev->cache.clip.r) ||
+       (obj->cur->cache.clip.g != obj->prev->cache.clip.g) ||
+       (obj->cur->cache.clip.b != obj->prev->cache.clip.b) ||
+       (obj->cur->cache.clip.a != obj->prev->cache.clip.a))
      {
         evas_object_render_pre_prev_cur_add(&obj->layer->evas->clip_changes, eo_obj, obj);
         goto done;
@@ -701,8 +840,8 @@ _efl_canvas_vg_object_render_pre(Evas_Object *eo_obj,
    /* it obviously didn't change - add a NO obscure - this "unupdates"  this */
    /* area so if there were updates for it they get wiped. don't do it if we */
    /* arent fully opaque and we are visible */
-   if (evas_object_is_visible(eo_obj, obj) &&
-       evas_object_is_opaque(eo_obj, obj) &&
+   if (evas_object_is_visible(obj) &&
+       evas_object_is_opaque(obj) &&
        (!obj->clip.clipees))
      {
         Evas_Coord x, y, w, h;
@@ -759,6 +898,79 @@ _efl_canvas_vg_object_was_opaque(Evas_Object *eo_obj EINA_UNUSED,
    return 0;
 }
 
+/* animated feature */
+EOLIAN static Eina_Bool
+_efl_canvas_vg_object_efl_gfx_frame_controller_animated_get(const Eo *eo_obj EINA_UNUSED,
+                                                                      Efl_Canvas_Vg_Object_Data *pd EINA_UNUSED EINA_UNUSED)
+{
+   //TODO:
+   return EINA_TRUE;
+}
+
+EOLIAN static int
+_efl_canvas_vg_object_efl_gfx_frame_controller_frame_count_get(const Eo *eo_obj EINA_UNUSED,
+                                                                                  Efl_Canvas_Vg_Object_Data *pd EINA_UNUSED)
+{
+   if (!pd->vg_entry) return 0;
+   return evas_cache_vg_anim_frame_count_get(pd->vg_entry);
+}
+
+EOLIAN static Efl_Gfx_Frame_Controller_Loop_Hint
+_efl_canvas_vg_object_efl_gfx_frame_controller_loop_type_get(const Eo *eo_obj EINA_UNUSED,
+                                                                                Efl_Canvas_Vg_Object_Data *pd EINA_UNUSED)
+{
+   //TODO:
+   return EFL_GFX_FRAME_CONTROLLER_LOOP_HINT_NONE;
+}
+
+EOLIAN static int
+_efl_canvas_vg_object_efl_gfx_frame_controller_loop_count_get(const Eo *eo_obj EINA_UNUSED,
+                                                                                 Efl_Canvas_Vg_Object_Data *pd EINA_UNUSED)
+{
+   //TODO:
+   return 0;
+}
+
+EOLIAN static double
+_efl_canvas_vg_object_efl_gfx_frame_controller_frame_duration_get(const Eo *eo_obj EINA_UNUSED,
+                                                                                     Efl_Canvas_Vg_Object_Data *pd,
+                                                                                     int start_frame EINA_UNUSED,
+                                                                                     int frame_num EINA_UNUSED)
+{
+   if (!pd->vg_entry) return 0;
+   return evas_cache_vg_anim_duration_get(pd->vg_entry);
+}
+
+EOLIAN static Eina_Bool
+_efl_canvas_vg_object_efl_gfx_frame_controller_frame_set(Eo *eo_obj,
+                                                         Efl_Canvas_Vg_Object_Data *pd,
+                                                         int frame_index)
+{
+   //TODO: Validate frame_index range
+   if (pd->frame_idx == frame_index) return EINA_TRUE;
+
+   //Image is changed, drop previous cached image.
+   pd->frame_idx = frame_index;
+   pd->changed = EINA_TRUE;
+   evas_object_change(eo_obj, efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS));
+
+   return EINA_TRUE;
+}
+
+EOLIAN static int
+_efl_canvas_vg_object_efl_gfx_frame_controller_frame_get(const Eo *eo_obj EINA_UNUSED,
+                                                                            Efl_Canvas_Vg_Object_Data *pd EINA_UNUSED)
+{
+   return pd->frame_idx;
+}
+
+EOLIAN static Eina_Size2D
+_efl_canvas_vg_object_default_size_get(const Eo *eo_obj EINA_UNUSED,
+                                       Efl_Canvas_Vg_Object_Data *pd EINA_UNUSED)
+{
+   return evas_cache_vg_entry_default_size_get(pd->vg_entry);
+}
+
 /* the actual api call to add a vector graphic object */
 EAPI Evas_Object *
 evas_object_vg_add(Evas *e)
@@ -769,5 +981,79 @@ evas_object_vg_add(Evas *e)
    return efl_add(MY_CLASS, e, efl_canvas_object_legacy_ctor(efl_added));
 }
 
+EAPI int
+evas_object_vg_animated_frame_get(const Evas_Object *obj)
+{
+   return efl_gfx_frame_controller_frame_get(obj);
+}
+
+EAPI double
+evas_object_vg_animated_frame_duration_get(const Evas_Object *obj, int start_frame, int frame_num)
+{
+   return efl_gfx_frame_controller_frame_duration_get(obj, start_frame, frame_num);
+}
+
+EAPI int
+evas_object_vg_animated_frame_count_get(const Evas_Object *obj)
+{
+   return efl_gfx_frame_controller_frame_count_get(obj);
+}
+
+EAPI Eina_Bool
+evas_object_vg_animated_frame_set(Evas_Object *obj, int frame_index)
+{
+   return efl_gfx_frame_controller_frame_set(obj, frame_index);
+}
+
+EAPI Eina_Bool
+evas_object_vg_file_set(Evas_Object *obj, const char *file, const char *key)
+{
+   return efl_file_simple_load(obj, file, key);
+}
+
+static inline Efl_Canvas_Vg_Fill_Mode
+_evas_object_vg_fill_mode_to_efl_ui_canvas_object_vg_fill_mode(Evas_Object_Vg_Fill_Mode mode)
+{
+   switch (mode)
+     {
+#define CONVERT_MODE(MODE) case EVAS_OBJECT_VG_FILL_MODE_##MODE: return EFL_CANVAS_VG_FILL_MODE_##MODE
+       CONVERT_MODE(NONE);
+       CONVERT_MODE(STRETCH);
+       CONVERT_MODE(MEET);
+       CONVERT_MODE(SLICE);
+       default: break;
+     }
+#undef CONVERT_MODE
+   return EFL_CANVAS_VG_FILL_MODE_NONE;
+}
+
+static inline Evas_Object_Vg_Fill_Mode
+_efl_ui_canvas_object_vg_fill_mode_to_evas_object_vg_fill_mode(Efl_Canvas_Vg_Fill_Mode mode)
+{
+   switch (mode)
+     {
+#define CONVERT_MODE(MODE) case EFL_CANVAS_VG_FILL_MODE_##MODE: return EVAS_OBJECT_VG_FILL_MODE_##MODE
+       CONVERT_MODE(NONE);
+       CONVERT_MODE(STRETCH);
+       CONVERT_MODE(MEET);
+       CONVERT_MODE(SLICE);
+       default: break;
+     }
+#undef CONVERT_MODE
+   return EVAS_OBJECT_VG_FILL_MODE_NONE;
+}
+
+EAPI void
+evas_object_vg_fill_mode_set(Efl_VG *obj, Evas_Object_Vg_Fill_Mode fill_mode)
+{
+   efl_canvas_vg_object_fill_mode_set(obj, _evas_object_vg_fill_mode_to_efl_ui_canvas_object_vg_fill_mode(fill_mode));
+}
+
+EAPI Evas_Object_Vg_Fill_Mode
+evas_object_vg_fill_mode_get(const Efl_VG *obj)
+{
+   return _efl_ui_canvas_object_vg_fill_mode_to_evas_object_vg_fill_mode(efl_canvas_vg_object_fill_mode_get(obj));
+}
+
 #include "efl_canvas_vg_object.eo.c"
 #include "efl_canvas_vg_object_eo.legacy.c"
