@@ -6,7 +6,7 @@
 
 #include <Evas.h>
 #include <Evas_Internal.h>
-#include "canvas/evas_canvas.eo.h"
+#include "canvas/evas_canvas_eo.h"
 
 #define EFL_INTERNAL_UNSTABLE
 #include "interfaces/efl_common_internal.h"
@@ -95,7 +95,7 @@ _noref_death(void *data EINA_UNUSED, const Efl_Event *event)
 }
 
 Efl_Input_Event *
-efl_input_event_instance_get(Eo *klass, Eo *owner)
+efl_input_event_instance_get(const Eo *klass, Eo *owner)
 {
    Efl_Input_Event *evt;
 
@@ -117,9 +117,9 @@ efl_input_event_instance_get(Eo *klass, Eo *owner)
      }
    else
      {
-        evt = efl_add(klass, owner,
-                      efl_event_callback_add(efl_added, EFL_EVENT_NOREF, _noref_death, NULL),
-                      efl_del_intercept_set(efl_added, _del_hook));
+        evt = efl_add(klass, owner);
+        efl_event_callback_add(evt, EFL_EVENT_NOREF, _noref_death, NULL);
+        efl_del_intercept_set(evt, _del_hook);
      }
 
    return efl_ref(evt);
@@ -136,14 +136,10 @@ efl_input_event_instance_clean(Eo *klass)
 /* Internal EO APIs */
 
 EOAPI EFL_FUNC_BODY_CONST(efl_input_legacy_info_get, void *, NULL)
-EOAPI EFL_FUNC_BODYV_CONST(efl_input_instance_get, Efl_Input_Event *, NULL, EFL_FUNC_CALL(owner, priv), Efl_Object *owner, void **priv)
 
 #define EFL_INPUT_EVENT_EXTRA_OPS \
    EFL_OBJECT_OP_FUNC(efl_input_legacy_info_get, NULL)
 
-#define EFL_INPUT_EVENT_EXTRA_CLASS_OPS \
-   EFL_OBJECT_OP_FUNC(efl_input_instance_get, NULL)
-
 #include "efl_input_event.eo.c"
 #include "efl_input_state.eo.c"
 #include "efl_input_interface.eo.c"
