@@ -213,7 +213,7 @@ evas_common_draw_context_font_ext_set(RGBA_Draw_Context *dc,
                                       void *data,
                                       void *(*gl_new)  (void *data, RGBA_Font_Glyph *fg),
                                       void  (*gl_free) (void *ext_dat),
-                                      void  (*gl_draw) (void *data, void *dest, void *context, RGBA_Font_Glyph *fg, int x, int y),
+                                      void  (*gl_draw) (void *data, void *dest, void *context, RGBA_Font_Glyph *fg, int x, int y, int w, int h),
                                       void *(*gl_image_new) (void *gc, RGBA_Font_Glyph *fg, int alpha, Evas_Colorspace cspace),
                                       void  (*gl_image_free) (void *image),
                                       void  (*gl_image_draw) (void *gc, void *im, int dx, int dy, int dw, int dh, int smooth))
