@@ -1,7 +1,4 @@
-#include "evas_common_private.h"
-#include "language/evas_bidi_utils.h" /*defines BIDI_SUPPORT if possible */
 #include "evas_font_private.h" /* for Frame-Queuing support */
-#include "evas_font_ot.h"
 
 
 /* FIXME: Check coverage according to the font and not by actually loading */
@@ -77,6 +74,12 @@ evas_common_font_query_run_font_end_get(RGBA_Font *fn, RGBA_Font_Int **script_fi
               * the meanwhile. */
              if (*itr <= 0x1F)
                 continue;
+
+             /* Skip searching font for INHERITED script unicodes.
+              * It is meaningful when only it comes after other unicodes from same font. */
+             if (evas_common_language_char_script_get(*itr) == EVAS_SCRIPT_INHERITED)
+                continue;
+
              /* Break if either it's not in the font, or if it is in the
               * script's font. */
              if (!evas_common_get_char_index(fi, *itr))
@@ -755,13 +758,13 @@ evas_common_font_query_char_at_coords(RGBA_Font *fn, const Evas_Text_Props *text
         if (text_props->bidi_dir == EVAS_BIDI_DIRECTION_LTR)
           {
              double part;
-             part = cluster_adv / items;
+             part = (double) cluster_adv / items;
              item_pos = (int) ((x - cluster_start) / part);
           }
         else
           {
              double part;
-             part = cluster_adv / items;
+             part = (double) cluster_adv / items;
              item_pos = items - ((int) ((x - cluster_start) / part)) - 1;
           }
 
@@ -810,6 +813,7 @@ end:
  * @param text_props the string object.
  * @param x the x boundary.
  * @param y the y boundary.
+ * @param width_offset the additional width only for allowing glyph's.
  * @return the position found, -1 on failure.
  */
 EAPI int
