@@ -2,9 +2,8 @@
 
 #define MY_CLASS EFL_CANVAS_GESTURE_LONG_TAP_CLASS
 
-
 EOLIAN static Efl_Object *
-_efl_canvas_gesture_long_tap_efl_object_constructor(Eo *obj, Efl_Canvas_Gesture_Long_Tap_Data *pd EINA_UNUSED)
+_efl_canvas_gesture_long_tap_efl_object_constructor(Eo *obj, void *pd EINA_UNUSED)
 {
    Efl_Canvas_Gesture_Data *gd;
 
@@ -16,11 +15,8 @@ _efl_canvas_gesture_long_tap_efl_object_constructor(Eo *obj, Efl_Canvas_Gesture_
 }
 
 EOLIAN static void
-_efl_canvas_gesture_long_tap_efl_object_destructor(Eo *obj, Efl_Canvas_Gesture_Long_Tap_Data *pd)
+_efl_canvas_gesture_long_tap_efl_object_destructor(Eo *obj, void *pd EINA_UNUSED)
 {
-   if (pd->timeout)
-     ecore_timer_del(pd->timeout);
-
    efl_destructor(efl_super(obj, MY_CLASS));
 }
 
