@@ -8,14 +8,7 @@
 #include <limits.h>
 #include <wchar.h>
 
-#ifndef WIN32_LEAN_AND_MEAN
-# define WIN32_LEAN_AND_MEAN
-#endif
-#include <windows.h>
-#undef WIN32_LEAN_AND_MEAN
-
-#include "evil_macro.h"
-#include "evil_util.h"
+#include "evil_private.h"
 
 DWORD _evil_tls_index;
 
@@ -168,19 +161,6 @@ _evil_last_error_display(const char *fct)
    fprintf(stderr, "[Evil] [%s] ERROR: %s\n", fct, evil_last_error_get());
 }
 
-
-const char *
-evil_tmpdir_get(void)
-{
-   return NULL;
-}
-
-const char *
-evil_homedir_get(void)
-{
-   return NULL;
-}
-
 int
 evil_path_is_absolute(const char *path)
 {
