@@ -338,7 +338,7 @@ _ecore_evas_modifiers_locks_mask_set(Evas *e, int mask)
 }
 
 static void
-_ecore_evas_extn_cb_mouse_in(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+_ecore_evas_extn_cb_mouse_in(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -353,14 +353,14 @@ _ecore_evas_extn_cb_mouse_in(void *data, Evas *e EINA_UNUSED, Evas_Object *obj E
         memset(&ipc, 0, sizeof(ipc));
 
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_IN, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_mouse_out(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+_ecore_evas_extn_cb_mouse_out(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -375,14 +375,14 @@ _ecore_evas_extn_cb_mouse_out(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
         memset(&ipc, 0, sizeof(ipc));
 
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_OUT, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_mouse_down(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Evas_Event_Mouse_Down *ev = event_info;
@@ -405,7 +405,7 @@ _ecore_evas_extn_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
           ipc_move.x = x;
           ipc_move.y = y;
           ipc_move.timestamp = ev->timestamp;
-          ipc_move.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+          ipc_move.mask = _ecore_evas_modifiers_locks_mask_get(e);
           ipc_move.event_flags = ev->event_flags;
           ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_MOVE, 0, 0, 0, &ipc_move, sizeof(ipc_move));
        }
@@ -415,7 +415,7 @@ _ecore_evas_extn_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
           ipc.b = ev->button;
           ipc.flags = ev->flags;
           ipc.timestamp = ev->timestamp;
-          ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+          ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
           ipc.event_flags = ev->event_flags;
           ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_DOWN, 0, 0, 0, &ipc, sizeof(ipc));
        }
@@ -423,7 +423,7 @@ _ecore_evas_extn_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
 }
 
 static void
-_ecore_evas_extn_cb_mouse_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_mouse_up(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -440,14 +440,14 @@ _ecore_evas_extn_cb_mouse_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj E
         ipc.b = ev->button;
         ipc.flags = ev->flags;
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_UP, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_mouse_move(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -468,14 +468,14 @@ _ecore_evas_extn_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
         ipc.x = x;
         ipc.y = y;
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_MOVE, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_mouse_wheel(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_mouse_wheel(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -492,14 +492,14 @@ _ecore_evas_extn_cb_mouse_wheel(void *data, Evas *e EINA_UNUSED, Evas_Object *ob
         ipc.direction = ev->direction;
         ipc.z = ev->z;
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MOUSE_WHEEL, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_multi_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_multi_down(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -529,7 +529,7 @@ _ecore_evas_extn_cb_multi_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
         ipc.fy = ev->canvas.ysub;
         ipc.flags = ev->flags;
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MULTI_DOWN, 0, 0, 0, &ipc, sizeof(ipc));
      }
@@ -537,7 +537,7 @@ _ecore_evas_extn_cb_multi_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
 
 
 static void
-_ecore_evas_extn_cb_multi_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_multi_up(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -567,14 +567,14 @@ _ecore_evas_extn_cb_multi_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj E
         ipc.fy = ev->canvas.ysub;
         ipc.flags = ev->flags;
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MULTI_UP, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_multi_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_multi_move(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -603,14 +603,14 @@ _ecore_evas_extn_cb_multi_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj
         ipc.fx = ev->cur.canvas.xsub;
         ipc.fy = ev->cur.canvas.ysub;
         ipc.timestamp = ev->timestamp;
-        ipc.mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc.mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc.event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_MULTI_MOVE, 0, 0, 0, &ipc, sizeof(ipc));
      }
 }
 
 static void
-_ecore_evas_extn_cb_key_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_key_down(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -660,14 +660,14 @@ _ecore_evas_extn_cb_key_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj E
              p += strlen(p) + 1;
           }
         ipc->timestamp = ev->timestamp;
-        ipc->mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc->mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc->event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_KEY_DOWN, 0, 0, 0, ipc, len);
      }
 }
 
 static void
-_ecore_evas_extn_cb_key_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
+_ecore_evas_extn_cb_key_up(void *data, Evas *e, Evas_Object *obj EINA_UNUSED, void *event_info)
 {
    Ecore_Evas *ee = data;
    Ecore_Evas_Engine_Buffer_Data *bdata = ee->engine.data;
@@ -717,7 +717,7 @@ _ecore_evas_extn_cb_key_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EIN
              p += strlen(p) + 1;
           }
         ipc->timestamp = ev->timestamp;
-        ipc->mask = _ecore_evas_modifiers_locks_mask_get(ee->evas);
+        ipc->mask = _ecore_evas_modifiers_locks_mask_get(e);
         ipc->event_flags = ev->event_flags;
         ecore_ipc_server_send(extn->ipc.server, MAJOR, OP_EV_KEY_UP, 0, 0, 0, ipc, len);
      }
@@ -845,66 +845,67 @@ _ecore_evas_extn_plug_msg_parent_send(Ecore_Evas *ee, int msg_domain, int msg_id
 static const Ecore_Evas_Engine_Func _ecore_extn_plug_engine_func =
 {
    _ecore_evas_extn_free,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
+   NULL, // fn_callback_resize_set
+   NULL, // fn_callback_move_set
+   NULL, // fn_callback_show_set
+   NULL, // fn_callback_hide_set
+   NULL, // fn_callback_delete_request_set
+   NULL, // fn_callback_destroy_set
+   NULL, // fn_callback_focus_in_set
+   NULL, // fn_callback_focus_out_set
+   NULL, // fn_callback_mouse_in_set
+   NULL, // fn_callback_mouse_out_set
+   NULL, // fn_callback_sticky_set
+   NULL, // fn_callback_unsticky_set
+   NULL, // fn_callback_pre_render_set
+   NULL, // fn_callback_post_render_set
+   NULL, // fn_move
+   NULL, // fn_managed_move
    _ecore_evas_resize,
    _ecore_evas_move_resize,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL, //transparent
-   NULL, // profiles_set
+   NULL, // fn_rotation_set
+   NULL, // fn_shaped_set
+   NULL, // fn_show
+   NULL, // fn_hide
+   NULL, // fn_raise
+   NULL, // fn_lower
+   NULL, // fn_activate
+   NULL, // fn_title_set
+   NULL, // fn_name_class_set
+   NULL, // fn_size_min_set
+   NULL, // fn_size_max_set
+   NULL, // fn_size_base_set
+   NULL, // fn_size_step_set
+   NULL, // fn_object_cursor_set
+   NULL, // fn_object_cursor_unset
+   NULL, // fn_layer_set
+   NULL, // fn_focus_set
+   NULL, // fn_iconified_set
+   NULL, // fn_borderless_set
+   NULL, // fn_override_set
+   NULL, // fn_maximized_set
+   NULL, // fn_fullscreen_set
+   NULL, // fn_avoid_damage_set
+   NULL, // fn_withdrawn_set
+   NULL, // fn_sticky_set
+   NULL, // fn_ignore_events_set
+   NULL, // fn_alpha_set
+   NULL, // fn_transparent_set
+   NULL, // fn_profiles_set
    _ecore_evas_extn_plug_profile_set,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
-   NULL,
 
-   NULL, // render
-   NULL, // screen_geometry_get
-   NULL, // screen_dpi_get
+   NULL, // fn_window_group_set
+   NULL, // fn_aspect_set
+   NULL, // fn_urgent_set
+   NULL, // fn_modal_set
+   NULL, // fn_demands_attention_set
+   NULL, // fn_focus_skip_set
+
+   NULL, // fn_render
+   NULL, // fn_screen_geometry_get
+   NULL, // fn_screen_dpi_get
    _ecore_evas_extn_plug_msg_parent_send,
-   NULL,   // msg_send
+   NULL,  // fn_msg_send
 
    /* 1.8 abstractions */
    NULL, // pointer_xy_get
@@ -921,14 +922,18 @@ static const Ecore_Evas_Engine_Func _ecore_extn_plug_engine_func =
    NULL, // fn_animator_unregister
 
    NULL, // fn_evas_changed
-   NULL, //fn_focus_device_set
-   NULL, //fn_callback_focus_device_in_set
-   NULL, //fn_callback_focus_device_out_set
-   NULL, //fn_callback_device_mouse_in_set
-   NULL, //fn_callback_device_mouse_out_set
-   NULL, //fn_pointer_device_xy_get
-   NULL, //fn_prepare
-   NULL, //fn_last_tick_get
+
+   NULL, // fn_focus_device_set
+   NULL, // fn_callback_focus_device_in_set
+   NULL, // fn_callback_focus_device_out_set
+
+   NULL, // fn_callback_device_mouse_in_set
+   NULL, // fn_callback_device_mouse_out_set
+   NULL, // fn_pointer_device_xy_get
+
+   NULL, // fn_prepare
+
+   NULL  // fn_last_tick_get
 };
 
 static Eina_Bool
@@ -2110,6 +2115,7 @@ static const Ecore_Evas_Engine_Func _ecore_extn_socket_engine_func =
    NULL, //fn_callback_device_mouse_out_set
    NULL, //fn_pointer_device_xy_get
    _ecore_evas_extn_socket_prepare,
+   NULL //fn_last_tick_get
 };
 
 EAPI Ecore_Evas *
