@@ -33,9 +33,8 @@ ecore_evas_wayland_shm_new_internal(const char *disp_name, Ecore_Window parent,
 {
    LOGFN(__FILE__, __LINE__, __FUNCTION__);
 
-   return _ecore_evas_wl_common_new_internal(disp_name, parent,
-                                             x, y, w, h, frame,
-                                             "wayland_shm");
+   return _ecore_evas_wl_common_new_internal(disp_name, parent, x, y, w, h,
+                                             frame, NULL, "wayland_shm");
 }
 
 #endif
