@@ -82,7 +82,11 @@ static Ecore_IMF_Context_Class wayland_imf_class =
    wayland_im_context_input_panel_language_locale_get, /* input_panel_language_locale_get */
    NULL,                                      /* candidate_window_geometry_get */
    wayland_im_context_input_hint_set,         /* input_hint_set */
-   NULL                                       /* bidi_direction_set */
+   NULL,                                      /* bidi_direction_set */
+   NULL,                                      /* keyboard_mode_get */
+   NULL,                                      /* prediction_hint_set */
+   NULL,                                      /* mime_type_accept_set */
+   NULL                                       /* input_panel_position_set */
 };
 
 static struct zwp_text_input_manager_v1 *text_input_manager = NULL;
