@@ -2,10 +2,6 @@
 # include <config.h>
 #endif
 
-#ifdef EVAS_CSERVE2
-#include "evas_cs2_private.h"
-#endif
-
 #include "evas_common_private.h"
 #include "evas_engine.h"
 
@@ -18,14 +14,7 @@ void
 evas_buffer_outbuf_buf_free(Outbuf *buf)
 {
    if (buf->priv.back_buf)
-     {
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          evas_cache2_image_close(&buf->priv.back_buf->cache_entry);
-        else
-#endif
-        evas_cache_image_drop(&buf->priv.back_buf->cache_entry);
-     }
+     evas_cache_image_drop(&buf->priv.back_buf->cache_entry);
    free(buf);
 }
 
@@ -57,34 +46,18 @@ evas_buffer_outbuf_buf_update_fb(Outbuf *buf, int w, int h, Outbuf_Depth depth,
        (buf->dest) && (buf->dest_row_bytes == (buf->w * sizeof(DATA32))))
      {
 	memset(buf->dest, 0, h * buf->dest_row_bytes);
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          buf->priv.back_buf = (RGBA_Image *) evas_cache2_image_data(evas_common_image_cache2_get(),
-                                                                     w, h,
-                                                                     buf->dest,
-                                                                     1, EVAS_COLORSPACE_ARGB8888);
-        else
-#endif
-	buf->priv.back_buf = (RGBA_Image *) evas_cache_image_data(evas_common_image_cache_get(),
-                                                                  w, h,
-                                                                  buf->dest,
-                                                                  1, EVAS_COLORSPACE_ARGB8888);
+	buf->priv.back_buf =
+          (RGBA_Image *) evas_cache_image_data(evas_common_image_cache_get(),
+                                               w, h, buf->dest,
+                                               1, EVAS_COLORSPACE_ARGB8888);
      }
    else if ((buf->depth == OUTBUF_DEPTH_RGB_32BPP_888_8888) &&
        (buf->dest) && (buf->dest_row_bytes == (buf->w * sizeof(DATA32))))
      {
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          buf->priv.back_buf = (RGBA_Image *) evas_cache2_image_data(evas_common_image_cache2_get(),
-                                                                     w, h,
-                                                                     buf->dest,
-                                                                     0, EVAS_COLORSPACE_ARGB8888);
-        else
-#endif
-        buf->priv.back_buf = (RGBA_Image *) evas_cache_image_data(evas_common_image_cache_get(),
-                                                                  w, h,
-                                                                  buf->dest,
-                                                                  0, EVAS_COLORSPACE_ARGB8888);
+        buf->priv.back_buf =
+          (RGBA_Image *) evas_cache_image_data(evas_common_image_cache_get(),
+                                               w, h, buf->dest,
+                                               0, EVAS_COLORSPACE_ARGB8888);
      }
 }
 
@@ -130,11 +103,6 @@ evas_buffer_outbuf_buf_new_region_for_update(Outbuf *buf, int x, int y, int w, i
    else
      {
 	*cx = 0; *cy = 0; *cw = w; *ch = h;
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          im = (RGBA_Image *)evas_cache2_image_empty(evas_common_image_cache2_get());
-        else
-#endif
 	im = (RGBA_Image *) evas_cache_image_empty(evas_common_image_cache_get());
         if (im)
           {
@@ -144,11 +112,6 @@ evas_buffer_outbuf_buf_new_region_for_update(Outbuf *buf, int x, int y, int w, i
 		  im->cache_entry.flags.alpha = 1;
                }
 
-#ifdef EVAS_CSERVE2
-	     if (evas_cserve2_use_get())
-	       evas_cache2_image_size_set(&im->cache_entry, w, h);
-	     else
-#endif
 	       im = (RGBA_Image *) evas_cache_image_size_set(&im->cache_entry, w, h);
           }
      }
@@ -159,14 +122,7 @@ void
 evas_buffer_outbuf_buf_free_region_for_update(Outbuf *buf, RGBA_Image *update)
 {
    if (update != buf->priv.back_buf)
-     {
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          evas_cache2_image_close(&update->cache_entry);
-        else
-#endif
-          evas_cache_image_drop(&update->cache_entry);
-     }
+     evas_cache_image_drop(&update->cache_entry);
 }
 
 void
@@ -177,26 +133,13 @@ evas_buffer_outbuf_buf_switch_buffer(Outbuf *buf, Tilebuf_Rect *surface_damage E
         buf->dest = buf->func.switch_buffer(buf->switch_data, buf->dest);
         if (buf->priv.back_buf)
           {
-#ifdef EVAS_CSERVE2
-             if (evas_cserve2_use_get())
-               {
-                  evas_cache2_image_close(&buf->priv.back_buf->cache_entry);
-                  buf->priv.back_buf = (RGBA_Image *) evas_cache2_image_data(evas_common_image_cache2_get(),
-                                                                            buf->w, buf->h,
-                                                                            buf->dest,
-                                                                            buf->depth == OUTBUF_DEPTH_ARGB_32BPP_8888_8888 ? 1 : 0,
-                                                                            EVAS_COLORSPACE_ARGB8888);
-               }
-             else
-#endif
-               {
-                  evas_cache_image_drop(&buf->priv.back_buf->cache_entry);
-                  buf->priv.back_buf = (RGBA_Image *) evas_cache_image_data(evas_common_image_cache_get(),
-                                                                            buf->w, buf->h,
-                                                                            buf->dest,
-                                                                            buf->depth == OUTBUF_DEPTH_ARGB_32BPP_8888_8888 ? 1 : 0,
-                                                                            EVAS_COLORSPACE_ARGB8888);
-               }
+             evas_cache_image_drop(&buf->priv.back_buf->cache_entry);
+             buf->priv.back_buf =
+               (RGBA_Image *) evas_cache_image_data(evas_common_image_cache_get(),
+                                                    buf->w, buf->h,
+                                                    buf->dest,
+                                                    buf->depth == OUTBUF_DEPTH_ARGB_32BPP_8888_8888 ? 1 : 0,
+                                                    EVAS_COLORSPACE_ARGB8888);
           }
      }
 }
