@@ -1,7 +1,4 @@
 #include "evas_engine.h"
-#ifdef EVAS_CSERVE2
-# include "evas_cs2_private.h"
-#endif
 
 /* FIXME: We NEED to get the color map from the VT and use that for the mask */
 #define RED_MASK 0xff0000
@@ -11,26 +8,6 @@
 #define MAX_BUFFERS 10
 #define QUEUE_TRIM_DURATION 100
 
-static void
-_outbuf_buffer_swap(Outbuf *ob, Eina_Rectangle *rects, unsigned int count)
-{
-   /* Ecore_Drm2_Plane *plane; */
-   Outbuf_Fb *ofb;
-
-   ofb = ob->priv.draw;
-   if (!ofb) return;
-
-   ecore_drm2_fb_dirty(ofb->fb, rects, count);
-
-   if (!ob->priv.plane)
-     ob->priv.plane = ecore_drm2_plane_assign(ob->priv.output, ofb->fb, 0, 0);
-   else ecore_drm2_plane_fb_set(ob->priv.plane, ofb->fb);
-
-   ecore_drm2_fb_flip(ofb->fb, ob->priv.output);
-   ofb->drawn = EINA_TRUE;
-   ofb->age = 0;
-}
-
 static Outbuf_Fb *
 _outbuf_fb_create(Outbuf *ob, int w, int h)
 {
@@ -68,6 +45,126 @@ _outbuf_fb_destroy(Outbuf_Fb *ofb)
    free(ofb);
 }
 
+static Outbuf_Fb *
+_outbuf_fb_wait(Outbuf *ob)
+{
+   Eina_List *l;
+   Outbuf_Fb *ofb, *best = NULL;
+   int best_age = -1, num_required = 1, num_allocated = 0;
+
+   /* We pick the oldest available buffer to avoid using the same two
+    * repeatedly and then having the third be stale when we need it
+    */
+   EINA_LIST_FOREACH(ob->priv.fb_list, l, ofb)
+     {
+        num_allocated++;
+        if (ecore_drm2_fb_busy_get(ofb->fb))
+          {
+             num_required++;
+             continue;
+          }
+        if (ofb->valid && (ofb->age > best_age))
+          {
+             best = ofb;
+             best_age = best->age;
+          }
+     }
+
+   if (num_required < num_allocated)
+      ob->priv.unused_duration++;
+   else
+      ob->priv.unused_duration = 0;
+
+   /* If we've had unused buffers for longer than QUEUE_TRIM_DURATION, then
+    * destroy the oldest buffer (currently in best) and recursively call
+    * ourself to get the next oldest.
+    */
+   if (best && (ob->priv.unused_duration > QUEUE_TRIM_DURATION))
+     {
+        ob->priv.unused_duration = 0;
+        ob->priv.fb_list = eina_list_remove(ob->priv.fb_list, best);
+        _outbuf_fb_destroy(best);
+        best = _outbuf_fb_wait(ob);
+     }
+
+   return best;
+}
+
+static Outbuf_Fb *
+_outbuf_fb_assign(Outbuf *ob)
+{
+   int fw = 0, fh = 0;
+   Outbuf_Fb *ofb;
+   Eina_List *l;
+
+   ob->priv.draw = _outbuf_fb_wait(ob);
+   if (!ob->priv.draw)
+     {
+        EINA_SAFETY_ON_TRUE_RETURN_VAL(eina_list_count(ob->priv.fb_list) >= MAX_BUFFERS, NULL);
+
+        if ((ob->rotation == 0) || (ob->rotation == 180))
+          {
+             fw = ob->w;
+             fh = ob->h;
+          }
+        else if ((ob->rotation == 90) || (ob->rotation == 270))
+          {
+             fw = ob->h;
+             fh = ob->w;
+          }
+        ob->priv.draw = _outbuf_fb_create(ob, fw, fh);
+        if (ob->priv.draw)
+          ob->priv.fb_list = eina_list_append(ob->priv.fb_list, ob->priv.draw);
+     }
+
+   while (!ob->priv.draw)
+     {
+        ecore_drm2_fb_release(ob->priv.output, EINA_TRUE);
+        ob->priv.draw = _outbuf_fb_wait(ob);
+     }
+
+   EINA_LIST_FOREACH(ob->priv.fb_list, l, ofb)
+     {
+        if ((ofb->valid) && (ofb->drawn))
+          {
+             ofb->age++;
+             if (ofb->age > 4)
+               {
+                  ofb->age = 0;
+                  ofb->drawn = EINA_FALSE;
+               }
+          }
+     }
+
+   return ob->priv.draw;
+}
+
+static void
+_outbuf_buffer_swap(Outbuf *ob)
+{
+   Outbuf_Fb *ofb;
+
+   ofb = ob->priv.draw;
+   if (!ofb)
+     {
+        ecore_drm2_fb_release(ob->priv.output, EINA_TRUE);
+        ofb = _outbuf_fb_assign(ob);
+        if (!ofb)
+          {
+             ERR("Could not assign front buffer");
+             return;
+          }
+     }
+
+   if (!ob->priv.plane)
+     ob->priv.plane = ecore_drm2_plane_assign(ob->priv.output, ofb->fb, 0, 0);
+   else ecore_drm2_plane_fb_set(ob->priv.plane, ofb->fb);
+
+   ecore_drm2_fb_flip(ofb->fb, ob->priv.output);
+   ofb->drawn = EINA_TRUE;
+   ofb->age = 0;
+}
+
 Outbuf *
 _outbuf_setup(Evas_Engine_Info_Drm *info, int w, int h)
 {
@@ -107,12 +204,7 @@ _outbuf_free(Outbuf *ob)
 
         rect = img->extended_info;
 
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          evas_cache2_image_close(&img->cache_entry);
-        else
-#endif
-          evas_cache_image_drop(&img->cache_entry);
+        evas_cache_image_drop(&img->cache_entry);
 
         eina_rectangle_free(rect);
      }
@@ -136,7 +228,6 @@ _outbuf_rotation_get(Outbuf *ob)
 void
 _outbuf_reconfigure(Outbuf *ob, int w, int h, int rotation, Outbuf_Depth depth)
 {
-   Outbuf_Fb *ofb;
    unsigned int format = DRM_FORMAT_ARGB8888;
 
    switch (depth)
@@ -189,104 +280,7 @@ _outbuf_reconfigure(Outbuf *ob, int w, int h, int rotation, Outbuf_Depth depth)
    ob->rotation = rotation;
    ob->priv.unused_duration = 0;
 
-   EINA_LIST_FREE(ob->priv.fb_list, ofb)
-     _outbuf_fb_destroy(ofb);
-
-   /* TODO: idle flush */
-}
-
-static Outbuf_Fb *
-_outbuf_fb_wait(Outbuf *ob)
-{
-   Eina_List *l;
-   Outbuf_Fb *ofb, *best = NULL;
-   int best_age = -1, num_required = 1, num_allocated = 0;
-
-   /* We pick the oldest available buffer to avoid using the same two
-    * repeatedly and then having the third be stale when we need it
-    */
-   EINA_LIST_FOREACH(ob->priv.fb_list, l, ofb)
-     {
-        num_allocated++;
-        if (ecore_drm2_fb_busy_get(ofb->fb))
-          {
-             num_required++;
-             continue;
-          }
-        if (ofb->valid && (ofb->age > best_age))
-          {
-             best = ofb;
-             best_age = best->age;
-          }
-     }
-
-   if (num_required < num_allocated)
-      ob->priv.unused_duration++;
-   else
-      ob->priv.unused_duration = 0;
-
-   /* If we've had unused buffers for longer than QUEUE_TRIM_DURATION, then
-    * destroy the oldest buffer (currently in best) and recursively call
-    * ourself to get the next oldest.
-    */
-   if (best && (ob->priv.unused_duration > QUEUE_TRIM_DURATION))
-     {
-        ob->priv.unused_duration = 0;
-        ob->priv.fb_list = eina_list_remove(ob->priv.fb_list, best);
-        _outbuf_fb_destroy(best);
-        best = _outbuf_fb_wait(ob);
-     }
-
-   return best;
-}
-
-static Eina_Bool
-_outbuf_fb_assign(Outbuf *ob)
-{
-   int fw = 0, fh = 0;
-   Outbuf_Fb *ofb;
-   Eina_List *l;
-
-   ob->priv.draw = _outbuf_fb_wait(ob);
-   if (!ob->priv.draw)
-     {
-        EINA_SAFETY_ON_TRUE_RETURN_VAL(eina_list_count(ob->priv.fb_list) >= MAX_BUFFERS, EINA_FALSE);
-
-        if ((ob->rotation == 0) || (ob->rotation == 180))
-          {
-             fw = ob->w;
-             fh = ob->h;
-          }
-        else if ((ob->rotation == 90) || (ob->rotation == 270))
-          {
-             fw = ob->h;
-             fh = ob->w;
-          }
-        ob->priv.draw = _outbuf_fb_create(ob, fw, fh);
-        if (ob->priv.draw)
-          ob->priv.fb_list = eina_list_append(ob->priv.fb_list, ob->priv.draw);
-     }
-
-   while (!ob->priv.draw)
-     {
-        ecore_drm2_fb_release(ob->priv.output, EINA_TRUE);
-        ob->priv.draw = _outbuf_fb_wait(ob);
-     }
-
-   EINA_LIST_FOREACH(ob->priv.fb_list, l, ofb)
-     {
-        if ((ofb->valid) && (ofb->drawn))
-          {
-             ofb->age++;
-             if (ofb->age > 4)
-               {
-                  ofb->age = 0;
-                  ofb->drawn = EINA_FALSE;
-               }
-          }
-     }
-
-   return EINA_TRUE;
+   _outbuf_idle_flush(ob);
 }
 
 Render_Output_Swap_Mode
@@ -294,7 +288,7 @@ _outbuf_state_get(Outbuf *ob)
 {
    int age;
 
-   if (!_outbuf_fb_assign(ob)) return MODE_FULL;
+   if (!ob->priv.draw) return MODE_FULL;
 
    age = ob->priv.draw->age;
    if (age > 4) return MODE_FULL;
@@ -319,12 +313,7 @@ _outbuf_update_region_new(Outbuf *ob, int x, int y, int w, int h, int *cx, int *
    if (!(rect = eina_rectangle_new(x, y, w, h)))
      return NULL;
 
-#ifdef EVAS_CSERVE2
-   if (evas_cserve2_use_get())
-     img = (RGBA_Image *)evas_cache2_image_empty(evas_common_image_cache2_get());
-   else
-#endif
-     img = (RGBA_Image *)evas_cache_image_empty(evas_common_image_cache_get());
+   img = (RGBA_Image *)evas_cache_image_empty(evas_common_image_cache_get());
 
    if (!img)
      {
@@ -334,12 +323,7 @@ _outbuf_update_region_new(Outbuf *ob, int x, int y, int w, int h, int *cx, int *
 
    img->cache_entry.flags.alpha = ob->alpha;
 
-#ifdef EVAS_CSERVE2
-   if (evas_cserve2_use_get())
-     evas_cache2_image_surface_alloc(&img->cache_entry, w, h);
-   else
-#endif
-     evas_cache_image_surface_alloc(&img->cache_entry, w, h);
+   evas_cache_image_surface_alloc(&img->cache_entry, w, h);
 
    img->extended_info = rect;
 
@@ -552,23 +536,59 @@ _outbuf_flush(Outbuf *ob, Tilebuf_Rect *surface_damage EINA_UNUSED, Tilebuf_Rect
 
         eina_rectangle_free(rect);
 
-#ifdef EVAS_CSERVE2
-        if (evas_cserve2_use_get())
-          evas_cache2_image_close(&img->cache_entry);
-        else
-#endif
-          evas_cache_image_drop(&img->cache_entry);
+        evas_cache_image_drop(&img->cache_entry);
 
         i++;
      }
+
+   _outbuf_buffer_swap(ob);
 }
 
 void
-_outbuf_redraws_clear(Outbuf *ob)
+_outbuf_damage_region_set(Outbuf *ob, Tilebuf_Rect *damage)
 {
-   if (!ob->priv.rect_count) return;
+   Tilebuf_Rect *tr;
+   Eina_Rectangle *rects;
+   Ecore_Drm2_Fb *fb;
+   int count, i = 0;
 
-   _outbuf_buffer_swap(ob, ob->priv.rects, ob->priv.rect_count);
-   free(ob->priv.rects);
-   ob->priv.rect_count = 0;
+   if (!ob->priv.draw) return;
+
+   fb = ob->priv.draw->fb;
+
+   count = eina_inlist_count(EINA_INLIST_GET(damage));
+   rects = alloca(count * sizeof(Eina_Rectangle));
+
+   EINA_INLIST_FOREACH(damage, tr)
+     {
+        rects[i].x = tr->x;
+        rects[i].y = tr->y;
+        rects[i].w = tr->w;
+        rects[i].h = tr->h;
+        i++;
+     }
+
+   ecore_drm2_fb_dirty(fb, rects, count);
+}
+
+void
+_outbuf_idle_flush(Outbuf *ob)
+{
+   while (ob->priv.pending)
+     {
+        RGBA_Image *img;
+        Eina_Rectangle *rect;
+
+        img = ob->priv.pending->data;
+        ob->priv.pending =
+          eina_list_remove_list(ob->priv.pending, ob->priv.pending);
+
+        rect = img->extended_info;
+
+        evas_cache_image_drop(&img->cache_entry);
+
+        eina_rectangle_free(rect);
+     }
+
+   while (ecore_drm2_fb_release(ob->priv.output, EINA_TRUE));
 }
