@@ -8,10 +8,6 @@
 # error eglfs should not get compiled if dlsym is not found on the system!
 #endif
 
-#ifdef EVAS_CSERVE2
-# include "evas_cs2_private.h"
-#endif
-
 #define EVAS_GL_NO_GL_H_CHECK 1
 #include "Evas_GL.h"
 
@@ -237,7 +233,8 @@ gl_extn_veto(Render_Engine *re)
              glsym_eglSwapBuffersWithDamage = NULL;
           }
         if (!strstr(str, "EGL_EXT_buffer_age")) _extn_have_buffer_age = 0;
-        if (!strstr(str, "EGL_EXT_swap_buffers_with_damage"))
+        if ((!strstr(str, "EGL_EXT_swap_buffers_with_damage")) &&
+            (!strstr(str, "EGL_KHR_swap_buffers_with_damage")))
           glsym_eglSwapBuffersWithDamage = NULL;
      }
    else
