@@ -265,7 +265,8 @@ enum _Shader_Type {
    SHD_FILTER_DISPLACE,
    SHD_FILTER_CURVE,
    SHD_FILTER_BLUR_X,
-   SHD_FILTER_BLUR_Y
+   SHD_FILTER_BLUR_Y,
+   SHD_FILTER_GRAYSCALE
 };
 
 #define ARRAY_BUFFER_USE 500
@@ -308,8 +309,6 @@ struct _Evas_Engine_GL_Context
       Eina_Bool          size       : 1;
    } change;
 
-   Eina_Bool             havestuff  : 1;
-
    struct {
       struct {
          int              x, y, w, h;
@@ -335,7 +334,7 @@ struct _Evas_Engine_GL_Context
       } shader;
       struct {
          int            num, alloc;
-         GLshort       *vertex;
+         GLfloat       *vertex;
          GLubyte       *color;
          GLfloat       *texuv;
          GLfloat       *texuv2;
@@ -380,6 +379,9 @@ struct _Evas_Engine_GL_Context
 
    GLuint preserve_bit;
    int    gles_version;
+
+   Eina_Bool havestuff : 1;
+   Eina_Bool msaa : 1;
 };
 
 struct _Evas_GL_Texture_Pool
@@ -679,6 +681,7 @@ void              evas_gl_common_filter_curve_push(Evas_Engine_GL_Context *gc, E
 void              evas_gl_common_filter_blur_push(Evas_Engine_GL_Context *gc, Evas_GL_Texture *tex, double sx, double sy, double sw, double sh,
                                                   double dx, double dy, double dw, double dh, const double * const values, const double * const offsets, int count, double radius,
                                                   Eina_Bool horiz, Eina_Bool alphaonly);
+void              evas_gl_common_filter_grayscale_push(Evas_Engine_GL_Context *gc, Evas_GL_Texture *tex, int x, int y, int w, int h);
 
 int               evas_gl_common_shader_program_init(Evas_GL_Shared *shared);
 void              evas_gl_common_shader_program_shutdown(Evas_GL_Shared *shared);
