@@ -45,8 +45,9 @@ typedef enum {
    SHADER_FLAG_FILTER_BLUR       = (1 << 23),
    SHADER_FLAG_FILTER_DIR_Y      = (1 << 24),
    SHADER_FLAG_FILTER_ALPHA_ONLY = (1 << 25),
+   SHADER_FLAG_FILTER_GRAYSCALE  = (1 << 26),
 } Shader_Flag;
-#define SHADER_FLAG_COUNT 26
+#define SHADER_FLAG_COUNT 27
 
 static const char *_shader_flags[SHADER_FLAG_COUNT] = {
    "TEX",
@@ -75,6 +76,7 @@ static const char *_shader_flags[SHADER_FLAG_COUNT] = {
    "FILTER_BLUR",
    "FILTER_DIR_Y",
    "ALPHA_ONLY",
+   "FILTER_GRAYSCALE",
 };
 
 static Eina_Bool compiler_released = EINA_FALSE;
@@ -824,6 +826,9 @@ evas_gl_common_shader_flags_get(Evas_GL_Shared *shared, Shader_Type type,
         flags |= SHADER_FLAG_FILTER_BLUR;
         flags |= SHADER_FLAG_FILTER_DIR_Y;
         break;
+      case SHD_FILTER_GRAYSCALE:
+        flags |= SHADER_FLAG_FILTER_GRAYSCALE;
+        break;
       default:
         CRI("Impossible shader type.");
         return 0;
