@@ -31,6 +31,11 @@ struct _Evas_Engine_Info_Wayland
    int x_cursor, y_cursor;
    int resizing;
    uint32_t timestamp;
+   /* window surface should be made with these config */
+   int depth_bits;
+   int stencil_bits;
+   int msaa_bits;
+
    Eina_Bool dragging : 1;
    Eina_Bool drag_start : 1;
    Eina_Bool drag_stop : 1;
