@@ -7,10 +7,6 @@
 # include <dlfcn.h>
 #endif
 
-#ifdef EVAS_CSERVE2
-# include "evas_cs2_private.h"
-#endif
-
 #define EVAS_GL_NO_GL_H_CHECK 1
 #include "Evas_GL.h"
 
@@ -227,7 +223,8 @@ gl_extn_veto(Render_Engine *re)
                 )
                extn_have_y_inverted = EINA_FALSE;
           }
-        if (!strstr(str, "EGL_EXT_swap_buffers_with_damage"))
+        if ((!strstr(str, "EGL_EXT_swap_buffers_with_damage")) &&
+            (!strstr(str, "EGL_KHR_swap_buffers_with_damage")))
           {
              glsym_eglSwapBuffersWithDamage = NULL;
           }
