@@ -69,7 +69,7 @@ struct _Outbuf
    int vsync;
    int frame_cnt;
 
-   struct 
+   struct
      {
         Eina_Bool drew : 1;
      } draw;
@@ -79,6 +79,16 @@ struct _Outbuf
    EGLConfig egl_config;
    EGLDisplay egl_disp;
 
+   struct {
+      unsigned char depth_buffer_size;
+      unsigned char stencil_buffer_size;
+      unsigned char msaa;
+   } detected;
+
+   int depth_bits;
+   int stencil_bits;
+   int msaa_bits;
+
    Eina_Bool lost_back : 1;
    Eina_Bool surf : 1;
 };
