@@ -4,10 +4,6 @@
 
 #include <stdio.h>
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #include <math.h>
 
 #include "evas_common_private.h"
@@ -323,7 +319,7 @@ evas_image_load_file_close_bmp(void *loader_data)
 
 static Eina_Bool
 evas_image_load_file_head_bmp(void *loader_data,
-                              Evas_Image_Property *prop,
+                              Emile_Image_Property *prop,
                               int *error)
 {
    Evas_Loader_Internal *loader;
@@ -458,7 +454,7 @@ evas_image_load_file_head_bmp(void *loader_data,
 
 static Eina_Bool
 evas_image_load_file_data_bmp(void *loader_data,
-                              Evas_Image_Property *prop,
+                              Emile_Image_Property *prop,
 			      void *pixels,
 			      int *error)
 {
@@ -1433,10 +1429,12 @@ evas_image_load_file_data_bmp(void *loader_data,
 
 static Evas_Image_Load_Func evas_image_load_bmp_func =
 {
+  EVAS_IMAGE_LOAD_VERSION,
   evas_image_load_file_open_bmp,
   evas_image_load_file_close_bmp,
-  evas_image_load_file_head_bmp,
-  evas_image_load_file_data_bmp,
+  (void*) evas_image_load_file_head_bmp,
+  NULL,
+  (void*) evas_image_load_file_data_bmp,
   NULL,
   EINA_TRUE,
   EINA_FALSE
