@@ -2,10 +2,6 @@
 # include <config.h>
 #endif
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #include "evas_common_private.h"
 #include "evas_private.h"
 
@@ -71,7 +67,7 @@ evas_image_load_file_close_pmaps(void *loader_data EINA_UNUSED)
 
 static Eina_Bool
 evas_image_load_file_head_pmaps(void *loader_data,
-                                Evas_Image_Property *prop,
+                                Emile_Image_Property *prop,
                                 int *error)
 {
    Eina_File *f = loader_data;
@@ -99,7 +95,7 @@ evas_image_load_file_head_pmaps(void *loader_data,
 
 static Eina_Bool
 evas_image_load_file_data_pmaps(void *loader_data,
-				Evas_Image_Property *prop,
+				Emile_Image_Property *prop,
 				void *pixels,
 				int *error)
 {
@@ -555,10 +551,12 @@ pmaps_buffer_plain_bw_get(Pmaps_Buffer *b, DATA32 *val)
 
 /* external functions */
 Evas_Image_Load_Func evas_image_load_pmaps_func = {
+   EVAS_IMAGE_LOAD_VERSION,
    evas_image_load_file_open_pmaps,
    evas_image_load_file_close_pmaps,
-   evas_image_load_file_head_pmaps,
-   evas_image_load_file_data_pmaps,
+   (void*) evas_image_load_file_head_pmaps,
+   NULL,
+   (void*) evas_image_load_file_data_pmaps,
    NULL,
    EINA_TRUE,
    EINA_FALSE
