@@ -6,10 +6,6 @@
 #include <sys/types.h>
 #include <fcntl.h>
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #include "evas_common_private.h"
 #include "evas_private.h"
 
@@ -72,7 +68,7 @@ evas_image_load_file_close_tga(void *loader_data EINA_UNUSED)
 
 static Eina_Bool
 evas_image_load_file_head_tga(void *loader_data,
-                              Evas_Image_Property *prop,
+                              Emile_Image_Property *prop,
                               int *error)
 {
    Eina_File *f = loader_data;
@@ -168,7 +164,7 @@ close_file:
 
 static Eina_Bool
 evas_image_load_file_data_tga(void *loader_data,
-                              Evas_Image_Property *prop,
+                              Emile_Image_Property *prop,
                               void *pixels,
                               int *error)
 {
@@ -567,10 +563,12 @@ evas_image_load_file_data_tga(void *loader_data,
 
 static Evas_Image_Load_Func evas_image_load_tga_func =
 {
+  EVAS_IMAGE_LOAD_VERSION,
   evas_image_load_file_open_tga,
   evas_image_load_file_close_tga,
-  evas_image_load_file_head_tga,
-  evas_image_load_file_data_tga,
+  (void*) evas_image_load_file_head_tga,
+  NULL,
+  (void*) evas_image_load_file_data_tga,
   NULL,
   EINA_TRUE,
   EINA_FALSE
