@@ -35,7 +35,8 @@ struct _Evas_SVG_Loader
    Eina_Array *stack;
    Svg_Node *doc;
    Svg_Node *def;
-   Svg_Style_Gradient *gradient;
+   Eina_List *gradients;
+   Svg_Style_Gradient *latest_gradient; //for stops
    Evas_SVG_Parser *svg_parse;
    int level;
    Eina_Bool result:1;
@@ -83,7 +84,7 @@ _parse_number(const char **content, double *number)
 {
    char *end = NULL;
 
-   *number = strtod(*content, &end);
+   *number = eina_convert_strtod_c(*content, &end);
    // if the start of string is not number
    if ((*content) == end) return EINA_FALSE;
    //skip comma if any
@@ -101,7 +102,7 @@ _parse_number(const char **content, double *number)
 static inline double
 _to_double(Evas_SVG_Parser *svg_parse, const char *str, SVG_Parser_Length_Type type)
 {
-   double parsed_value = strtod(str, NULL);
+   double parsed_value = eina_convert_strtod_c(str, NULL);
 
    if (strstr(str, "cm"))
      parsed_value = parsed_value * 35.43307;
@@ -140,7 +141,7 @@ _gradient_to_double(Evas_SVG_Parser *svg_parse, const char *str, SVG_Parser_Leng
 {
    char *end = NULL;
 
-   double parsed_value = strtod(str, &end);
+   double parsed_value = eina_convert_strtod_c(str, &end);
    double max = 1;
 
    /**
@@ -181,7 +182,7 @@ _to_offset(const char *str)
 {
    char *end = NULL;
 
-   double parsed_value = strtod(str, &end);
+   double parsed_value = eina_convert_strtod_c(str, &end);
 
    if (strstr(str, "%"))
      parsed_value = parsed_value / 100.0;
@@ -194,9 +195,9 @@ _to_opacity(const char *str)
 {
    char *end = NULL;
    int a = 0;
-   double opacity = strtod(str, &end);
+   double opacity = eina_convert_strtod_c(str, &end);
 
-   if (*end == '\0')
+   if (end && (*end == '\0'))
      a = lrint(opacity * 255);
    return a;
 }
@@ -276,7 +277,7 @@ _parse_dash_array(const char *str, Efl_Gfx_Dash** dash, int *length)
      {
         // skip white space, comma
         str = _skipcomma(str);
-        tmp[count++] = strtod(str, &end);
+        tmp[count++] = eina_convert_strtod_c(str, &end);
         str = _skipcomma(end);
      }
 
@@ -336,7 +337,7 @@ _color_parser(const char *value, char **end)
 {
    double r;
 
-   r = strtod(value + 4, end);
+   r = eina_convert_strtod_c(value + 4, end);
    *end = _skip_space(*end, NULL);
    if (**end == '%')
      r = 255 * r / 100;
@@ -589,7 +590,7 @@ parse_numbers_array(char *str, double *points, int *pt_count)
           *str == '+' ||
           *str == '.')
      {
-        points[count++] = strtod(str, &end);
+        points[count++] = eina_convert_strtod_c(str, &end);
         str = end;
         str = _skip_space(str, NULL);
         if (*str == ',')
@@ -693,6 +694,10 @@ _parse_transformation_matrix(const char *value)
           }
         else if (state == SVG_MATRIX_ROTATE)
           {
+             //Transform to signed.
+             points[0] = fmod(points[0], 360);
+             if (points[0] < 0) points[0] += 360;
+
              if (pt_count == 1)
                {
                   eina_matrix3_rotate(matrix, points[0] * (M_PI/180.0));
@@ -753,7 +758,7 @@ parse_length(const char *str, Svg_Length_Type *type)
        {
           *type = length_tags[i].type;
        }
-   value = strtod(str, NULL);
+   value = eina_convert_strtod_c(str, NULL);
    return value;
 }
 
@@ -887,6 +892,12 @@ _handle_fill_rule_attr(Evas_SVG_Loader *loader EINA_UNUSED, Svg_Node* node, cons
    node->style->fill.fill_rule = _to_fill_rule(value);
 }
 
+static void
+_handle_opacity_attr(Evas_SVG_Loader *loader EINA_UNUSED, Svg_Node* node, const char *value)
+{
+   node->style->opacity = _to_opacity(value);
+}
+
 static void
 _handle_fill_opacity_attr(Evas_SVG_Loader *loader EINA_UNUSED, Svg_Node* node, const char *value)
 {
@@ -900,6 +911,16 @@ _handle_transform_attr(Evas_SVG_Loader *loader EINA_UNUSED, Svg_Node* node, cons
    node->transform = _parse_transformation_matrix(value);
 }
 
+static void
+_handle_display_attr(Evas_SVG_Loader *loader EINA_UNUSED, Svg_Node* node, const char *value)
+{
+   //TODO : The display attribute can have various values as well as "none".
+   //       The default is "inline" which means visible and "none" means invisible.
+   //       Depending on the type of node, additional functionality may be required.
+   //       refer to https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/display
+   if (!strcmp(value, "none")) node->display = EINA_FALSE;
+   else node->display = EINA_TRUE;
+}
 
 typedef void (*Style_Method)(Evas_SVG_Loader *loader, Svg_Node *node, const char *value);
 
@@ -915,12 +936,14 @@ static const struct {
   STYLE_DEF(fill, fill),
   STYLE_DEF(fill-rule, fill_rule),
   STYLE_DEF(fill-opacity, fill_opacity),
+  STYLE_DEF(opacity, opacity),
   STYLE_DEF(stroke, stroke),
   STYLE_DEF(stroke-width, stroke_width),
   STYLE_DEF(stroke-linejoin, stroke_linejoin),
   STYLE_DEF(stroke-linecap, stroke_linecap),
   STYLE_DEF(stroke-opacity, stroke_opacity),
-  STYLE_DEF(transform, transform)
+  STYLE_DEF(transform, transform),
+  STYLE_DEF(display, display)
 };
 
 static Eina_Bool
@@ -995,12 +1018,13 @@ _create_node(Svg_Node *parent, Svg_Node_Type type)
    // update the default value of stroke and fill
    //https://www.w3.org/TR/SVGTiny12/painting.html#SpecifyingPaint
    // default fill color is black
-   node->style->fill.paint.r = 0;
-   node->style->fill.paint.g = 0;
-   node->style->fill.paint.b = 0;
+   //node->style->fill.paint.r = 0;
+   //node->style->fill.paint.g = 0;
+   //node->style->fill.paint.b = 0;
    node->style->fill.paint.none = EINA_FALSE;
    // default fill opacity is 1
    node->style->fill.opacity = 255;
+   node->style->opacity = 255;
 
    // default fill rule is nonzero
    node->style->fill.fill_rule = EFL_GFX_FILL_RULE_WINDING;
@@ -1017,6 +1041,9 @@ _create_node(Svg_Node *parent, Svg_Node_Type type)
    node->style->stroke.join = EFL_GFX_JOIN_MITER;
    node->style->stroke.scale = 1.0;
 
+   // default display is true("inline").
+   node->display = EINA_TRUE;
+
    node->parent = parent;
    node->type = type;
    node->child = NULL;
@@ -1521,6 +1548,11 @@ _clone_gradient(Svg_Style_Gradient *from)
    grad->spread = from->spread;
    grad->use_percentage = from->use_percentage;
    grad->user_space = from->user_space;
+   if (from->transform)
+     {
+        grad->transform = calloc(1, sizeof(Eina_Matrix3));
+        eina_matrix3_copy(grad->transform, from->transform);
+     }
    grad->stops = _clone_grad_stops(from->stops);
    if (grad->type == SVG_LINEAR_GRADIENT)
      {
@@ -1745,15 +1777,63 @@ _handle_radial_r_attr(Evas_SVG_Loader *loader, Svg_Radial_Gradient* radial, cons
    radial->r = _gradient_to_double(loader->svg_parse, value, SVG_PARSER_LENGTH_OTHER);
 }
 
+static void
+_recalc_radial_cx_attr(Evas_SVG_Loader *loader, Svg_Radial_Gradient* radial, Eina_Bool user_space)
+{
+   if (!user_space)
+     {
+        radial->cx = radial->cx * loader->svg_parse->global.width;
+     }
+}
+
+static void
+_recalc_radial_cy_attr(Evas_SVG_Loader *loader, Svg_Radial_Gradient* radial, Eina_Bool user_space)
+{
+   if (!user_space)
+     {
+        radial->cy = radial->cy * loader->svg_parse->global.height;
+     }
+}
+
+static void
+_recalc_radial_fx_attr(Evas_SVG_Loader *loader, Svg_Radial_Gradient* radial, Eina_Bool user_space)
+{
+   if (!user_space)
+     {
+        radial->fx = radial->fx * loader->svg_parse->global.width;
+     }
+}
+
+static void
+_recalc_radial_fy_attr(Evas_SVG_Loader *loader, Svg_Radial_Gradient* radial, Eina_Bool user_space)
+{
+   if (!user_space)
+     {
+        radial->fy = radial->fy * loader->svg_parse->global.height;
+     }
+}
+
+static void
+_recalc_radial_r_attr(Evas_SVG_Loader *loader, Svg_Radial_Gradient* radial, Eina_Bool user_space)
+{
+   if (!user_space)
+     {
+        radial->r = radial->r * (sqrt(pow(loader->svg_parse->global.height, 2) + pow(loader->svg_parse->global.width, 2)) / sqrt(2.0));
+     }
+}
+
+
 typedef void (*Radial_Method)(Evas_SVG_Loader *loader, Svg_Radial_Gradient *radial, const char *value);
+typedef void (*Radial_Method_Recalc)(Evas_SVG_Loader *loader, Svg_Radial_Gradient *radial, Eina_Bool user_space);
 
 #define RADIAL_DEF(Name)       \
-  { #Name, sizeof (#Name), _handle_radial_##Name##_attr}
+  { #Name, sizeof (#Name), _handle_radial_##Name##_attr, _recalc_radial_##Name##_attr}
 
 static const struct {
    const char *tag;
    int sz;
    Radial_Method tag_handler;;
+   Radial_Method_Recalc tag_recalc;
 } radial_tags[] = {
   RADIAL_DEF(cx),
   RADIAL_DEF(cy),
@@ -1801,6 +1881,7 @@ _attr_parse_radial_gradient_node(void *data, const char *key, const char *value)
 static Svg_Style_Gradient *
 _create_radialGradient(Evas_SVG_Loader *loader, const char *buf, unsigned buflen)
 {
+   unsigned int i = 0;
    Svg_Style_Gradient *grad = calloc(1, sizeof(Svg_Style_Gradient));
    loader->svg_parse->style_grad = grad;
 
@@ -1821,6 +1902,11 @@ _create_radialGradient(Evas_SVG_Loader *loader, const char *buf, unsigned buflen
    eina_simple_xml_attributes_parse(buf, buflen,
                                     _attr_parse_radial_gradient_node, loader);
 
+   for (i = 0; i < sizeof (radial_tags) / sizeof(radial_tags[0]); i++)
+     radial_tags[i].tag_recalc(loader, grad->radial, grad->user_space);
+
+   grad->use_percentage = EINA_TRUE;
+
    return loader->svg_parse->style_grad;
 }
 
@@ -1961,6 +2047,10 @@ _attr_parse_linear_gradient_node(void *data, const char *key, const char *value)
      {
         grad->user_space = EINA_TRUE;
      }
+   else if (!strcmp(key, "gradientTransform"))
+     {
+        grad->transform = _parse_transformation_matrix(value);
+     }
 
    return EINA_TRUE;
 }
@@ -2087,11 +2177,21 @@ _evas_svg_loader_xml_open_parser(Evas_SVG_Loader *loader,
      {
         Svg_Style_Gradient *gradient;
         gradient = gradient_method(loader, attrs, attrs_length);
+        /*FIXME: The current parsing structure does not distinguish end tags.
+                 There is no way to know if the currently parsed gradient is in defs.
+                 If a gradient is declared outside of defs after defs is set, it is included in the gradients of defs.
+                 But finally, the loader has a gradient style list regardless of defs.
+                 This is only to support this when multiple gradients are declared, even if no defs are declared.
+                 refer to: https://developer.mozilla.org/en-US/docs/Web/SVG/Element/defs */
         if (loader->doc->node.doc.defs)
           {
              loader->def->node.defs.gradients = eina_list_append(loader->def->node.defs.gradients, gradient);
           }
-        loader->gradient = gradient;
+        else
+          {
+             loader->gradients = eina_list_append(loader->gradients, gradient);
+          }
+        loader->latest_gradient = gradient;
      }
    else if (!strcmp(tag_name, "stop"))
      {
@@ -2101,8 +2201,10 @@ _evas_svg_loader_xml_open_parser(Evas_SVG_Loader *loader,
         stop->a = 255;
         eina_simple_xml_attributes_parse(attrs, attrs_length,
                                     _attr_parse_stops, loader);
-        if (loader->gradient)
-          loader->gradient->stops = eina_list_append(loader->gradient->stops, stop);
+        if (loader->latest_gradient)
+          {
+             loader->latest_gradient->stops = eina_list_append(loader->latest_gradient->stops, stop);
+          }
      }
 
 }
@@ -2344,9 +2446,9 @@ evas_vg_load_file_open_svg(Eina_File *file,
           _update_gradient(loader.doc, defs->node.defs.gradients);
         else
           {
-             if (loader.gradient)
+             if (loader.gradients)
                {
-                  Eina_List* gradient_list = eina_list_append(NULL, loader.gradient);
+                  Eina_List* gradient_list = loader.gradients;
                   _update_gradient(loader.doc, gradient_list);
                   eina_list_free(gradient_list);
                }
