@@ -202,10 +202,11 @@ struct _Svg_Style_Gradient
    Eina_Stringshare  *id;
    Eina_Stringshare  *ref;
    Efl_Gfx_Gradient_Spread spread;
-   Eina_Bool user_space;
    Eina_List   *stops; // Efl_Gfx_Gradient_Stop
    Svg_Radial_Gradient *radial;
    Svg_Linear_Gradient *linear;
+   Eina_Matrix3 *transform;
+   Eina_Bool user_space;
    Eina_Bool use_percentage;
 };
 
@@ -271,6 +272,7 @@ struct _Svg_Style_Property
    int                r;
    int                g;
    int                b;
+   int                opacity;
 };
 
 struct _Svg_Node
@@ -281,6 +283,7 @@ struct _Svg_Node
    Eina_Stringshare    *id;
    Svg_Style_Property  *style;
    Eina_Matrix3        *transform;
+   Eina_Bool           display;
    union
      {
         Svg_G_Node   g;
@@ -318,4 +321,10 @@ Vg_File_Data * vg_common_svg_create_vg_node(Svg_Node *node);
 Svg_Node *vg_common_svg_create_svg_node(Vg_File_Data *node);
 void vg_common_svg_node_free(Svg_Node *node);
 
+
+/******************************************************************************************
+ * Lottie Compatible feature implementation
+ ******************************************************************************************/
+Eina_Bool vg_common_json_create_vg_node(Vg_File_Data *vfd);
+
 #endif //EVAS_VG_COMMON_H_
