@@ -22,12 +22,23 @@
 
 #include "ector_suite.h"
 #include "../efl_check.h"
+#include <Ector.h>
 
 static const Efl_Test_Case etc[] = {
   { "init", ector_test_init },
   { NULL, NULL }
 };
 
+SUITE_INIT(ector)
+{
+   ck_assert_int_eq(ector_init(), 1);
+}
+
+SUITE_SHUTDOWN(ector)
+{
+   ck_assert_int_eq(ector_shutdown(), 0);
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -41,7 +52,7 @@ main(int argc, char *argv[])
 #endif
 
    failed_count = _efl_suite_build_and_run(argc - 1, (const char **)argv + 1,
-                                           "Ector", etc);
+                                           "Ector", etc, SUITE_INIT_FN(ector), SUITE_SHUTDOWN_FN(ector));
 
    return (failed_count == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
