@@ -1,16 +1,28 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 using System;
 using System.Linq;
 using System.Collections.Generic;
+using System.Reflection;
 
 namespace TestSuite
 {
 
 class TestEo
 {
-    private class Derived : Dummy.TestObject
-    {
-    }
-
     public static void return_null_object()
     {
         var testing = new Dummy.TestObject();
@@ -56,7 +68,7 @@ class TestEo
        {
            var obj = new Dummy.TestObject();
            Eina.Log.Error($"Created object 0x{obj.NativeHandle.ToInt64():x}");
-           obj.DelEvt += (object sender, EventArgs e) => { delEventCalled = true; };
+           obj.DelEvent += (object sender, EventArgs e) => { delEventCalled = true; };
            Eina.Log.Error($"Will dispose object 0x{obj.NativeHandle.ToInt64():x}");
            ((IDisposable)obj).Dispose();
        }
@@ -110,6 +122,20 @@ class TestEoInherit
         Efl.Object loop = new MyObject();
         Test.Assert(loop.NativeHandle != System.IntPtr.Zero);
     }
+
+    private static WeakReference CreateCollectableInherited()
+    {
+        var obj = new MyObject();
+        return new WeakReference(obj);
+    }
+
+    public static void inherited_collected()
+    {
+        var wref = CreateCollectableInherited();
+        Test.CollectAndIterate(300, 10);
+
+        Test.AssertNull(wref.Target);
+    }
 }
 
 class TestEoNames
@@ -232,7 +258,7 @@ class TestEoAccessors
 
         var zipped = acc.Zip(lst, (first, second) => new Tuple<int, int>(first, second));
 
-        foreach(Tuple<int, int> pair in zipped)
+        foreach (Tuple<int, int> pair in zipped)
         {
             Test.AssertEquals(pair.Item1, pair.Item2);
         }
@@ -334,6 +360,14 @@ class TestCsharpProperties
         iface.IfaceProp = val;
         Test.AssertEquals(val, iface.IfaceProp);
     }
+
+    public static void test_csharp_multi_valued_prop()
+    {
+        var obj = new Dummy.TestObject();
+        obj.MultiValuedProp = (1, 2);
+        var ret = obj.MultiValuedProp;
+        Test.AssertEquals(ret, (1, 2));
+    }
 }
 
 class TestEoGrandChildrenFinalize
@@ -496,4 +530,117 @@ class TestProvider
     }
 }
 
+class TestObjectDeletion
+{
+    public static void test_object_deletion()
+    {
+        var obj = new Dummy.PartHolder();
+        var part = obj.OnePart;
+
+        Test.AssertNotNull(part);
+
+        part.Del();
+
+        Test.AssertNull(obj.OnePart);
+    }
+}
+
+class TestProtectedInterfaceMembers
+{
+
+    private class MyObject : Dummy.TestObject
+    {
+        public MyObject(Efl.Object parent = null) : base(parent)
+        {
+        }
+
+        protected override int MethodProtected(int x)
+        {
+            return x * x;
+        }
+    }
+
+    public static void test_protected_interface_in_generated_class_called_from_c()
+    {
+        var obj = new Dummy.TestObject();
+        Test.AssertEquals(obj.CallMethodProtected(42), -42);
+    }
+
+    public static void test_protected_interface_in_inherited_class_called_from_c()
+    {
+        var obj = new MyObject();
+        Test.AssertEquals(obj.CallMethodProtected(42), 42 * 42);
+    }
+
+    public static void test_interface_skipped_protected()
+    {
+        var type = typeof(Dummy.ITestIface);
+        var methods = type.GetMethods(BindingFlags.Public | BindingFlags.Instance);
+
+        // Fully protected property
+        Test.AssertNull(methods.SingleOrDefault(m => m.Name == "GetProtectedProp"));
+        Test.AssertNull(methods.SingleOrDefault(m => m.Name == "SetProtectedProp"));
+
+        // Partially protected property
+        Test.AssertNotNull(methods.SingleOrDefault(m => m.Name == "GetPublicGetterPrivateSetter"));
+        Test.AssertNull(methods.SingleOrDefault(m => m.Name == "SetPublicGetterPrivateSetter"));
+
+        var properties = type.GetProperties(BindingFlags.Public | BindingFlags.Instance);
+        Test.AssertNull(properties.SingleOrDefault(m => m.Name == "ProtectedProp"));
+        Test.AssertNotNull(properties.SingleOrDefault(m => m.Name == "PublicGetterPrivateSetter"));
+    }
+
+    public static void test_interface_skipped_protected_in_implementation()
+    {
+        var type = typeof(Dummy.TestObject);
+
+        // Fully protected property
+        var protected_methods = type.GetMethods(BindingFlags.NonPublic | BindingFlags.Instance).Where(m => m.IsFamily);
+        Test.AssertNotNull(protected_methods.SingleOrDefault(m => m.Name == "GetProtectedProp"));
+        Test.AssertNotNull(protected_methods.SingleOrDefault(m => m.Name == "SetProtectedProp"));
+
+        // Partially protected property
+        var public_methods = type.GetMethods(BindingFlags.Public | BindingFlags.Instance);
+        Test.AssertNotNull(public_methods.SingleOrDefault(m => m.Name == "GetPublicGetterPrivateSetter"));
+        Test.AssertNotNull(protected_methods.SingleOrDefault(m => m.Name == "SetPublicGetterPrivateSetter"));
+
+        var protected_properties = type.GetProperties(BindingFlags.NonPublic | BindingFlags.Instance);
+        var prop = protected_properties.SingleOrDefault(m => m.Name == "ProtectedProp");
+        Test.AssertNotNull(prop);
+        Test.Assert(prop.GetMethod.IsFamily);
+        Test.Assert(prop.SetMethod.IsFamily);
+
+        var public_properties = type.GetProperties(BindingFlags.Public | BindingFlags.Instance);
+        prop = public_properties.SingleOrDefault(m => m.Name == "PublicGetterPrivateSetter");
+        Test.AssertNotNull(prop);
+        Test.Assert(prop.GetMethod.IsPublic);
+        Test.Assert(prop.SetMethod.IsFamily);
+    }
+}
+
+class TestStaticInterfaceMembers
+{
+    public static void test_interface_static_member()
+    {
+        var iface = typeof(Dummy.ITestIface);
+        var properties = iface.GetProperties(BindingFlags.Public | BindingFlags.Instance);
+        Test.AssertNull(properties.SingleOrDefault(p => p.Name == "StaticProp"));
+
+        var implementation = typeof(Dummy.TestObject);
+        properties = implementation.GetProperties(BindingFlags.Public | BindingFlags.Static);
+        Test.AssertNotNull(properties.SingleOrDefault(p => p.Name == "StaticProp"));
+    }
+}
+
+class TestHiddenClasses
+{
+    public static void test_hidden_class()
+    {
+        var obj = new Dummy.TestObject();
+        var hidden = obj.HiddenObject;
+
+        Test.AssertEquals(hidden.Name, "hidden_object");
+    }
+}
+
 }
