@@ -1,3 +1,18 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 using System;
 
 namespace TestSuite
@@ -21,8 +36,10 @@ class TestEinaError
 class TestEolianError
 {
 
-    class CustomException : Exception {
+    public class CustomException : Exception {
+        public CustomException() {}
         public CustomException(string msg): base(msg) {}
+        public CustomException(string msg, Exception inner) : base(msg, inner) {}
     }
 
     class Overrider : Dummy.TestObject {
@@ -99,7 +116,7 @@ class TestEolianError
         // the managed code
         var obj = new Dummy.TestObject();
         Listener listener = new Listener();
-        obj.EvtWithIntEvt += listener.callback;
+        obj.EvtWithIntEvent += listener.callback;
 
         Test.AssertRaises<Efl.EflException>(() => { obj.EmitEventWithInt(2); });
     }
