@@ -1,3 +1,18 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 using System;
 using System.Runtime.InteropServices;
 using System.Runtime.CompilerServices;
@@ -15,7 +30,10 @@ class TestMain
 
     static int Main(string[] args)
     {
-        Efl.All.Init();
+        if (Environment.GetEnvironmentVariable("ELM_ENGINE") == null)
+            Environment.SetEnvironmentVariable("ELM_ENGINE", "buffer");
+
+        Efl.All.Init(Efl.Csharp.Components.Ui);
 
         bool pass = true;
 
@@ -30,18 +48,21 @@ class TestMain
 
         Console.WriteLine("[ START SUITE ] " + ckRunSuite);
         var cases= GetTestCases(ckRunCase);
-        foreach(var testCase in cases)
+        foreach (var testCase in cases)
         {
             var localTestCases = testCase.GetMethods(BindingFlags.Static | BindingFlags.Public);
 
             var setUp = Array.Find(localTestCases, m => String.Equals(m.Name, "SetUp", StringComparison.Ordinal));
             var tearDown = Array.Find(localTestCases, m => String.Equals(m.Name, "TearDown", StringComparison.Ordinal));
 
-            foreach(var localTestCase in localTestCases)
+            foreach (var localTestCase in localTestCases)
             {
                 if (localTestCase == setUp || localTestCase == tearDown)
                     continue;
 
+                // Cleanup garbage collector and job queue
+                Test.CollectAndIterate(1);
+
                 Console.WriteLine("[ RUN         ] " + testCase.Name + "." + localTestCase.Name);
                 bool caseResult = true;
 
