@@ -1,3 +1,18 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 using System;
 using System.Runtime.InteropServices;
 using System.Linq;
@@ -20,11 +35,13 @@ internal class TestStructs
         checkZeroedStructSimple(simple);
     }
 
+#if EFL_BETA
     private static void complex_default_instantiation()
     {
         var complex = new Dummy.StructComplex();
         checkZeroedStructComplex(complex);
     }
+#endif
 
     public static void parameter_initialization()
     {
@@ -47,6 +64,7 @@ internal class TestStructs
         Test.Assert(r, "Function returned false");
     }
 
+    /*
     public static void simple_ptr_in()
     {
         var simple = structSimpleWithValues();
@@ -68,6 +86,7 @@ internal class TestStructs
         Test.AssertEquals(-original, result.Fint);
         Test.AssertEquals("nwO nI rtP tcurtS", result.Fmstring);
     }
+    */
 
     public static void simple_out()
     {
@@ -78,6 +97,7 @@ internal class TestStructs
         checkStructSimple(simple);
     }
 
+    /*
     public static void simple_ptr_out()
     {
         Dummy.StructSimple simple;
@@ -95,6 +115,7 @@ internal class TestStructs
         Test.AssertEquals(result.Fint, simple.Fint);
         Test.AssertEquals(simple.Fstring, "Ptr Out Own");
     }
+    */
 
     public static void simple_return()
     {
@@ -103,6 +124,7 @@ internal class TestStructs
         checkStructSimple(simple);
     }
 
+    /*
     public static void simple_ptr_return()
     {
         var t = new Dummy.TestObject();
@@ -116,6 +138,7 @@ internal class TestStructs
         var simple = t.StructSimplePtrReturnOwn();
         Test.AssertEquals(simple.Fstring, "Ret Ptr Own");
     }
+    */
 
     public class StructReturner : Dummy.TestObject
     {
@@ -136,6 +159,7 @@ internal class TestStructs
             return true;
         }
 
+        /*
         public override bool StructSimplePtrIn(ref Dummy.StructSimple simple)
         {
             called = true;
@@ -149,6 +173,7 @@ internal class TestStructs
             received = simple;
             return received;
         }
+        */
 
         public override bool StructSimpleOut(out Dummy.StructSimple simple) {
             called = true;
@@ -157,6 +182,7 @@ internal class TestStructs
             return true;
         }
 
+        /*
         public override Dummy.StructSimple StructSimplePtrOut(out Dummy.StructSimple simple) {
             called = true;
             // No way to explicitly define the ownership of the parameter.
@@ -172,6 +198,7 @@ internal class TestStructs
             simple.Fstring = "Virtual Struct Ptr Out Own";
             return simple;
         }
+        */
 
         public override Dummy.StructSimple StructSimpleReturn()
         {
@@ -181,6 +208,7 @@ internal class TestStructs
             return simple;
         }
 
+        /*
         public override Dummy.StructSimple StructSimplePtrReturn()
         {
             called = true;
@@ -196,6 +224,7 @@ internal class TestStructs
             simple.Fstring = "Virtual Struct Ptr Return Own";
             return simple;
         }
+        */
     }
 
     public static void simple_in_virtual()
@@ -209,6 +238,7 @@ internal class TestStructs
         Test.AssertEquals(simple.Fstring, t.received.Fstring);
     }
 
+    /*
     public static void simple_ptr_in_virtual()
     {
         StructReturner t = new StructReturner();
@@ -230,6 +260,7 @@ internal class TestStructs
         Test.Assert(t.called);
         Test.AssertEquals(t.received.Fstring, simple.Fstring);
     }
+    */
 
     public static void simple_out_virtual()
     {
@@ -240,6 +271,7 @@ internal class TestStructs
         Test.AssertEquals("Virtual Struct Out", simple.Fstring);
     }
 
+    /*
     public static void simple_ptr_out_virtual()
     {
         StructReturner t = new StructReturner();
@@ -257,6 +289,7 @@ internal class TestStructs
         Test.Assert(t.called, "override was not called");
         Test.AssertEquals("Virtual Struct Ptr Out Own", simple.Fstring);
     }
+    */
 
     public static void simple_return_virtual()
     {
@@ -266,6 +299,7 @@ internal class TestStructs
         Test.AssertEquals("Virtual Struct Return", simple.Fstring);
     }
 
+    /*
     public static void simple_ptr_return_virtual()
     {
         StructReturner t = new StructReturner();
@@ -281,7 +315,9 @@ internal class TestStructs
         Test.Assert(t.called, "override was not called");
         Test.AssertEquals("Virtual Struct Ptr Return Own", simple.Fstring);
     }
+    */
 
+#if EFL_BETA
     // Complex Structs
     public static void complex_in()
     {
@@ -322,7 +358,7 @@ internal class TestStructs
         var complex = t.StructComplexReturn();
         checkStructComplex(complex);
     }
-
+#endif
     // public static void complex_ptr_return()
     // {
     // }
