@@ -29,13 +29,12 @@
 
 #include "eina_suite.h"
 
-START_TEST(eina_matrix2)
+EFL_START_TEST(eina_matrix2)
 {
    Eina_Matrix2 m;
    Eina_Matrix2 n;
    double xx, xy, yx, yy;
 
-   eina_init();
 
    eina_matrix2_values_set(&m,
                            1, 0,
@@ -54,11 +53,10 @@ START_TEST(eina_matrix2)
    fail_if(!EINA_DBL_EQ(xy, yx) ||
            !EINA_DBL_EQ(xy, 0));
 
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix2_operation)
+EFL_START_TEST(eina_matrix2_operation)
 {
    Eina_Matrix2 m1, m2, m3;
    double xx, xy, yx, yy;
@@ -119,9 +117,9 @@ START_TEST(eina_matrix2_operation)
            !EINA_DBL_EQ(xy, 5));
 
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix4)
+EFL_START_TEST(eina_matrix4)
 {
    Eina_Matrix4 m;
    Eina_Matrix4 n;
@@ -130,7 +128,6 @@ START_TEST(eina_matrix4)
      zx, zy, zz, zw,
      wx, wy, wz, ww;
 
-   eina_init();
 
    eina_matrix4_values_set(&m,
                            1, 0, 0, 0,
@@ -192,11 +189,10 @@ START_TEST(eina_matrix4)
            !EINA_DBL_EQ(n.wz, 12) ||
            !EINA_DBL_EQ(n.ww, 16));
 
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix4_operation)
+EFL_START_TEST(eina_matrix4_operation)
 {
    double det;
    double l=5, r=4, b=4, t=3, dn=3, df=2;
@@ -316,14 +312,13 @@ START_TEST(eina_matrix4_operation)
             !EINA_DBL_EQ(wz, 5) ||
             !EINA_DBL_EQ(ww, 1));
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix4_2_3)
+EFL_START_TEST(eina_matrix4_2_3)
 {
    Eina_Matrix4 m4;
    Eina_Matrix3 m3, m3b;
 
-   eina_init();
 
    eina_matrix3_values_set(&m3,
                            1, 3, 2,
@@ -335,11 +330,10 @@ START_TEST(eina_matrix4_2_3)
 
    fail_if(memcmp(&m3, &m3b, sizeof (Eina_Matrix3)) != 0);
 
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix3)
+EFL_START_TEST(eina_matrix3)
 {
    Eina_Bool ret;
    Eina_Matrix3 m, m1, m2;
@@ -347,7 +341,6 @@ START_TEST(eina_matrix3)
           yx, yy, yz,
           zx, zy, zz;
 
-          eina_init();
 
    eina_matrix3_values_set(&m,
                            1, 0, 0,
@@ -385,9 +378,8 @@ START_TEST(eina_matrix3)
    ret = eina_matrix3_equal(&m1, &m2);
    fail_if(ret != EINA_FALSE);
 
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
 #define MATRIX3_CMP(XX, XY, XZ, YX, YY, YZ, ZX, ZY, ZZ, AXX, AXY, AXZ, AYX, AYY, AYZ, AZX, AZY, AZZ) \
   (EINA_DBL_EQ(XX, AXX) && \
@@ -400,7 +392,7 @@ END_TEST
    EINA_DBL_EQ(ZY, AZY) && \
    EINA_DBL_EQ(ZZ, AZZ))
 
-START_TEST(eina_matrix3_operations)
+EFL_START_TEST(eina_matrix3_operations)
 {
    Eina_Matrix3 m1, m2, m3;
    double xx, xy, xz,
@@ -653,9 +645,9 @@ START_TEST(eina_matrix3_operations)
    fail_if (!EINA_DBL_EQ(xx, 6) ||
             !EINA_DBL_EQ(yy, 7));
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix3_f16p16)
+EFL_START_TEST(eina_matrix3_f16p16)
 {
    Eina_Matrix3_F16p16 m1;
    Eina_Matrix3 m2;
@@ -664,7 +656,6 @@ START_TEST(eina_matrix3_f16p16)
                zx, zy, zz;
    Eina_Matrix3_F16p16 m3;
 
-   eina_init();
 
    eina_matrix3_values_set(&m2,
                            1, 0, 0,
@@ -715,11 +706,10 @@ START_TEST(eina_matrix3_f16p16)
             m3.zy != m3.zz ||
             m3.zz != 196608);
 
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_matrix3_map_transform)
+EFL_START_TEST(eina_matrix3_map_transform)
 {
    double x = 2, y = 3, x1, y1;
    Eina_Matrix3 m;
@@ -727,7 +717,6 @@ START_TEST(eina_matrix3_map_transform)
    Eina_Quad q;
    Eina_Bool ret;
 
-   eina_init();
 
    eina_matrix3_values_set(&m,
                            0, 1, 0,
@@ -779,11 +768,10 @@ START_TEST(eina_matrix3_map_transform)
            !EINA_DBL_EQ(q.x3, 0) ||
            !EINA_DBL_EQ(q.y3, 3));
 
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eina_normal3_test)
+EFL_START_TEST(eina_normal3_test)
 {
    Eina_Matrix3 out;
    Eina_Matrix4 m;
@@ -791,7 +779,6 @@ START_TEST(eina_normal3_test)
           yx, yy, yz,
           zx, zy, zz;
 
-   eina_init();
    eina_matrix4_values_set(&m,
                            1, 0, 0, 0,
                            0, 1, 0, 0,
@@ -826,9 +813,8 @@ START_TEST(eina_normal3_test)
            (fabs(yz)) > DBL_EPSILON ||
            (fabs(zy)) > DBL_EPSILON
           );
-   eina_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
 void
 eina_test_matrix(TCase *tc)
