@@ -3,7 +3,7 @@
 #endif
 
 #include "efl_ui_suite.h"
-#include "suite_helpers.h"
+#include "eo_internal.h"
 
 static const Efl_Test_Case etc[] = {
   //{ "elm_focus", elm_test_focus},
@@ -11,6 +11,7 @@ static const Efl_Test_Case etc[] = {
   //{ "elm_widget_focus", elm_test_widget_focus},
   { "efl_ui_atspi", efl_ui_test_atspi},
   { "efl_ui_callback", efl_ui_test_callback},
+  { "efl_ui_config", efl_ui_test_config},
   { "efl_ui_focus", efl_ui_test_focus},
   { "efl_ui_focus_sub", efl_ui_test_focus_sub},
   { "efl_ui_box", efl_ui_test_box},
@@ -24,9 +25,27 @@ static const Efl_Test_Case etc[] = {
   { "efl_ui_layout", efl_ui_test_layout},
   { "Efl_Ui_Model", efl_ui_model },
   { "efl_ui_widget", efl_ui_test_widget },
+  { "efl_ui_spotlight", efl_ui_test_spotlight},
+  { "efl_ui_check", efl_ui_test_check },
+  { "efl_ui_popup", efl_ui_test_popup },
+  { "efl_ui_progressbar", efl_ui_test_progressbar },
+  { "efl_ui_radio_group", efl_ui_test_radio_group },
+  { "efl_ui_scroller", efl_ui_test_scroller },
+  { "efl_ui_slider", efl_ui_test_slider },
+  { "efl_ui_win", efl_ui_test_win },
+  { "efl_ui_spin", efl_ui_test_spin },
+  { "efl_ui_spin_button", efl_ui_test_spin_button },
+  { "efl_ui_collection", efl_ui_test_item_container },
+  { "efl_ui_grid_container", efl_ui_test_grid_container },
+  { "efl_ui_list_container", efl_ui_test_list_container },
+  { "efl_ui_select_model", efl_ui_test_select_model },
+  { "efl_ui_view_model", efl_ui_test_view_model },
+  { "efl_ui_group_item", efl_ui_test_group_item },
   { NULL, NULL }
 };
 
+EFL_CLASS_SIMPLE_CLASS(efl_ui_widget, "efl_ui_widget", EFL_UI_WIDGET_CLASS);
+
 int
 main(int argc, char **argv)
 {
