@@ -6,6 +6,7 @@
 #define EFL_ACCESS_OBJECT_PROTECTED
 #include <Elementary.h>
 #include "elm_suite.h"
+#include "suite_helpers.h"
 
 static Evas_Object *win, *genlist;
 static Elm_Gen_Item_Class itc = { .version = ELM_GENLIST_ITEM_CLASS_VERSION };
@@ -14,9 +15,6 @@ static int counter;
 static Efl_Access_Event_Children_Changed_Data ev_data;
 Evas_Object *content;
 
-static int tree_abort_level;
-static int tree_abort;
-
 static void
 verify_item_iteration_api(Elm_Object_Item *parent)
 {
@@ -161,7 +159,7 @@ EFL_START_TEST(elm_genlist_test_item_content)
    evas_object_show(genlist);
    evas_object_show(win);
 
-   ecore_main_loop_begin();
+   get_me_to_those_events(win);
 
    end = elm_object_item_part_content_get(it, "elm.swallow.end");
    parent = elm_object_parent_widget_get(end);
@@ -385,6 +383,7 @@ EFL_START_TEST(elm_genlist_test_item_destroy)
 EFL_END_TEST
 
 #define NUM_TREE_ITEMS 10
+#define GL_ITEM_SIZE_ISH 30
 
 static Evas_Object *
 genlist_tree_test_content_get(void *data EINA_UNUSED, Evas_Object *obj, const char *part)
@@ -456,8 +455,6 @@ static void
 _do_quit()
 {
    itc.func.content_get = NULL;
-   eina_log_abort_on_critical_set(tree_abort);
-   eina_log_abort_on_critical_level_set(tree_abort_level);
    ecore_main_loop_quit();
 }
 
@@ -503,6 +500,7 @@ EFL_START_TEST(elm_genlist_test_tree_expand)
 
    evas_object_size_hint_align_set(genlist, EVAS_HINT_FILL, EVAS_HINT_FILL);
    evas_object_size_hint_weight_set(genlist, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_weight_set(win, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    elm_genlist_item_append(genlist, &itc,
                            NULL/* item data */, NULL/* parent */,
                            ELM_GENLIST_ITEM_TREE, NULL/* func */,
@@ -514,14 +512,10 @@ EFL_START_TEST(elm_genlist_test_tree_expand)
                              NULL/* func data */);
 
    evas_object_show(genlist);
-   evas_object_resize(genlist, 100, 10 + 10 * NUM_TREE_ITEMS);
+   evas_object_resize(genlist, 100, 10 + GL_ITEM_SIZE_ISH * NUM_TREE_ITEMS);
    evas_object_show(win);
-   evas_object_resize(win, 100, 10 + 10 * NUM_TREE_ITEMS);
-   tree_abort = eina_log_abort_on_critical_get();
-   tree_abort_level = eina_log_abort_on_critical_level_get();
-   /* this should never trigger errors */
-   eina_log_abort_on_critical_level_set(1);
-   eina_log_abort_on_critical_set(1);
+   evas_object_resize(win, 100, 10 + GL_ITEM_SIZE_ISH * NUM_TREE_ITEMS);
+
    ecore_main_loop_begin();
 }
 EFL_END_TEST
