@@ -14,7 +14,7 @@ _object_impl_a_set(Eo *obj, Object_Impl_Data *pd, const char *part, const Eina_L
 }
 
 EOLIAN static Eina_List *
-_object_impl_a_get(Eo *obj, Object_Impl_Data *pd, const char *part)
+_object_impl_a_get(const Eo *obj, Object_Impl_Data *pd, const char *part)
 {
 
 }
