@@ -1,3 +1,18 @@
+/*
+ * Copyright 2019 by its authors. See AUTHORS.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
@@ -24,7 +39,7 @@ klass_def init_test_data(efl::eolian::eolian_state const& state)
 {
    ck_assert(::eolian_state_directory_add(state.value, TESTS_SRC_DIR));
    ck_assert(::eolian_state_all_eot_files_parse(state.value));
-   ck_assert(::eolian_state_file_parse(state.value, TESTS_SRC_DIR"/docs.eo"));
+   ck_assert(::eolian_state_file_parse(state.value, "docs.eo"));
 
    const Eolian_Class *c_klass = ::eolian_state_class_by_name_get(state.value, "Docs");
    ck_assert_ptr_ne(c_klass, NULL);
