@@ -4,6 +4,7 @@
 #include <check.h>
 #include "../efl_check.h"
 void evas_test_init(TCase *tc);
+void evas_test_focus(TCase *tc);
 void evas_test_new(TCase *tc);
 void evas_test_object(TCase *tc);
 void evas_test_textblock(TCase *tc);
@@ -21,5 +22,6 @@ void evas_test_mask(TCase *tc);
 void evas_test_evasgl(TCase *tc);
 void evas_test_object_smart(TCase *tc);
 void evas_test_matrix(TCase *tc);
+void evas_test_events(TCase *tc);
 
 #endif /* _EVAS_SUITE_H */
